/*	 Copyright (c) 2010-2018 by ANNECY ELECTRONIQUE, Chavanod, France


   Environment :	PC	(Langage C)

   DESCRIPTION:

   Bibliothque d'accs aux cartes EXXOTEST Multiplexage //
   DLL interface for EXXOTest Multiplexing board

   AUTHOR : Philippe CHAZOT

   MODIFICATION:

        V 6.00 (new driver) 19/04/2010 Cyril BOJIDAROVITCH
      - Add support of Windows 64 bits architecture.
      - Porting Muxdll On visual Studio.
	
        V 6.01 (new driver) 10/05/2010 Cyril BOJIDAROVITCH
      - Add some fonctionnality in driver.

        V 6.02 (new driver) 03/06/2010
      - Send preRelease for some test.

        V 6.03 (new driver) 01/07/2010 Cyril BOJIDAROVITCH
      - Add CanReadMsg && CanWriteMsg.

        V 6.04 (new driver) 19/07/2010 Cyril BOJIDAROVITCH
      - Powers fonctions Added to the drivers.
      - Add some internals fonctions.
      - Correct a size error on Win2k.

        V 6.05 (new driver) 26/07/2010 Cyril BOJIDAROVITCH
      - Improve efficiency in spy mode.
      - On client software crash, unplug device is no longer necessary.

        V 6.06 (new driver) 18/08/2010 Cyril BOJIDAROVITCH
      - Correct a memory leak in MuxLoadDLL.

        V 6.07 (new driver) 31/08/2010 Cyril BOJIDAROIVTCH
      - Correct a bug in MuxGetVersion.
      - Add MuxSetEthernet & MuxGetEthernet functions.

        V 6.08 (new driver) 07/10/2010 Cyril BOJIDAROVITCH
      - Add support of CanChangeBaudRate for 6C6L.

        V 6.09 (new driver) 29/10/2010 Cyril BOJIDAROVITCH
      - Improve max licence number. 

        V 6.10 (new driver) 15/11/2010	Cyril BOJIDAROVITCH
      - Add support of 4C4L.

        V 6.11 (new driver) 11/02/2011	Cyril BOJIDAROVITCH / Vincent COMINOTTI / Nouredine BOUNEMOURA / David PROVENT
      - Correct LIN 2.X management for PCI boards
      - Add additional length byte option for ISO14230 messages less than 64 bytes
      - Add new LIN / ISO speed

        V 6.12 (new driver) 02/03/2011 Cyril BOJIDAROVITCH
      - Correct CanconfigBus for the bus load calculation 

        V 6.13 (new driver) 12/05/2011 Cyril BOJIDAROVITCH
      - Add J1939 protocol.

        V 6.14 (new driver) 07/06/2011 Cyril BOJIDAROVITCH
      - Add NwcSetBytePadding function

        V 6.15 (new driver) 25/07/2011 Cyril BOJIDAROVITCH
      - Add NMEA2000 support

        V 6.16 28/10/2011 Nouredine BOUNEMOURA
      - End of support for Exxotest v1.x.x and Jungo v5.2.2 USB drivers
      - Support now Exxotest USB v2.x.x & above, Jungo PCI v6.0.3 (Kernel Plugin v1.2.4, VXD 4.34)
      - Remove cards counting from MuxInit, MuxPciGetCardInfo and MuxUsbGetCardInfo
      - Dynamically load Winsock 2 and IP Helper DLLs at main entry
      - Change MuxEthCountCards and add new function MuxEthGetCardInfo
      - Change MuxOpen & MuxClose for Ethernet cards (wired and wireless), update IP routing table if necessary
      - MuxWifiCountCards & MuxWifiGetCardInfo deprecated : use MuxEthCountCards & MuxEthGetCardInfo instead
      - Minor change in EEPROM initialization routine for PCI boards
      - MuxGetHardwareID function valid only for USB cards
      - CAN error events of same type now signaled only once per ms (PCI boards)
      - Minor change for LIN IFR handling (PCI boards)
      - Correction in length management for ISO 9141 & ISO 14230 protocols (PCI boards)
      - Add new function NMEA0183ConfigUart

        V 6.17 07/12/2011 Nouredine BOUNEMOURA
      - All USB drivers workable (Exxotest v1.x.x/v2.x.x and Jungo v6.0.3)
      - Dynamically load extern DLLs during execution (only when needed and no more at main entry)
      - Ensure that all allocated resources are freed when DLL is being unloaded
      - Minors corrections in the FlashFileDownload function
      - Add extra informations to LIN events : checksum and protected identifier
      - Add 64 bits version of the MUXDLL library

        V 6.18 14/12/2011 Nouredine BOUNEMOURA
      - Add version number for Exxotest USB drivers
      - Correct index of the configuration's interface to be registered for USB data transfer
      - Correct a parameter passed to the ETH data transfer function

        V 6.19 22/06/2012 Nouredine BOUNEMOURA
      - Fix MuxGetBuildNumber function
      - Start migration to Jungo WDU library
      - Minors corrections in the MuxOpen function
      - Support of the opening of non multiplexed Ethernet cards
      - TCP sockets are now placed in non-blocking mode
      - The wCard parameter is now correctly checked in the MuxEthGetCardInfo function
      - Change the handling of CAN periodic frames to correct some minor bugs (PCI boards) 
      - Support commands whose response has unknown size
      - Minors changes in FlashGetInformations and FlashFileDownload functions
      - Fix the position numbers in IO events (for edge-triggered inputs)
      - Change the calling convention for all J1939 functions, add J19ChannelParam and correct a memory leak
      - General code cleanup

        V 6.20 28/01/2013 Nouredine BOUNEMOURA
      - Minor change in FlashGetInformations function
      - Change default timeout value to 5s for wireless ethernet cards
      - Remove counter used for opening and closing USB driver
      - All CAN clock frequencies are now supported for non multiplexed cards
      - MuxPciCountCards, MuxUsbCountCards and MuxEthCountCards are now thread safe again
      - MuxInit will now fail if the card is in the opened state (may be forced by setting MSB of wCard parameter)
      - Changes in MuxEthCountCards function to differentiate between wired and wireless cards
      - Changes in the way of opening and closing ethernet cards
      - Some resources are not freed anymore when MuxClose is called as a result of process termination

        V 6.21 31/05/2013 Nouredine BOUNEMOURA / Alexandre GAMBIER / Franois-Georges REY
       - Add support for a new device
            + USB_MUX_DIAG_V2_LT (USB Device - 1 CAN 1 ISO/LIN)
       - Add new Admin functions :
            + AdminGetLicenceData
            + AdminSetLicenceData
            + AdminReadLicencesData
            + AdminWriteLicencesData
       - Minor changes to AdminReadLicences and AdminWriteLicences functions
       - Add a new function to stop the read thread of Exxotest v2.x.x USB driver (when required)
       - Fix a problem with the initialization of the TX FIFO for ISO 9141 & ISO 14230 protocols
       - Change to MuxEthCountCards: for wireless networks, send several times the counting datagram

        V 6.30 21/05/2014 Nouredine BOUNEMOURA
       - Update Jungo Windriver to version 8.02 and add 64-bit support for PCI boards
       - Change to AdminWriteLicencesData: accept NULL parameters to enable erase of the last remaining licence data
       - Change to MuxEthCountCards: enhance the processing of received datagrams
       - Unload extern DLLs after execution (MuxOpen, MuxClose and MuxEthCountCards) 
       - Minor changes to the formatting of the last error string
       - Remove the keyword 'HANDLE' from the header file and change the definition of '_MUXAPI'
       - J19ChannelSendMsg & J19ChannelSendNMEAFastPacket functions send now variable-length messages
       - Fix a closing issue after opening a J1939 channel
       - Fix a closing issue after opening a PCI card
       - Fix a memory leak when scanning the USB bus fails (Exxotest v1.x.x/v2.x.x drivers)
       - Fix the CARB mode of the Iso14230SendMsg function 

        V 6.31 11/12/2014 Nouredine BOUNEMOURA
       - Fix the alignment of structures for the 32-bit version of the library
       - Fix the handling of a LIN IFR by a 1.x master (PCI boards)
       - Fix the packet reassembly algorithm of the reading thread

        V 6.32 12/12/2014 Nouredine BOUNEMOURA
       - Fix the return value of MuxGetHardwareID function

        V 6.33 01/07/2015 Nouredine BOUNEMOURA
       - Change packing alignment value for 64-bit applications
       - Add the location ID information for each item in the USB card list
       - Fix some output parameters in the functions MuxPciGetCardInfo & MuxUsbGetCardInfo
       - Fix dependency problems between the functions MuxPciCountCards, MuxUsbCountCards, MuxEthCountCards & MuxOpen
       - Add the device instance ID to the multistring value returned by the function MuxGetHardwareID
       - ISO15765-2: fix an issue for the parameter N_AE when using mixed addressing
       - ISO15765-2: mixed addressing is now supported for 11 bit CAN identifier
       - ISO15765-2: add a new spy mode working on a per-channel basis

        V 6.34 02/09/2015 Nouredine BOUNEMOURA
       - Fix an issue when calling the function USBLIB_GetDeviceList more than seven times
       - Update some strings used for the last-error code

        V 6.35 13/11/2015 Nouredine BOUNEMOURA
       - Fix an issue when mixing multiplexed and non multiplexed USB cards
       - Change the declaration specifier and calling convention for the GNU compiler

        V 6.36 15/06/2016 Benjamin TERRIER / Nouredine BOUNEMOURA
       - Fix the value of the wN_Br parameter in the NwcChannelParam function (for ethernet cards)
       - Fix the formatting of some error strings
       - Add some missing J1939 functions
       - Add a new API to the J1939 protocol stack
       - Add the ability to use the ISO L line as a generic output (USB_MUX_DIAG_V2)
       - Change to MuxEthCountCards: support of the opening of multiple emulated cards having the same IP address
       - Change the C standard integer types to fixed-width integer types in order to ease the use of the library with other languages
       - Remove the calling to the PeekMessage function because of an issue with Qt

	   V 6.37 14/10/2016 Benjamin TERRIER / Alexandre GAMBIER
	   - Fix AdminGetLicenceData() to make it work properly with all devices

	   V 6.38 24/10/2016 Cyril BOJIDAROVITCH
       - Add USBLIB_GetHardwareID	

	   V6.39 08/02/2017 Cyril BOJIDAROVITCH
		- Correct bug in USBLIB_GetHardwareID

		V6.40 --/03/2017 Benjamin TERRIER
		- Fix exported symbols in MuxDLL.lib

		V6.50 20/09/2017 Cyril BOJIDAROVITCH
		- Fix exported symbols (MuxUsbGetCardInfo) in MuxDLL.lib
	   
	   V6.51 22/01/2018 Alexandre Gambier
	   - Fix AdminGetLicenceData()

	   V6.52 05/02/2018 Alexandre Gambier
	   - Force wHandleMsg to zero for the following functions (Ethernet and USB):
	     + LinConfigPeriodic()
		 + LinConfigPeriodicList()
		 + LinSendMsg()
		 + CanConfigPeriodic()
		 + CanConfigPeriodicList()
		 + CanSendMsg()

	   V6.53 05/12/2018 Alexandre Gambier
	   - Fix USBLIB_GetHardwareID() so it returns the same value as MuxGetHardwareID()
	   - Add function USBLIB_GetDeviceIDs()

	   V6.54 05/12/2018 Alexandre Gambier
	   - Fix MuxGetHardwareID()

	   V6.55 22/01/2020 David Provent
	   - Fix internal bug for usbMaj.
*/

#ifndef _REFMUX_H_
#define _REFMUX_H_
 
//	Dont forget to call MuxGetBuildNumber function to get information about the timestamp of the build
#define MUX_DLL_VERSION     0x654          // DLL version

// Define fixed size integer types:
// - Rely on stdint.h if possible.
// - Use typedef as a fallback.
// Notes:
// - The typedef should be enough for x86 and x86_64. For int32_t and uint32_t
//   we use "int" and not "long int" as the later is 64 bit long on LP64
//   platforms (e.g. gcc)
// - Borland as of XE3 does not support "System::Int64", so we do not make a
//   special case to use its types. However, it defines "int8_t" so we have to
//   skip it.
#if ((defined(__SUNPRO_C) && __SUNPRO_C >= 0x570) || (defined(_MSC_VER) && _MSC_VER >= 1600) || (defined(__STDC__) && __STDC__ && defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L) || (defined (__WATCOMC__) && (defined (_STDINT_H_INCLUDED) || __WATCOMC__ >= 1250)) || (defined(__GNUC__) && (__GNUC__ > 3 || defined(_STDINT_H) || defined(_STDINT_H_) || defined (__UINT_FAST64_TYPE__)) ))
#include <stdint.h>
#else
	typedef unsigned char uint8_t;
	typedef unsigned short uint16_t;
	typedef unsigned int uint32_t;
	typedef unsigned long long uint64_t;
#ifndef __BORLANDC__
	typedef signed char int8_t;
#endif
	typedef short int16_t;
	typedef int int32_t;
	typedef long long int64_t;
#endif

#if defined(_WIN64) || defined(_LP64) || defined(__LP64__)
#pragma pack(push,8) 	  			        // 8-byte alignment
#else
#pragma pack(push,2) 	  			        // 2-byte alignment: MSVC & Borland
#endif

#ifdef  __BORLANDC__
#pragma option push -b                      // Treat enums on 4 bytes
#endif

#ifdef LINUX
#ifndef INFINITE
	#define	INFINITE		-1			// Infinite time out
#endif	// INFINITE
#endif	// LINUX

#ifdef MUX_EXPORT_DLL
	#ifndef LINUX
		#define _MUXSPEC __declspec(dllexport) 
		#define _MUXAPI __stdcall 
	#else
		#define _MUXSPEC
		#define _MUXAPI
	#endif	// LINUX
#else
	#ifdef LINUX
		#define _MUXSPEC
		#define _MUXAPI
	#else
		#if defined __BORLANDC__
			#define _MUXSPEC __declspec(dllimport)
			#define _MUXAPI __stdcall
		#elif defined _MSC_VER
			#define _MUXSPEC __declspec(dllimport)
			#define _MUXAPI __stdcall
		#elif defined _CVI_
			#define _MUXSPEC
			#define _MUXAPI __stdcall
		#elif defined __GNUC__
			#define _MUXSPEC __declspec(dllimport)
			#define _MUXAPI __stdcall
		#endif
	#endif
#endif

/*******************************************************************************
; Macros gnrales	// Main macros
*******************************************************************************/
#ifndef _MUXALIGN
#ifndef _WIN32_WCE
#define	_MUXALIGN
#else
#define	_MUXALIGN			__unaligned
#endif
#endif

#ifndef _WIN32_WCE
#define	REFMUX_STR(s)		s
#else
#define	REFMUX_STR(s)		_T(s)		/* Convertir le (char*) en (uint16_t*) // Cast (char*) into (uint16_t*) */
#endif // _WIN32_WCE

#ifdef _UNICODE
	#define		_MUXDLLBIN_STR	L".\\bin\\muxdll.dll"
	#define		_MUXDLLCUR_STR	L".\\muxdll.dll"
	#define		_MUXDLL_STR		L"muxdll.dll"
	#define		_MUTEX_NAME		L"SERVERMUX_MUTEX_SERVERISRUNNING"
	#define		_AEBRDGBIN_STR	L".\\bin\\AEBRIDGE.dll"
	#define		_AEBRDGB_STR	L"AEBRIDGE.dll"
#else
	#ifdef UNICODE
		#define		_MUXDLLBIN_STR	L".\\bin\\muxdll.dll"
		#define		_MUXDLLCUR_STR	L".\\muxdll.dll"
		#define		_MUXDLL_STR		L"muxdll.dll"
		#define		_MUTEX_NAME		L"SERVERMUX_MUTEX_SERVERISRUNNING"
		#define		_AEBRDGBIN_STR	L".\\bin\\AEBRIDGE.dll"
		#define		_AEBRDGB_STR	L"AEBRIDGE.dll"
	#else
		#define		_MUXDLLBIN_STR	".\\bin\\muxdll.dll"
		#define		_MUXDLLCUR_STR	".\\muxdll.dll"
		#define		_MUXDLL_STR		"muxdll.dll"
		#define		_MUTEX_NAME		"SERVERMUX_MUTEX_SERVERISRUNNING"
		#define		_AEBRDGBIN_STR	".\\bin\\AEBRIDGE.dll"
		#define		_AEBRDGB_STR	"AEBRIDGE.dll"
	#endif
#endif
/*******************************************************************************
; Dclaration pour les routines gnrales // main definition
*******************************************************************************/
typedef enum
{
	STATUS_OK               			= 1,			/* OK */
	STATUS_ERR_OPEN         			= 2,			/* Erreur ouverture handle sur carte             // Denies access to board */
	STATUS_ERR_OPENKP       			= 3,			/* Erreur ouverture handle sur driver kernel     // Denies access to the kernel driver */
	STATUS_ERR_MEMORY       			= 4,			/* Erreur d'allocation mmoire                   // Not enough memory */
	STATUS_ERR_PARAM        			= 5,			/* Erreur de paramtre d'entre                  // Input parameters error */
	STATUS_ERR_SEQUENCE     			= 6,			/* Erreur d'enchainement des commandes           // Sequence error */
	STATUS_ERR_BANK         			= 7,			/* Erreur d'allocation de banc mmoire           // Denies access to Memory bank */
	STATUS_ERR_INTERRUPT    			= 8,			/* Erreur d'autorisation des ITs                 // Error while allocating interrupt */
	STATUS_ERR_MSGEXCEED    			= 9,			/* Erreur nombre de messages dclar trop grand  // Message count has exceeded the maximum */
	STATUS_ERR_MSGEXIST     			= 10,			/* Erreur l'id dclar existe dj               // Identifier has already been declared */
	STATUS_ERR_MSGSVC       			= 11,			/* Service non support                          // Service message is not supported */
	STATUS_ERR_MSGBUSY      			= 12,			/* Erreur message en cours de transmission       // Message is already transmitted (buffer mode only) */
	STATUS_ERR_TSSOVER      			= 13,			/* Erreur dpassement mmoire ou canaux du TSS   // Memory or channel count has reached */
	STATUS_ERR_HANDLE       			= 14,			/* Erreur handle de communication                // Invalid message handle */
	STATUS_ERR_FIFOFULL     			= 15,			/* Fifo de transmission pleine                   // Tx FIFO is full */
	STATUS_ERR_BUSOFF       			= 16,			/* Erreur bus dconnect                         // CAN bus off */
	STATUS_ERR_FILEDLL      			= 17,			/* Erreur de fichier DLLs                        // DLL file error */
	STATUS_ERR_OPENDLL      			= 18,			/* Erreur d'initialisation des DLLs              // DLL call error */
	STATUS_ERR_BOARD        			= 19,			/* Type de carte non support                    // Board is not supported by DLL */
	STATUS_WARNING          			= 20,			/* Avertissement, fonction non supporte         // Warning - function is not supported */
	STATUS_ERR_TO_USB       			= 21,			/* Erreur de communication sur l'USB             // USB communication error */
	STATUS_ERR_SEQ_USB      			= 22,			/* Erreur de communication sur l'USB             // USB communication error */
	STATUS_ERR_PARAM_USB    			= 23,			/* Erreur de communication sur l'USB             // USB communication error */
	STATUS_ERR_FLASH        			= 24,			/* Erreur de programmation de la flash           // USB flash error */
#ifdef _WIN32_WCE	// Under Windows CE the STATUS_NOT_SUPPORTED is already defined
	STATUS_UNSUPPORTED      			= 25,			/* Requte non supporte                         // Not supported function */
#else
	STATUS_NOT_SUPPORTED    			= 25,			/* Requte non supporte                         // Not supported function */
#endif	//  _WIN32_WCE
	STATUS_ERR_REGISTER     			= 26,			/* Requte non enregistre                       // No registered function */
	STATUS_ERR_NWC_OPEN     			= 27,			/* Erreur d'ouverture du canal NWC               // NWC channel open error */
	STATUS_ERR_NWC_BUSY     			= 28,			/* Erreur d'ouverture du canal NWC               // NWC channel open error */
	STATUS_ERR_ALREADY_OPEN 			= 29,			/* Erreur device dj ouvert                     // Device already open error */
	STATUS_ERR_FUNCTION     			= 31,			/* Erreur sur la fonction                        // Function error */
	STATUS_ERR_ALIGNMENT    			= 32,			/* Erreur d'alignement                           // alignment error */
	STATUS_ERR_SERVERNOTLOADED			= 33,			/* Le serveur n'est pas charg                   // Server is not loaded */
	STATUS_ERR_TIMEOUT					= 34,			/* Timeout atteint                               // Timeout has occured */
	STATUS_ERR_LICENCE					= 35,			/*	La licence de prt est expire				//		*/
	STATUS_ERR_TOOMANYFILEOPENED		= 36,			/* Trop de ficher sont ouvert sur la flash		// Too many files are opened on the flash */
	STATUS_ERR_FILEACCESS				= 37,			/* Impossible d'accder au fichier				// Can not access to file */
	STATUS_ERR_FILENOTOPENED			= 38,			/* Fichier non ouvert							// File not opened */
	STATUS_ERR_NOCFCARD 				= 39,			/*	Pas de carte compact flash					// No compactcard flash */
	STATUS_CANCELLED 					= 40,			/*	Annule									//	Cancelled */
	STATUS_COMMANDE_IN_PROGRESS			= 41,			/* Commande en progression */
	STATUS_COMMANDE_ALREADY_OPENED 		= 42,  			/* La commande a dj en cours... */
    STATUS_ERR_CF_FORMAT				= 43,			/* Erreur lors du formatage de la carte compactflash */
	STATUS_ERR_SERVER_TIMEOUT			= 44,			/* Timeout en communicant avec le serveur */
	STATUS_ERR_SERVER_BUSY				= 45,			/* Le serveur semble occup */
	STATUS_ERR_SERVER_FCTNOTSUPPORTED 	= 46,			/* Fonction non support en mode serveur */
	STATUS_ERR_NWL_OPEN					= 47,			/* Erreur d'ouverture du canal NWL               // NWL channel open error */
	STATUS_ERR_NWL_BUSY					= 48,			/* Erreur d'ouverture du canal NWL               // NWL channel open error */
	STATUS_ERR_NO_DEVICE				= 49,			/* Pas de priphrique connect					//	No connected devices */
	STATUS_ERR_DEVICE_NOT_OPENED		= 50,			/* Priphrique non ouvert					//	Device not opened */
  	STATUS_FILE_FOUND					= 51,			/* Fichier trouv (enregisteur)            // File Found (datalogger)*/
	STATUS_ERR_CFCARD_BUSY	= 52			/* Carte en cours d'utilisation (enregisteur)            // CF Card busy (datalogger)*/

} tMuxStatus;

typedef enum
{
	MODE_APPLI    = 0,                      /* Mode application                         // Application mode */
	MODE_KERNEL   = 1,                      /* Mode kernel                              // Kernel mode */
	MODE_DEMO     = 2,                      /* Mode dmonstration (sans carte)          // Demonstration mode (without board) */
	MODE_MUXTRACE = 3                       /* Mode MuxTrace                            // MuxTrace mode */
} tMuxMode;

typedef struct
{
    tMuxMode        eMuxMode;           /* Mode de fonctionnement interne               // Internal mode */
    uint16_t  wBusInterface;      /* Mode d'interface (Individuel ou group)      // Interface mode */
} tMuxConfigMode;

typedef struct
{
    uint32_t   dwUSBPacketCount;   /* Nombre de paquet USB recu                    // USB transfer packet count */
    uint32_t   dwUSBByteCount;     /* Nbre d'octet USB recu                        // USB transfer byte count  */
} tMuxInternalInfo;

typedef enum
{
	EVENT_EMPTY					=   0x0,      /* Pas d'vnement prsent                                    // No event*/
	EVENT_ANA_INPUT				=   0x0D,	  /* information entr ANA										// Input ANA information */
    EVENT_PWM_INPUT				=   0x0E,     /* Informations entre PWM                                    // Input PWM information */
    EVENT_IO_INPUT				=   0x0F,     /* Changement d'tat d'une entre                             // Input edge detcted */
	EVENT_CAN_MSGTX				=   0x10,     /* Fin de transmission                                        // End of transmission */
    EVENT_CAN_MSGRX				=   0x11,     /* Rception                                                  // Message has been received */
    EVENT_CAN_ERROR				=   0x12,     /* Erreur bus                                                 // Bus error */
    EVENT_CAN_BUSCHANGE			=   0x13,     /* Chgt d'tat du comp. (active,passive,busoff)               // Chip state has chaged active or passive error ou bus off*/
    EVENT_CAN_BUSLOAD			=   0x14,     /* Information charge bus courante                            // Bus load information  */
    EVENT_VAN_MSGTX				=   0x20,     /* Fin de transmission                                        // End of transmission */
	EVENT_VAN_MSGRX				=   0x21,     /* Rception                                                  // Message has been received */
    EVENT_VAN_MSGTXERR			=   0x22,     /* Fin de transmission en erreur                              // End of transmission with error */
    EVENT_VAN_MSGRXERR			=   0x23,     /* Erreur de rception                                        // Rx error */
    EVENT_VAN_BUSCHANGE			=   0x24,     /* Changement de la ligne de rception                        // Communication indication  */
    EVENT_VAN_BUSLOAD			=   0x25,     /* Information charge bus courante                            // Bus load information  */
	EVENT_ISO_MSGTX				=   0x30,     /* Fin de transmission                                        // End of transmission */
	EVENT_ISO_MSGRX				=   0x31,     /* Rception                                                  // Message has been received */
    EVENT_ISO_MSGTXERR			=   0x32,     /* Fin de transmission en erreur                              // End of transmission with error */
    EVENT_ISO_MSGRXERR			=   0x33,     /* Erreur de rception                                        // Rx error */
    EVENT_ISO_BUSLOAD			=   0x34,     /* Information charge bus courante                            // Bus load information  */
    EVENT_ISO_ERROR				=   0x35,     /* Erreur bus                                                 // Serial communication error */
    EVENT_ISO_RXCHAR			=   0x36,     /* Rception d'un caractre                                   // Character has been received */
    EVENT_LIN_MSGTX				=   0x40,     /* Fin de transmission                                        // End of transmission */
    EVENT_LIN_MSGRX				=   0x41,     /* Rception                                                  // Message has been received */
    EVENT_LIN_MSGTXERR			=   0x42,     /* Fin de transmission en erreur                              // End of transmission with error */
    EVENT_LIN_MSGRXERR			=   0x43,     /* Erreur de rception                                        // Rx error */
    EVENT_LIN_BUSCHANGE			=   0x44,     /* Changement do contrleur                                   // Communication indication  */
    EVENT_LIN_BUSLOAD			=   0x45,     /* Information charge bus courante                            // Bus load information  */
    EVENT_NWC_MSGTX				=   0x50,     /* Fin de transmission                                        // End of transmission */
    EVENT_NWC_MSGRX				=   0x51,     /* Rception                                                  // Message has been received */
    EVENT_NWC_MSGTXERR			=   0x52,     /* Fin de transmission en erreur                              // End of transmission with error */
    EVENT_NWC_MSGRXERR			=   0x53,     /* Erreur de rception                                        // Rx error */
    EVENT_NWC_MSGRXFF			=   0x54,     /* Rception d'une FF                                         // First frame indication */
    EVENT_NWC_MSGTXFF			=   0x55,     /* Dbut de transmission d'une FF                             // First frame start of transmission */
	EVENT_J1587_MSGTX			=   0x60,     /* Fin de transmission                                        // End of transmission */
	EVENT_J1587_MSGRX			=   0x61,     /* Rception                                                  // Message has been received */
    EVENT_J1587_BUSCHANGE		=   0x62,     /* Changement do contrleur                                   // Communication indication  */
    EVENT_J1587_BUSLOAD			=   0x63,     /* Information charge bus courante                            // Bus load information  */
    EVENT_NMEA0183_MSGTX		=   0x70,     /* Fin de transmission                                        // End of transmission */
    EVENT_NMEA0183_MSGRX		=   0x71,     /* Rception                                                  // Message has been received */
    EVENT_NMEA0183_MSGTXERR		=   0x72,     /* Fin de transmission en erreur                              // End of transmission with error */
	EVENT_NMEA0183_MSGRXERR		=   0x73,     /* Erreur de rception                                        // Rx error */
    EVENT_NMEA0183_BUSCHANGE	=   0x74,     /* Changement do contrleur                                   // Communication indication  */
    EVENT_NMEA0183_BUSLOAD		=   0x75,     /* Information charge bus courante                            // Bus load information  */
	EVENT_WINCE_BATTSTATE		=	0x80,     /* Information sur l'tat de la batterie                      // Battery state information */
	EVENT_WINCE_POWERDOWN		=   0x81,     /* L'alimentation passe en veille                             // Power is going down */
	EVENT_WINCE_POWERRESUME		=	0x82,     /* L'alimentation se rveille                                 // Power is going up */
	EVENT_WINCE_DRIVERUNLOADED	=	0x83,     /* Le driver a t dcharg, il faut recharger la muxdll.dll  // Driver has been unload, the muxdll.dll file must be fully reload */
	EVENT_J18_MSGTX             =   0x90,     /* Fin de transmission                          // End of transmission */
    EVENT_J18_MSGRX             =   0x91,     /* Rception                                    // Message has been received */
    EVENT_J18_MSGRXERR          =   0x92,     /* Erreur                                       // Error */
    EVENT_PRY_MSGTX             =   0xA0,     /* Fin de transmission                          // End of transmission */
    EVENT_PRY_MSGRX             =   0xA1,     /* Rception                                    // Message has been received */
	EVENT_NWL_MSGTX				=   0xB0,     /* Fin de transmission                          // End of transmission */
	EVENT_NWL_MSGRX				=   0xB1,     /* Rception                                    // Message has been received */
	EVENT_NWL_MSGTXERR			=   0xB2,     /* Fin de transmission en erreur                // End of transmission with error */
	EVENT_NWL_MSGRXERR			=   0xB3,     /* Erreur de rception                          // Rx error */
	EVENT_NWL_MSGRXFF			=   0xB4,     /* Rception d'une FF                           // First frame indication */
	EVENT_NWL_MSGTXFF			=   0xB5,     /* Dbut de transmission d'une FF               // First frame start of transmission */
	EVENT_J19_MSGTX				=	0xC0,     /* Fin de transmission                                        // End of transmission */
	EVENT_J19_MSGRX				=	0xC1,     /* Rception                                                  // Message has been received */
	EVENT_J19_MSGTXERR			=	0xC2,     /* Fin de transmission en erreur                              // End of transmission with error */
	EVENT_J19_MSGRXERR			=	0xC3,     /* Erreur de rception                                        // Rx error */
	EVENT_J19_MSGRXFF			=	0xC4,     /* Dbut de transmission d'une FF                             // First frame start of transmission */
	EVENT_J19_MSGTXFF			=	0xC5,     /* Dbut de transmission d'une FF                             // First frame start of transmission */
    EVENT_TIMER					=   0x100,    /* Timer applicatif                                           // Application timer */
    EVENT_TIMEERROR				=   0x101,    /* Information perte d'interruption timer                     // Time error detection */
    EVENT_TRIGGER				=   0x200,	  /* Evnement trigger							                // Trigger event */
	EVENT_INTERNAL				=   0x201,	  /* Evnement interne							                // Internal event */
	EVENT_SYS_USBDEVICELOST		=	0x300,		/*	On a perdu la com avec le priphrique USB			//	We lost the usb device link */
	EVENT_SYS_WIFIDEVICELOST	=	0x301,		/*	On a perdu la com avec le priphrique WIFI			//	We lost the WIFI device link */
	EVENT_FIFO_OVF				=   0x8000,		/* Bit indiquant une perte de message                         // Message lost cause fifo overflow */
} tMuxTypeEvent;

typedef enum
{
	xxx_MUX_UNREACHABLE	 	=   0xFC,           //	Carte non accessible                         //	Card unreachable
	xxx_MUX_SIMU	 		=   0xFD,           //	Simulation d'une carte MUX                   //	Card simulator
	xxx_MUX_UNKNOWN	 		=   0xFE,           //	Inconnu                                      //	Unknown
	PCI_MUX_DEMO			=   0xFF,           //	Pas de materiel                              // No card
	PCI_MUX_C3V2L			=   0x00,           //	Carte PCI 1 CAN, 3 VAN et 2 LIN/ISO9141      // PCI board 1 CAN, 3 VAN and 2 ISO9141/LIN channels
	PCI_MUX_CVL				=   0x01,           //	Carte PCI 1 CAN, 1 VAN et 1 LIN/ISO9141      // PCI board 1 CAN, 1 VAN and 1 ISO9141/LIN channels
	PCI_MUX_CAN				=   0x02,           //	Carte PCI 1 CAN                              // PCI board 1 CAN channel
	PCI_MUX_VAN				=   0x03,           //	Carte PCI 1 VAN                              // PCI board 1 VAN channel
	PCI_MUX_MultiCAN		=   0x08,           //	V 2.0 Carte PCI 4 CAN                        // PCI board 4 CAN channels
	USB_MUX_C3VL			=   0x10,           //	Carte USB 1 CAN, 3 VAN et 1 LIN              // USB board 1 CAN, 3 VAN and 1 LIN channel
	USB_CL500				=   0x11,           //	Carte USB CL500  1 CAN et 1 ISO9141    	     // USB board 1 CAN, 1 ISO9141 channel
	USB_MUX_CL				=   0x12,           //	Carte USB 1 CAN et 1 LIN                     // USB board 1 CAN channel and 1 LIN channel
	USB_OBD_EX1				=   0x13,           //	Carte USB OBD-EX1  1 CAN et 1 ISO9141 	     // USB board 1 CAN, 1 ISO9141 channel
	USB_CM					=   0x14,           //	Carte USB CM       1 CAN et 1 ISO9141 	     // USB board 1 CAN, 1 ISO9141 channel
	USB_MUX_4C2L			=   0x18,           //	Carte USB 4 CAN et 2 LIN                     // USB board 4 CAN channels and 2 LIN channels
	USB_MUX_4C4IJ			=   0x20,           //	Carte USB 4 CAN, 4 ISO9141 et 1 J1587        // USB board 4 CAN, 4 ISO9141 and 1 J1587 channel
	USB_MUX_DIAG			=   0x21,           //	Carte USB 2 CAN, 4 ISO9141                   // USB board 2 CAN and 4 ISO9141 channels
	USB_MUX_CV32A			=   0x22,           //	Carte USB 1 CAN, 1VAN ,1 ISO9141 et 32 ANA   // USB board 1 CAN, 1 VAN, & ISO9141 channels and 32 analog channels
	USB_MUX_2C2L			=   0x23,           //	Carte USB/WIFI 2 CAN, 2 ISO9141/LIN          // USB/WIFI board 2 CAN, 2 ISO9141/LIN
	USB_MUX_DIAG_V2			=   0x24,           //	Carte USB/WIFI 2 CAN, 4 ISO9141/LIN, 2 J1850 // USB/WIFI board 2 CAN, 4 ISO9141/LIN and 2 J1850 channels
	USB_ART_10201			=   0x25,           //  Carte USB 1 CAN et 3 ISO9141                 // USB board 1 CAN, 3 ISO9141 channels */
	USB_EXXOCLIM			=   0x26,			//  EXXOClim
	USB_MUX_4C4L_FHS		=	0x28,			//	Carte USB 4 CAN, 4 ISO9141 (HighSpeed)
	USB_MUX_4C4L_MC 		=	0x29,			//	Carte USB 4 CAN, 4 ISO9141 (MixedCAN)
	USB_MUX_6C6L			=	0x2A,			//	Carte USB/ETHERNET 6 CAN 6 ISO9141/LIN
	USB_MUX_4C4L			=	0x2B,			//	Carte USB 4 CAN 4 ISO9141/LIN 				 // USB board 4 CAN 4 ISO9141/LIN
	USB_MUX_DIAG_V2_LT		=   0x2C,           //	Carte USB 1 CAN et 1 ISO9141/LIN             // USB board 1 CAN and 1 ISO9141/LIN
	USB_PID					=	0x8000			//	USB device
} tMuxHWType;


#define	MUXALIGNEMENT_8BITS_TESTVALUE		0x80
#define	MUXALIGNEMENT_16BITS_TESTVALUE		0x8000
#define	MUXALIGNEMENT_32BITS_TESTVALUE		0x80000000
#define	MUXALIGNEMENT_ENUM_TESTVALUE		STATUS_ERR_FILEDLL

typedef struct
{
	uint8_t	b8Bits;				// unsigned 8 bits value
    uint32_t   dw32Bits;			// unsigned 32 bits value
	tMuxStatus		eEnum;				// Enum type
    uint16_t	w16Bits;			// unsigned 16 bits value
} tMuxAlignment ;

typedef enum
{
	CSMODE_DISABLED	=	0,			// Client/Server is disabled
	CSMODE_ENABLED	=	1			// Client/Server is enabled
} tMuxCSMode ;

typedef struct
{
	char			szSerialNumber[ 16 ];	//	Numro de srie du produits
	char			szRefProduct[ 16 ];		//	Rfrence produit
	uint8_t	pbReserved[ 218 ];
} tMuxInformations ;

typedef enum
{
	LICLOCK_UNKNOWN					=	0,	 	//	Raison inconnu
	LICLOCK_EXPIRED					=	1,	 	//	La dure d'utilisation de la licence est expire
	LICLOCK_INVALIDTIME				=	2, 		//	L'heure du jour est fausse (on a essay de reculer les jours pour gagner du temps)
	LICLOCK_NOTYETACTIVATED			=	3, 		//	La licence n'a jamais t active
	LICLOCK_EEPROMACCESS			=	4, 		//	Erreur lors de l'accs  l'eeprom contenant les licences
	LICLOCK_CURRENTTIMEUNKNOWN		=	5, 		//	L'heure du jour est inconnue
	LICLOCK_MANUALLOCK				=	6,		//	Blocage manuel
	LICLOCK_CURRENTHOSTIDUNKNOWN	=	7,		//	L'equipement en cours est inconnu
	LICLOCK_INVALIDHOSTID			=	8		//	L'quipement associ ne correspond pas
} tMuxLicenceLock ;

typedef struct
{
	uint16_t	wHour;						//	Heure							//	Hou
	uint16_t	wMinute;					//	Minute							//	Minutes
	uint16_t	wDay;						//	Jour							//	Day
	uint16_t	wMonth;						//	Mois de 1  12					// Month from 1 to 12
	uint32_t	dwYear;						//	Anne							//	Year
} tMuxLicenceDate ;

typedef struct
{
	uint16_t 	wActivated;			//	La licence est active ?						//	Is the licence activated ?
	tMuxLicenceLock	eLock;				//	Raison si une licence n'est pas active		//	Reason why it's not activated
	tMuxLicenceDate	tFinalDate;			//	Date finale d'utilisation de la licence		//	Date when the licence will be locked (set to 0 if no date)
} tMuxLicence ;

typedef enum
{
    NO_PARITY            =   0,      /* Pas de bit de parit                         // No parity */
    ODD_PARITY             =   1,      /* Parit impaire                               // Odd parity */
    EVEN_PARITY            =   2       /* Parit paire                                 // Even parity */
} tUartParity;

typedef enum
{
    ONE_STOP_BIT             =   0,     /* 1 bit de stop                                 // 1 stop bit */
    TWO_STOP_BIT             =   1      /* 2 bits de stop                                // 2 stop bits */
} tUartStopBit;

typedef enum
{
    FIVE_DATA_BIT            =   0,     /* 5 bits de donnes                             // 5 data bits */
    SIX_DATA_BIT             =   1,     /* 6 bits de donnes                             // 6 data bits */
    SEVEN_DATA_BIT           =   2,     /* 7 bits de donnes                             // 7 data bits */
    EIGHT_DATA_BIT           =   3,     /* 8 bits de donnes                             // 8 data bits */
    NINE_DATA_BIT            =   4      /* 9 bits de donnes                             // 9 data bits */
} tUartDataBit;

typedef struct
{
	tUartParity     eParity;                /* Type de parit                               // Parity: none, even or odd */
    tUartStopBit    eStopBit;               /* Nombre de bits de stop                       // Number of stop bits */
    tUartDataBit    eDataBit;               /* Nombre de bits de donnes                    // Data bits number */
    uint32_t   dwBaudrate;             /* Vitesse du bus                               // Baudrate */
    uint16_t  wError;                 /* % d'erreur admise                            // Deviation */
    uint16_t  wReserved1;            /* Rserv pour utilisation future              // Reserved */
    uint16_t  wReserved2;            /* Rserv pour utilisation future              // Reserved */
    uint16_t  wReserved3;            /* Rserv pour utilisation future              // Reserved */
    uint16_t  wReserved4;            /* Rserv pour utilisation future              // Reserved */
} tUartConfig;

typedef struct
{
	uint16_t	wStructSize;			//	Taille de la tRTCValue	//	Size of tRTCValue
	uint16_t	wDay;					//	Jour de 1  31	//	Day from 1 to 31
	uint16_t	wMonth;					//	Mois de 1  12		//	Month from 1 to 12
	uint16_t	wYear;					//	Anne de 0  99	//	Year from 0 to 99
	uint16_t	wHour;					//	Heure de 0  23	//	Hour from 0 to 23
	uint16_t	wMinute;				//	Minute de 0  59	//	Minutes from 0 to 59
	uint16_t	wSecond;				//	Seconde de 0  59	//	Second from 0 to 59
	uint16_t	wDayOfWeek;				//	Jour de la semaine (0>dimanche, ... )	//	Day of the week (0>sunday, ...)
} tRTCValue ;

typedef struct
{
	uint32_t	ulLowPart;				//	Partie base pour le 64 bits
	uint32_t	ulHighPart;				//	Partie haute pour le 64 bits
	uint32_t	ulRealValue;			//	Datation correspondante en 100s
} TTimingValue ;

typedef struct
{
	TTimingValue	tMuxOpen;				//	Datation du dernier muxopen	//	Dating of the Last MuxOpen
} TTimings ;

//	Pointeur de fonction pour la datation personnalise	//	Pointer of function for the custom timer
typedef uint32_t ( *tMuxUserTimerFct )( void );

typedef enum 
{
	ETH_Disabled	= 0,
	ETH_Enabled		= 1
}tETHState;

/*******************************************************************************
; Routines gnrales // main functions
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif

#ifndef MUX_DYNAMIC_DLL
/* Rcupre les timings	//	Gets timings' information	*/
_MUXSPEC tMuxStatus _MUXAPI MuxGetTimings(uint16_t wCard, TTimings *ptTimings, TTimingValue *tBaseCounter );
/* Initialize la librairie sous Linux // Initialize the library under Linux */
_MUXSPEC tMuxStatus _MUXAPI MuxGlobalInit(void);
//	Dfinit une datation personnalise (mode dmo)
_MUXSPEC tMuxStatus _MUXAPI MuxSetUserTimerFct( tMuxUserTimerFct hUserTimerFct );
/* Cre un venement // Create an event object */
_MUXSPEC  void * _MUXAPI MuxCreateEvent(void);
/* Dtruit un vnement // Delete an event object */
_MUXSPEC tMuxStatus _MUXAPI MuxCloseEvent(void * hEvent);
/* Attend un vnement // Wait for an event */
_MUXSPEC tMuxStatus _MUXAPI MuxWaitOnEvent(void * hEvent, uint32_t dwMilliseconds);
/* Signal un vnement // Set an event */
_MUXSPEC tMuxStatus _MUXAPI MuxSetEvent(void * hEvent);
/* Active ou non le mode client/serveur RESERVE // Active or not the client/server mode RESERVED */
_MUXSPEC tMuxStatus _MUXAPI MuxClientServerMode(char *szUnlockKey, tMuxCSMode eCSMode);
/* Affiche les valeur contenu dans la structure afin de vrifier si les options d'alignements sont correctes	// Display all the values of the structure in order to check if the alignment options are correctly set */
_MUXSPEC tMuxStatus _MUXAPI MuxCheckAlignment(tMuxAlignment *hMuxAlignment, uint16_t wDisplayValues);
/* Retourne le nombre de cartes gres par les DLLs                         // Indicate the number of boards managed by DLL */
_MUXSPEC tMuxStatus _MUXAPI MuxCountCards(uint32_t *dwCardsCount);
/* Retourne le nombre de cartes sur le bus PCI                              // Indicate the number of PCI boards on the PCI bus */
_MUXSPEC tMuxStatus _MUXAPI MuxPciCountCards(uint32_t *dwCardsCount);
/* Retourne le nombre de cartes sur le bus USB                              // Indicate the number of USB devices USB bus */
_MUXSPEC tMuxStatus _MUXAPI MuxUsbCountCards(uint32_t *dwCardsCount);
/* Retourne le nombre de cartes sur le rseau ethernet							// Indicate the number of eth boards on the ETH network */
_MUXSPEC tMuxStatus _MUXAPI MuxEthCountCards(uint32_t *dwCardsCount);
/* Retourne les informations concernant la carte PCI                        // Give information about the PCI board */
_MUXSPEC tMuxStatus _MUXAPI MuxPciGetCardInfo(uint16_t wCard, uint32_t *dwCardBus, uint32_t *dwCardSlot, uint32_t *dwCardInfo);
/* Retourne les informations concernant la carte USB                        // Give information about the USB device */
_MUXSPEC tMuxStatus _MUXAPI MuxUsbGetCardInfo(uint16_t wCard, uint32_t *dwHubNum, uint32_t *dwPortNum, uint32_t *dwSerialNum, uint32_t *dwDeviceAddress, uint32_t *dwProductID, uint32_t *dwUniqueId);
/* Retourne les informations concernant la carte Ethernet                   // Give information about the ETH device */
_MUXSPEC tMuxStatus _MUXAPI MuxEthGetCardInfo(uint16_t wCard, uint8_t *bInfo, uint16_t *wSize);
/* Initialise les variable interne de la carte                              // Init. internal driver state and variables */
_MUXSPEC tMuxStatus _MUXAPI MuxInit(uint16_t wCard);
/* Retourne un handle de communication avec la carte                        // Return an handle to communicate with board */
_MUXSPEC tMuxStatus _MUXAPI MuxOpen(uint16_t wCard, tMuxConfigMode *hMuxConfigMode);
/* Retourne les informations concernant le logiciel                         // Give version informations */
_MUXSPEC tMuxStatus _MUXAPI MuxGetVersion(uint16_t wCard,uint32_t *dwVersionDll,uint32_t *dwVersionDriver,uint32_t *dwVersionKernel, tMuxHWType *eNumHWType);
/* Retourne la description de la carte en cours	// Give device description */
_MUXSPEC tMuxStatus _MUXAPI MuxGetDescription( uint16_t wCard, char *szDescription );
/* Retourne le numro de srie												// Get the serial number	*/
_MUXSPEC tMuxStatus _MUXAPI MuxGetInformations( uint16_t wCard, tMuxInformations *tInfos );
/* Fermeture du handle de communication avec la carte                       // Close the handle */
_MUXSPEC tMuxStatus _MUXAPI MuxClose(uint16_t wCard);
/* Rcupration d'une chaine de compte rendu d'erreur                       // Return a string which indicate the last error message */
_MUXSPEC tMuxStatus _MUXAPI MuxGetLastErrorString(char **pString);
/* Code de protection de la carte                                           // Get protected code */
_MUXSPEC tMuxStatus _MUXAPI MuxGetProtectedCode(uint16_t wCard, uint16_t *wCode);
/* Tlchargement USB                                                       // Download code */
_MUXSPEC tMuxStatus _MUXAPI MuxUsbDownload(uint16_t wCard, char *pcFileName, uint16_t wMode);
/* Rserv                                                                  // Reserved, do not used */
_MUXSPEC tMuxStatus _MUXAPI MuxGetInternalInfo(uint16_t wCard, tMuxInternalInfo *pstMuxInternalInfo);
/* Connaitre si une licence est active ou non								// Get if a licence is active or not */
_MUXSPEC tMuxStatus _MUXAPI MuxIsLicenceActive( uint16_t wCard, uint16_t wLicenceID, tMuxLicence *tLic );
/* Active la recherche des product ID */
_MUXSPEC tMuxStatus _MUXAPI MuxSetProductIDMode( uint16_t wEnabled );
/* Rcupre le n du build number au format AAMMJJHHMMSS Get the build number using format YYMMDDHHMMSS */
_MUXSPEC tMuxStatus _MUXAPI MuxGetBuildNumber( uint32_t *pdwBN, char *szBN );
/* Rcupre l'heure de l'horloge embarque // Read the timestamp of the embedded clock */
_MUXSPEC tMuxStatus _MUXAPI MuxGetRTCValue( uint16_t wCard, tRTCValue *tValue );
/* Dfini l'heure de l'horloge embarque // Set the timestamp of the embedded clock */
_MUXSPEC tMuxStatus _MUXAPI MuxSetRTCValue( uint16_t wCard, tRTCValue *tValue );
/* Reset un pipe // Reset a pipe */
_MUXSPEC tMuxStatus _MUXAPI MuxUsbResetPipe( uint16_t wCard, uint16_t wPipeNumber );
/* recupere le HARDWARE ID de la prise. //get peripheral HARDWARE ID*/
_MUXSPEC tMuxStatus _MUXAPI MuxGetHardwareID(uint16_t wCard, char *szHardwareID, uint32_t dwSize);
/* active ou pas le support de l'ETHERNET. // set or not ETHERNET support. */
_MUXSPEC tMuxStatus _MUXAPI MuxSetEthernet ( tETHState hEthState );
/* Rcupre l'etat de l'ETHERNET. // read ETHERNET State. */
_MUXSPEC tMuxStatus _MUXAPI MuxGetEthernet ( tETHState *hEthState );

#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tMuxGetTimings )( uint16_t wCard, TTimings *ptTimings, TTimingValue *tBaseCounter );
typedef tMuxStatus (__stdcall * tMuxGlobalInit)(void);
typedef tMuxStatus (__stdcall * tMuxSetUserTimerFct )( tMuxUserTimerFct hUserTimerFct );
typedef void *     (__stdcall * tMuxCreateEvent)(void);
typedef tMuxStatus (__stdcall * tMuxCloseEvent)(void * hEvent);
typedef tMuxStatus (__stdcall * tMuxWaitOnEvent)(void * hEvent, uint32_t dwMilliseconds);
typedef tMuxStatus (__stdcall * tMuxSetEvent)(void * hEvent);
typedef tMuxStatus (__stdcall * tMuxClientServerMode)(char *szUnlockKey, tMuxCSMode eCSMode);
typedef tMuxStatus (__stdcall * tMuxCheckAlignment)(tMuxAlignment *hMuxAlignment, uint16_t wDisplayValues);
typedef tMuxStatus (__stdcall * tMuxCountCards)(uint32_t *dwCardsCount);
typedef tMuxStatus (__stdcall * tMuxPciCountCards)(uint32_t *dwCardsCount);
typedef tMuxStatus (__stdcall * tMuxUsbCountCards)(uint32_t *dwCardsCount);
typedef tMuxStatus (__stdcall * tMuxEthCountCards)(uint32_t *dwCardsCount);
typedef tMuxStatus (__stdcall * tMuxPciGetCardInfo)(uint16_t wCard, uint32_t *dwCardBus, uint32_t *dwCardSlot, uint32_t *dwCardInfo);
typedef tMuxStatus (__stdcall * tMuxUsbGetCardInfo)(uint16_t wCard, uint32_t *dwHubNum, uint32_t *dwPortNum, uint32_t *dwSerialNum, uint32_t *dwDeviceAddress, uint32_t *dwCardInfo, uint32_t *dwUniqueId);
typedef tMuxStatus (__stdcall * tMuxEthGetCardInfo)(uint16_t wCard, uint8_t *bInfo, uint16_t *wSize);
typedef tMuxStatus (__stdcall * tMuxInit)(uint16_t wCard);
typedef tMuxStatus (__stdcall * tMuxOpen)(uint16_t wCard, tMuxConfigMode *hMuxConfigMode);
typedef tMuxStatus (__stdcall * tMuxGetVersion)(uint16_t wCard,uint32_t *dwVersionDll,uint32_t *dwVersionDriver,uint32_t *dwVersionKernel, tMuxHWType *eNumHWType);
typedef tMuxStatus (__stdcall * tMuxGetDescription)( uint16_t wCard, char *szDescription );
typedef tMuxStatus (__stdcall * tMuxGetInformations)( uint16_t wCard, tMuxInformations *tInfos );
typedef tMuxStatus (__stdcall * tMuxClose)(uint16_t wCard);
typedef tMuxStatus (__stdcall * tMuxGetLastErrorString)(char **pString);
typedef tMuxStatus (__stdcall * tMuxGetProtectedCode)(uint16_t wCard, uint16_t *wCode);
typedef tMuxStatus (__stdcall * tMuxUsbDownload)(uint16_t wCard, char *pcFileName, uint16_t wMode);
typedef tMuxStatus (__stdcall * tMuxGetInternalInfo)(uint16_t wCard, tMuxInternalInfo *pstMuxInternalInfo);
typedef tMuxStatus (__stdcall * tMuxIsLicenceActive)( uint16_t wCard, uint16_t wLicenceID, tMuxLicence *tLic );
typedef tMuxStatus (__stdcall * tMuxSetProductIDMode )( uint16_t wEnabled );
typedef tMuxStatus (__stdcall * tMuxGetBuildNumber )( uint32_t *pdwBN, char *szBN );
typedef tMuxStatus (__stdcall * tMuxGetRTCValue )( uint16_t wCard, tRTCValue *tValue );
typedef tMuxStatus (__stdcall * tMuxSetRTCValue )( uint16_t wCard, tRTCValue *tValue );
typedef tMuxStatus (__stdcall * tMuxUsbResetPipe )( uint16_t wCard, uint16_t wPipeNumber );
typedef tMuxStatus (__stdcall * tMuxGetHardwareID)(uint16_t wCard, char *szHardwareID, uint32_t dwSize);
typedef tMuxStatus (__stdcall * tMuxSetEthernet) ( tETHState hEthState );
typedef tMuxStatus (__stdcall * tMuxGetEthernet) ( tETHState hEthState );
#endif
#ifdef __cplusplus
	}
#endif

/*******************************************************************************
; Routines d'administration des cartes // USB devices setup function
*******************************************************************************/
#define ADMIN_MAX_DATA		512
typedef struct
{
	uint8_t	bData[ ADMIN_MAX_DATA ];		// Donnes de configuration		// Setup data
	uint16_t	wDataLen;						// Taille des donnes			// Setup data length
} tAdminConfig ;

#ifdef __cplusplus
	extern "C" {
#endif

#ifndef MUX_DYNAMIC_DLL
// Ouvre une session d'administration	// Open a administration session
_MUXSPEC tMuxStatus _MUXAPI AdminOpenSession( uint16_t wCard, uint8_t *szAccessKey, uint8_t *szUnlockKey );
// Ecrit une configuration	// Write a setup buffer
_MUXSPEC tMuxStatus _MUXAPI AdminWriteConfig( uint16_t wCard, tAdminConfig *tConfig );
// Lit une configuration	// Read a setup buffer
_MUXSPEC tMuxStatus _MUXAPI AdminReadConfig( uint16_t wCard, tAdminConfig *tConfig );
//	Lit le nombre de licence de max pouvant tre gr par la carte	//	Get how many licence can be manage by the device
_MUXSPEC tMuxStatus _MUXAPI AdminGetLicenceCount( uint16_t wCard, uint16_t *pwLicenceCount );
//	Lit la liste des licences	//	Read licences config
_MUXSPEC tMuxStatus _MUXAPI AdminReadLicences( uint16_t wCard, void *pBuffer, uint16_t *pwBufferLen );
//	Ecrit la liste des licences	//	Write licences config
_MUXSPEC tMuxStatus _MUXAPI AdminWriteLicences( uint16_t wCard, void *pBuffer, uint16_t wBufferLen );
//	Lit les donnes d'une licence	//	Read data of a licence
_MUXSPEC tMuxStatus _MUXAPI AdminGetLicenceData( uint16_t wCard, uint16_t wLicenceID, void *pBuffer, uint16_t *pwBufferLen );
//	Ecrit les donnes d'une licence	//	Write data of a licence
_MUXSPEC tMuxStatus _MUXAPI AdminSetLicenceData( uint16_t wCard, uint16_t wLicenceID, void *pBuffer, uint16_t wBufferLen );
//	Lit les donnes des licences	//	Read licences data
_MUXSPEC tMuxStatus _MUXAPI AdminReadLicencesData( uint16_t wCard, void *pBuffer, uint16_t *pwBufferLen );
//	Ecrit les donnes des licences	//	Write licenses data
_MUXSPEC tMuxStatus _MUXAPI AdminWriteLicencesData( uint16_t wCard, void *pBuffer, uint16_t wBufferLen );
#else
// Ouvre une session d'administration	// Open a administration session
typedef tMuxStatus (__stdcall * tAdminOpenSession)( uint16_t wCard, uint8_t *szAccessKey, uint8_t *szUnlockKey );
// Ecrit une configuration	// Write a setup buffer
typedef tMuxStatus (__stdcall * tAdminWriteConfig)( uint16_t wCard, tAdminConfig *tConfig );
// Lit une configuration	// Read a setup buffer
typedef tMuxStatus (__stdcall * tAdminReadConfig)( uint16_t wCard, tAdminConfig *tConfig );
//	Lit le nombre de licence de max pouvant tre gr par la carte	//	Get how many licence can be manage by the device
typedef tMuxStatus (__stdcall * tAdminGetLicenceCount)( uint16_t wCard, uint16_t *pwLicenceCount );
//	Lit la liste des licences	//	Read licences config
typedef tMuxStatus (__stdcall * tAdminReadLicences)( uint16_t wCard, void *pBuffer, uint16_t *pwBufferLen );
//	Ecrit la liste des licences	//	Write licences config
typedef tMuxStatus (__stdcall * tAdminWriteLicences)( uint16_t wCard, void *pBuffer, uint16_t wBufferLen );
//	Lit les donnes d'une licence	//	Read data of a licence
typedef tMuxStatus (__stdcall * tAdminGetLicenceData)( uint16_t wCard, uint16_t wLicenceID, void *pBuffer, uint16_t *pwBufferLen );
//	Ecrit les donnes d'une licence	//	Write data of a licence
typedef tMuxStatus (__stdcall * tAdminSetLicenceData)( uint16_t wCard, uint16_t wLicenceID, void *pBuffer, uint16_t wBufferLen );
//	Lit les donnes des licences	//	Read licences data
typedef tMuxStatus (__stdcall * tAdminReadLicencesData)( uint16_t wCard, void *pBuffer, uint16_t *pwBufferLen );
//	Ecrit les donnes des licences	//	Write licences data
typedef tMuxStatus (__stdcall * tAdminWriteLicencesData)( uint16_t wCard, void *pBuffer, uint16_t wBufferLen );
#endif
#ifdef __cplusplus
	}
#endif

/*******************************************************************************
	routine d'vnement systme	//	System Events functions
*******************************************************************************/
typedef struct _tSysEvent
{
	tMuxTypeEvent	eTypeEvent;			//	Type d'vnement		//	Event type
} tSysEvent ;

#ifdef __cplusplus
	extern "C" {
#endif

#ifndef MUX_DYNAMIC_DLL
//	Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application
_MUXSPEC tMuxStatus _MUXAPI SysSetNotification( uint16_t wCard, void * hWinEvent );
//	Rcupre un venement	//	Get a event
_MUXSPEC tMuxStatus _MUXAPI SysGetEvent( uint16_t wCard, tSysEvent *hSysEvent );
#else
//	Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application
typedef tMuxStatus (__stdcall * tSysSetNotification )( uint16_t wCard, void * hWinEvent );
//	Rcupre un venement	//	Get a event
typedef tMuxStatus (__stdcall * tSysGetEvent )( uint16_t wCard, tSysEvent *hSysEvent );
#endif

#ifdef __cplusplus
	}
#endif

/*******************************************************************************
; Dclaration pour les routines CAN // CAN definitions
*******************************************************************************/
#define	CAN_MAX_DATA	        		8		/* Nbre de donnes max CAN                      // Maximum CAN data length */

#define CAN_PERIODIC_PARAM_ENABLE		1		/* Active la priodique							// Enable periodic frame */
#define CAN_PERIODIC_PARAM_DISABLE		0		/* Desactive la periodique						// Disable periodic frame */
#define CAN_PERIODIC_PARAM_WITHEVENTS	2		/* Active la remonte des vnements			// Enable the events */
#define CAN_PERIODIC_PARAM_NOEVENTS		0		/* Desactive la remonte des vnements			// Disable the events */

#define	CAN_ERROR_BITERROR				0x0000	//	Erreur de bit
#define	CAN_ERROR_FORMAT				0x0040	//	Erreur de format
#define	CAN_ERROR_STUFFING				0x0080	//	Erreur de stuffing
#define	CAN_ERROR_MISCELLANEOUS			0x00C0	//	Divers
#define	CAN_ERROR_TX					0x0000	//	Transmission
#define CAN_ERROR_RX					0x0020	//	Rception
#define	CAN_ERROR_ID20TOID21			0x0002	//	ID20 a ID21
#define	CAN_ERROR_STARTOFFRAME			0x0003	//	Start of Frame
#define	CAN_ERROR_BITSRTR				0x0004	//	Bit SRTR
#define	CAN_ERROR_BITIDE				0x0005	//	Bit IDE
#define	CAN_ERROR_ID20TOID18			0x0006	//	ID20 TO ID18
#define	CAN_ERROR_ID17TOID13			0x0007	//	ID17 TO ID 13
#define	CAN_ERROR_CRCFIELD				0x0008	//	Champ CRC
#define	CAN_ERROR_RESERVEDBIT0			0x0009	//	Bit rserv
#define	CAN_ERROR_DATAFIELD				0x000A	//	Champ DATA
#define	CAN_ERROR_DLCFIELD				0x000B	//	Champ DLC
#define	CAN_ERROR_RTRBIT				0x000C	//	CRC BIT
#define	CAN_ERROR_RESERVEDBIT1			0x000D	//	Bit rserv
#define	CAN_ERROR_ID4TOID0				0x000E	//	ID4 a ID0
#define	CAN_ERROR_ID12TOID5				0x000F	//	ID13 a ID5
#define	CAN_ERROR_ACTIVEERROR			0x0011	//	Erreur active
#define	CAN_ERROR_INTERMISSION			0x0012	//	Intermission
#define	CAN_ERROR_DOMINANTBITS			0x0013	//	Dominant bits
#define	CAN_ERROR_PASSIVEERROR			0x0016	//	Erreur passive
#define	CAN_ERROR_ERRORDELIMITER		0x0017	//	Delimiteur d'erreur
#define	CAN_ERROR_CRCDELIMITER			0x0018	//	Delimiteur CRC
#define	CAN_ERROR_ACKNOWLEDGESLOT		0x0019	//	Acquitement
#define	CAN_ERROR_ENDOFFRAME			0x001A	//	Fin de trame
#define	CAN_ERROR_ACKNOWLEDGEDELIMITER	0x001B	//	Delimiteur d'acquitement
#define	CAN_ERROR_OVERLOAD				0x001C	//	Surchage

typedef enum
{
	CAN_OPER_ANA_FIFO       =   0,      /* Mode analyse, stockage fifo                  // Analyse mode, event is stored in fifo mode */
    CAN_OPER_ANA_BUFF       =   1       /* Mode analyse, stockage buffer                // Analyse mode, event is stored in buffer mode */
} tCanOperMode;

typedef struct
{
    tCanOperMode    eCanOperMode;       /* Type d'interface avec l'application          // Operating mode with API */
    uint16_t  wFifoSize;          /* Taille de la FIFO                            // FIFO Size */
} tCanOper;

typedef enum
{
    CAN_ID_STD              =   0,      /* Identificateur standard (11 bits)            // Standard identifier */
    CAN_ID_XTD              =   1       /* Identificateur tendu (29 bits)              // Extended identifier */
} tCanTypeId;

/*ATTENTION: Ne plus utiliser cet ENUM pour la fonction CanSelectTransceiverHS         // WARNING : don't use it for CanSelectTransceiverHS function.*/
typedef enum
{
    CAN_FALSE               =   0,      /* Boolen faux                                 // FALSE */
    CAN_TRUE                =   1       /* Boolen vrai                                 // TRUE */
} tCanBoolean;
typedef enum
{
	CAN_LS                =   0,      /* CAN LOW SPEED */
	CAN_HS                =   1,      /* CAN HIGH SPEED */
	CAN_SW                =   2       /* CAN SINGLE WIRE */
} tCanType;
typedef enum
{
    CAN_SVC_TRANSMIT_DATA   =   0,      /* Transmission de donnes                      // Transmit message */
    CAN_SVC_RECEIVE_DATA    =   1,      /* Rception de donnes                         // Receive message */
    CAN_SVC_TRANSMIT_RTR    =   2,      /* Transmission de remote                       // Transmit a remote */
    CAN_SVC_RECEIVE_RTR     =   3       /* Rception de remote                          // Receive a remote */
} tCanService;
typedef enum
{
	CAN_BUS_ACTIVE          =   0,      /* Etat erreur active                           // Active error state */
    CAN_BUS_PASSIVE         =   1,      /* Etat erreur passive                          // Passive error state */
    CAN_BUS_OFF             =   2       /* Etat bus off                                 // Bus off state */
} tCanChipState;
typedef enum
{
    CAN_SLOPE_CONTROL       =   0,      /* Front couch (interface de ligne)            // Slope control (line interface) */
    CAN_SLOPE_HIGH_SPEED    =   1       /* Front droit (interface de ligne)             // High speed (line interface) */
} tCanSlope;

typedef struct
{
    uint16_t  wBusLoad;           /* Valeur de la charge bus                      // Bus load value */
    uint16_t  wReserved;          /* Rserv pour utilisation future              // Reserved for future use */
    uint32_t   dwTxRq;             /* Demande de transmission                      // Tx request */
    uint32_t   dwTxOk;             /* Fin de transmission correcte                 // End of Tx Ok */
    uint32_t   dwRxOk;             /* Rception correcte                           // Rx Ok */
    uint32_t   dwErrTxBit;         /* Erreur de type Bit en Tx                     // Bit error during transmission */
    uint32_t   dwErrRxBit;         /* Erreur de type Bit en Rx                     // Bit error during reception */
    uint32_t   dwErrTxForm;        /* Erreur de format en Tx                       // Format error during transmission */
    uint32_t   dwErrRxForm;        /* Erreur de format en Rx                       // Format error during reception */
    uint32_t   dwErrTxStuff;       /* Erreur de stuffing en Tx                     // Stuff error during transmission */
    uint32_t   dwErrRxStuff;       /* Erreur de stuffing en Rx                     // Stuff error during reception */
    uint32_t   dwErrTxOther;       /* Erreur autre que les 3 types ci-dessus en Tx // Other error during transmission */
    uint32_t   dwErrRxOther;       /* Erreur autre que les 3 types ci-dessus en Rx // Other error during reception */
    uint32_t   dwErrFifoOvf;       /* Perte de message                             // FIFO Rx overflow */
} tCanStat;

typedef struct
{
    uint16_t  wBRP;               /* Baud rate prescaler [1-64]                   // Baud rate prescaler */
    uint16_t  wTSEG1;             /* Dlai avant point d'chantillonnage [3-16]   // Time segment 1 */
    uint16_t  wTSEG2;             /* Dlai aprs point d'chantillonnage [2-8]    // Time segment 2 */
    uint16_t  wSJW;               /* Saut de resynchronisation max [1-4]          // Synchronisation jump width */
    uint16_t  wSPL;               /* Nbre de point d'chantillonnage [1 ou 3]     // Sampling mode [1 or 3] */
} tCanBus;

typedef struct
{
    uint32_t   dwFiltIdent;        /* Identificateur pour filtrage                 // Identifier for filtering */
    tCanTypeId      eTypeId;            /* Type d'identifcateur STD ou XTD              // Identifier type (standard (11 bits) or extended (29 bits) */
    uint32_t   dwFiltMask;         /* Masque pour filtrage                         // Acceptance mask */
    tCanBoolean     eAckEnable;         /* Validation / dvalidation de l'acquittement  // Enable or disable acknowlegment */
    tCanBoolean     eRxAll;             /* Rception des ident non dclars             // All messages or only programmed message are given to the application */
    uint16_t  wSpecialModes;      /* Rserv pour utilisation futures             // Reserved for future used */
} tCanParam;

typedef struct
{
	uint16_t  wFiltIdent1;		/* Identificateur pour filtrage (1er groupe)    // Identifier for filtering (1st group) */
	uint16_t  wFiltMask1;		    /* Masque pour filtrage         (1er groupe)    // Acceptance mask (1st group) */
	uint16_t  wFiltIdent2;		/* Identificateur pour filtrage (2me groupe)   // Identifier for filtering (2nd group) */
	uint16_t  wFiltMask2;		    /* Masque pour filtrage         (2me groupe)   // Acceptance mask (2nd group) */
	tCanTypeId      eTypeId;            /* Type d'identifcateur STD ou XTD              // Identifier type (standard (11 bits) or extended (29 bits) */
} tCanDualFilter;

typedef enum
{
    CAN_CLOCK_16MHZ         =   0,      /* fCAN = 16MHZ pour SJA1000 (valeur par dfaut) */
    CAN_CLOCK_40MHZ         =   1,      /* fCAN = 40MHZ pour TWINCAN (= fCPU) */
    CAN_CLOCK_5MHZ          =   2       /* fCAN = 5MHZ pour TWINCAN (= fCPU/8) */
} tCanClockFreq;

typedef struct
{
    uint16_t  wBus;               /* Numro de bus                                // Bus number */
    uint16_t  wHandleMsg;         /* Index de comm. sur le msg (Infos DLL)        // Communication handle returned by DLL */
    tMuxTypeEvent   eTypeEvent;         /* Type d'vnement retourn  l'application    // Event type */
    uint32_t   dwIdent;            /* Identificateur du message                    // CAN identifier value */
    tCanTypeId      eTypeId;            /* Type d'identifcateur STD ou XTD              // Identifier type (standard (11 bits) or extended (29 bits) */
    uint32_t   dwTimeStamp;        /* Heure de l'vnement en multiple de 0.1 ms   // Time of event in 100 Sec */
    uint16_t  wTimePrecision;     /* Prcision de la datation                     // Time accuracy */
    tCanService     eService;           /* Service de la requte                        // CAN services */
    uint16_t  wError;             /* Type d'erreur                                // Error type */
    tCanChipState   eChipState;         /* Etat du composants                           // Chip state */
    uint16_t  wLineState;         /* Etat de l'interface de ligne LS              // Low speed line interface state */
    uint16_t  wBusLoad;           /* Valeur de la charge bus                      // Bus load value */
    uint32_t   dwReserved1;        /* Rserv pour utilisation future              // Reserved */
    uint32_t   dwReserved2;        /* Rserv pour utilisation future              // Reserved */
    uint16_t  wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t   bData[CAN_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tCanEvent;

typedef struct
{
    uint16_t  wHandleMsg;         /* Index de comm. sur le msg (Infos DLL)        // Communication handle returned by DLL */
    uint32_t   dwIdent;            /* Identificateur du message                    // CAN identifier value */
    tCanTypeId      eTypeId;            /* Type d'identificateur STD ou XTD             // Identifier type (standard (11 bits) or extended (29 bits) */
    uint32_t   dwMask;				/* Masque appos sur l'identificateur           // Mask code */
    tCanService     eService;           /* Service de la requte                        // CAN services */
    uint32_t   lPeriod;            /* Periodicit en ms                            // Period */
    uint32_t   dwReserved1;        /* Mettre  0 (rserv pour utilisation future) // Must be set to 0 (Reserved for future used) */
    uint32_t   dwReserved2;        /* Mettre  0 (rserv pour utilisation future) // Must be set to 0 (Reserved for future used) */
    uint16_t  wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t   bData[CAN_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tCanMsg;

typedef struct
{
	uint16_t	wOffset;			/* Offset du message periodic					// Offset du message periodic */
	uint16_t	wParam;				/* Paramtre pour la priodique					// Parameters for the periodic */
	tCanMsg			hCanMsg;			/* Message  mettre							// Message to send */
} tCanPeriodicMsg;

typedef struct
{
	tCanTypeId      eTypeId;            /* Type d'identifcateur STD ou XTD              // Identifier type (standard (11 bits) or extended (29 bits) */
	uint32_t	dwLowIdent;			/*	Ident bas // Low Ident */
	uint32_t	dwHighIdent;		/*	Ident Haut // High Ident */
} tCanRangeFilter ;

/*******************************************************************************
; Routines CAN // CAN prototypes
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL
/* Configuration du mode de fonctionnement des buffers                      // Select the operating mode */
_MUXSPEC tMuxStatus _MUXAPI CanConfigOper(uint16_t wCard, uint16_t wBus, tCanOper *hCanOper);
/* Configuration du bus                                                     // Bus parameter */
_MUXSPEC tMuxStatus _MUXAPI CanConfigBus(uint16_t wCard, uint16_t wBus, tCanBus *hCanBus);
/* Configuration des paramtres supplmentaires                             // Extra parameter */
_MUXSPEC tMuxStatus _MUXAPI CanConfigParam(uint16_t wCard, uint16_t wBus, tCanParam *hCanParam);
/* configuration du filtre sur plage	//	Range filter settings */
_MUXSPEC tMuxStatus _MUXAPI CanConfigRangeFilter(uint16_t wCard, uint16_t wBus, tCanRangeFilter *hCanRangeFilter );
/* Configuration de l'horloge du contrleur CAN                             // Clock parameter */
_MUXSPEC tMuxStatus _MUXAPI CanConfigClock(uint16_t wCard, uint16_t wBus, tCanClockFreq eCanClock);
/* Configuration des filtres d'acceptance double                            // Set dual filter */
_MUXSPEC tMuxStatus _MUXAPI CanConfigDualFilter(uint16_t wCard, uint16_t wBus, tCanDualFilter *hCanDualFilter);
/* Configuration des statistques                                            // Statistics configuration */
_MUXSPEC tMuxStatus _MUXAPI CanConfigStat(uint16_t wCard, uint16_t wBus, uint16_t wBusLoadTime);
/* Configuration de l'interface de ligne HS                                 // High speed transceiver configuration */
_MUXSPEC tMuxStatus _MUXAPI CanConfigTransceiverHS(uint16_t wCard, uint16_t wBus, tCanSlope eCanSlope);
/* Slection de l'interface de ligne / Ou du single wire                    // Transceiver HS selection or single wire */
_MUXSPEC tMuxStatus _MUXAPI CanSelectTransceiverHS(uint16_t wCard, uint16_t wBus, tCanType eCanType);
/* Configuration de l'interface de ligne LS                                 // Low speed transceiver configuration */
_MUXSPEC tMuxStatus _MUXAPI CanConfigTransceiverLS(uint16_t wCard, uint16_t wBus, uint16_t wStandBy, uint16_t wEnable, uint16_t wWakeUp);
/* Configuration des rsistances de rappel CANLS                            // Low speed pull up resistor configuration */
_MUXSPEC tMuxStatus _MUXAPI CanConfigTerminationLS(uint16_t wCard, uint16_t wBus, uint16_t wValue);
/* Lecture de l'interface de ligne LS                                       // Low speed transceiver information */
_MUXSPEC tMuxStatus _MUXAPI CanReadTransceiverLS(uint16_t wCard, uint16_t wBus, uint16_t *wLineState);
/* Cration des messages de communication                                   // Messages configuration */
_MUXSPEC tMuxStatus _MUXAPI CanCreateMsg(uint16_t wCard, uint16_t wBus, tCanMsg *hCanMsg);
/* Lecture des messages de communication                                   // Messages read */
_MUXSPEC tMuxStatus _MUXAPI CanReadMsg(uint16_t wCard, uint16_t wBus, uint16_t wNumMsg, tCanMsg *hCanMsg);
/* modification des messages de communication                                  // Messages modification */
_MUXSPEC tMuxStatus _MUXAPI CanWriteMsg(uint16_t wCard, uint16_t wBus, uint16_t wNumMsg, tCanMsg *hCanMsg);
/* Cration de message priodique                                           // Periodic Messages configuration */
_MUXSPEC tMuxStatus _MUXAPI CanConfigPeriodic(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tCanMsg *hCanMsg);
/* Cration de plusieurs message priodique                                 // Several Periodic Messages configuration */
_MUXSPEC tMuxStatus _MUXAPI CanConfigPeriodicList(uint16_t wCard, uint16_t wBus, uint16_t wPeriodicCount, tCanPeriodicMsg *hPeriodicCanMsgList);
/* Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application */
_MUXSPEC tMuxStatus _MUXAPI CanSetNotification(uint16_t wCard, uint16_t wBus, void * hWinEvent);
/* Dmarrage de la communication                                            // Start communication */
_MUXSPEC tMuxStatus _MUXAPI CanActivate(uint16_t wCard, uint16_t wBus);
/* Etat du bus de communication                                             // Bus state communication */
_MUXSPEC tMuxStatus _MUXAPI CanIsBusActive(uint16_t wCard, uint16_t wBus, uint16_t *wState);
/* Arrt de la communication                                                // Stop communication */
_MUXSPEC tMuxStatus _MUXAPI CanDeactivate(uint16_t wCard, uint16_t wBus);
/* Emission d'un message                                                    // Transmit a message */
_MUXSPEC tMuxStatus _MUXAPI CanSendMsg(uint16_t wCard, uint16_t wBus, tCanMsg *hCanMsg);
/* Emission plusieurs messages											// Transmit several messages */
_MUXSPEC tMuxStatus _MUXAPI CanSendMsgList(uint16_t wCard, uint16_t wBus, uint16_t wMsgCount, tCanMsg *hCanMsgList);
/* Rcupration d'un vnement en provenance du rseau                      // Get an event from DLL */
_MUXSPEC tMuxStatus _MUXAPI CanGetEvent(uint16_t wCard, uint16_t wBus, tCanEvent *hCanEvent);
/* Reconnexion du bus aprs passage en bus off                              // Connect CAN bus after bus off transition */
_MUXSPEC tMuxStatus _MUXAPI CanBusOn(uint16_t wCard, uint16_t wBus);
/* change la vitesse du bus can 											//change can baudrate */
_MUXSPEC tMuxStatus _MUXAPI CanChangeBaudRate(uint16_t wCard, uint16_t wBus, tCanBus *hCanBus);

/* Lecture des statistiques                                                 // Statistics information */
_MUXSPEC tMuxStatus _MUXAPI CanGetStat(uint16_t wCard, uint16_t wBus, tCanStat *hCanStat);
/* Rcupration de l'tat du contrleur de protocole                        // CAN controller state */
_MUXSPEC tMuxStatus _MUXAPI CanGetBusState(uint16_t wCard, uint16_t wBus, tCanChipState *eCanChipState, uint8_t *bTxErrCount, uint8_t *bRxErrCount);
/* Purge de la file d'attente de rception                                  // Flush FIFO rx */
_MUXSPEC tMuxStatus _MUXAPI CanClearFifoRx(uint16_t wCard, uint16_t wBus);
/* Etat de la FIFO                                                          // Counts of event in the receive queue */
_MUXSPEC tMuxStatus _MUXAPI CanGetFifoRxLevel(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);

/* Lecture d'un octet sur un composant CAN                                  // Read byte from the CAN controller */
_MUXSPEC tMuxStatus _MUXAPI CanReadByte(uint16_t wCard, uint16_t wBus, uint16_t wOffset,uint8_t *bData);
/* Ecriture d'un octet sur un composant CAN                                 // Write byte to the CAN controller */
_MUXSPEC tMuxStatus _MUXAPI CanWriteByte(uint16_t wCard, uint16_t wBus, uint16_t wOffset,uint8_t bData);
#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tCanConfigOper)(uint16_t wCard, uint16_t wBus, tCanOper *hCanOper);
typedef tMuxStatus (__stdcall * tCanConfigBus)(uint16_t wCard, uint16_t wBus, tCanBus *hCanBus);
typedef tMuxStatus (__stdcall * tCanConfigParam)(uint16_t wCard, uint16_t wBus, tCanParam *hCanParam);
typedef tMuxStatus (__stdcall * tCanConfigRangeFilter)(uint16_t wCard, uint16_t wBus, tCanRangeFilter *hCanRangeFilter );
typedef tMuxStatus (__stdcall * tCanConfigClock)(uint16_t wCard, uint16_t wBus, tCanClockFreq eCanClock);
typedef tMuxStatus (__stdcall * tCanConfigDualFilter)(uint16_t wCard, uint16_t wBus, tCanDualFilter *hCanDualFilter);
typedef tMuxStatus (__stdcall * tCanConfigStat)(uint16_t wCard, uint16_t wBus, uint16_t wBusLoadTime);
typedef tMuxStatus (__stdcall * tCanConfigTransceiverHS)(uint16_t wCard, uint16_t wBus, tCanSlope eCanSlope);
typedef tMuxStatus (__stdcall * tCanSelectTransceiverHS)(uint16_t wCard, uint16_t wBus,  tCanType eCanType);
typedef tMuxStatus (__stdcall * tCanConfigTransceiverLS)(uint16_t wCard, uint16_t wBus, uint16_t wStandBy, uint16_t wEnable, uint16_t wWakeUp);
typedef tMuxStatus (__stdcall * tCanConfigTerminationLS)(uint16_t wCard, uint16_t wBus, uint16_t wValue);
typedef tMuxStatus (__stdcall * tCanReadTransceiverLS)(uint16_t wCard, uint16_t wBus, uint16_t *wLineState);
typedef tMuxStatus (__stdcall * tCanCreateMsg)(uint16_t wCard, uint16_t wBus, tCanMsg *hCanMsg);
typedef tMuxStatus (__stdcall * tCanReadMsg)(uint16_t wCard, uint16_t wBus, uint16_t wNumMsg, tCanMsg *hCanMsg);
typedef tMuxStatus (__stdcall * tCanWriteMsg)(uint16_t wCard, uint16_t wBus, uint16_t wNumMsg, tCanMsg *hCanMsg);
typedef tMuxStatus (__stdcall * tCanConfigPeriodic)(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tCanMsg *hCanMsg);
typedef tMuxStatus (__stdcall * tCanConfigPeriodicList)(uint16_t wCard, uint16_t wBus, uint16_t wPeriodicCount, tCanPeriodicMsg *hPeriodicCanMsgList);
typedef tMuxStatus (__stdcall * tCanSetNotification)(uint16_t wCard, uint16_t wBus, void * hWinEvent);
typedef tMuxStatus (__stdcall * tCanActivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tCanIsBusActive)(uint16_t wCard, uint16_t wBus, uint16_t *wState);
typedef tMuxStatus (__stdcall * tCanDeactivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tCanSendMsg)(uint16_t wCard, uint16_t wBus, tCanMsg *hCanMsg);
typedef tMuxStatus (__stdcall * tCanSendMsgList)(uint16_t wCard, uint16_t wBus, uint16_t wMsgCount, tCanMsg *hCanMsgList);
typedef tMuxStatus (__stdcall * tCanGetEvent)(uint16_t wCard, uint16_t wBus, tCanEvent *hCanEvent);
typedef tMuxStatus (__stdcall * tCanBusOn)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tCanChangeBaudRate)(uint16_t wCard, uint16_t wBus, tCanBus *hCanBus);
typedef tMuxStatus (__stdcall * tCanGetStat)(uint16_t wCard, uint16_t wBus, tCanStat *hCanStat);
typedef tMuxStatus (__stdcall * tCanGetBusState)(uint16_t wCard, uint16_t wBus, tCanChipState *eCanChipState, uint8_t *bTxErrCount, uint8_t *bRxErrCount);
typedef tMuxStatus (__stdcall * tCanClearFifoRx)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tCanGetFifoRxLevel)(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
typedef tMuxStatus (__stdcall * tCanReadByte)(uint16_t wCard, uint16_t wBus, uint16_t wOffset,uint8_t *bData);
typedef tMuxStatus (__stdcall * tCanWriteByte)(uint16_t wCard, uint16_t wBus, uint16_t wOffset,uint8_t bData);
#endif
#ifdef __cplusplus
	}
#endif

/*******************************************************************************
; Dclaration pour les routines NWC // NWC definitions
*******************************************************************************/
#define	NWC_MAX_DATA	        4095	/* Nbre de donnes max NWC                      // Maximum NWC data length */
typedef enum
{
    NWC_MODE_PHYSICAL       =   0,      /* Adressage physique     1 vers 1              // Physical address */
    NWC_MODE_FUNCTIONNAL    =   1       /* Adressage fonctionnel  1 vers n              // Functionnal address */
} tNwcAddrMode;

typedef enum
{
    NWC_FORMAT_NORMAL       =   0,      /* Adressage normal                             // Normal addressing */
    NWC_FORMAT_NORMAL_FIXED =   1,      /* Adressage normal fixe (ident prprogramm)   // Normal fixed addressing */
    NWC_FORMAT_EXTENDED     =   2,      /* Adressage tendu                             // Extended addressing */
    NWC_FORMAT_MIXED        =   3       /* Adressage mixe (ident prprogramm           // Mixed addressing */
} tNwcAddrFormat;

typedef enum
{
    NWC_COMM_HALF_DUPLEX    =   0,      /* Communication half duplex                    // Half-duplex communication */
    NWC_COMM_FULL_DUPLEX    =   1       /* Communication full duplex                    // Full-duplex communication */
} tNwcCommMode;

typedef enum
{
	NWC_SVC_TRANSMIT_DATA   =   0,      /* Transmission de donnes                      // Transmit message */
	NWC_SVC_RECEIVE_DATA    =   1       /* Rception de donnes                         // Receive message */
} tNwcService;

typedef struct
{
    uint16_t wBlockSize;      /* Nbre de blocs conscutifs // maximum number of consecutives frames */
    uint16_t wSTmin;          /* Dlai entre 2 blocs // Separation time */
    uint16_t wN_As;           /* Dlai max de transmission cot transmetteur // Time for transmission (transmitter side) */
    uint16_t wN_Ar;           /* Dlai max de transmission cot rcepteur // Time for transmission (receiver side) */
    uint16_t wN_Bs;           /* Dlai jusqu' rception du FC // Time until reception of next FC */
    uint16_t wN_Br;           /* Dlai jusqu' transmission du FC // Time until transmission of next FC*/
    uint16_t wN_Cr;           /* Dlai jusqu' rception du CF // Time until reception of next CF */
    uint16_t wN_WFTmax;       /* Nbre de FC max. attendue // max flow control wait */
} tNwcParam;

#define NWC_VARIABLE_LEN    0x0000  /* Emission des trames de longueur variable // Messages length variable */
#define NWC_FIXED_LEN       0x0001  /* Emission des trames force  8 octets // Messages length fixed to 8 */
#define NWC_CAN_NO_EVENT    0x0000  /* Pas de remont des vnements CAN // CAN events are ignored */
#define NWC_CAN_EVENT       0x0002  /* Remoont des vnements FF // FF events are stored in NWC FIFO */
#define NWC_NOFLOW_7402     0x0000  /* Pasnt des vnements CAN // CAN events are stored in CAN FIFO */
#define NWC_FF_NO_EVENT     0x0000  /* Pas de remont des vnements FF // FF events are ignored */
#define NWC_FF_EVENT        0x0004  /* Rem de gestion du 7402 // No 7402 management */
#define NWC_FLOW_7402       0x0008  /* Gestion du 7402 // 7402 management */
#define NWC_NOSPY_MODE      0x0000  // Le canal n'est pas en mode espion
#define NWC_SPY_MODE        0x0010  // Le canal est en mode espion

typedef struct
{
    tNwcAddrMode    eNwcAddrMode;   /* Mode d'adressage // Target address mode (1->1 or 1->n) */
    tNwcAddrFormat  eNwcAddrFormat; /* Format d'adressage // Address format (normal, fixe ...) */
    tNwcCommMode    eNwcCommMode;   /* Mode de communication // Communication mode */
    tNwcService     eNwcService;    /* Sens de la requte // Networw services */
    uint16_t  wParam;         /* (NWC_FIXED_LEN...) Paramtres supplmentaires // Further parameters */
} tNwcConfig;

typedef struct
{
    uint8_t   bSA;            /* Adresse source // Source address */
    uint8_t   bTA;            /* Adresse cible // Target address */
    uint8_t   bAE;            /* Adresse tendue // Extended address */
    uint8_t   bReserved;      /* Rserv // Reserved for future used */
    uint32_t   dwIdentTx;      /* Identificateur d'mission // Transmitter */
    tCanTypeId      eTypeIdTx;      /* Type d'identifcateur STD ou XTD // Identifier type (standard (11 bits) or extended (29 bits) */
    uint32_t   dwIdentFC;      /* Identificateur control de flux  // Flow Ccontrol Identifier */
    tCanTypeId      eTypeIdFC;      /* Type d'identifcateur STD ou XTD // Identifier type (standard (11 bits) or extended (29 bits) */
} tNwcAddr;

typedef struct
{
    tCanTypeId      eTypeId;        /* Type d'identifcateur STD ou XTD // Identifier type (standard (11 bits) or extended (29 bits) */
    uint32_t   dwIdentReq;     /* Identificateur de la requte et FC rponse // Request and FC response identifier */
    uint32_t   dwIdentRsp;     /* Identificateur de la rponse et FC requete // Response and FC request identifier */
    uint32_t   dwMask;		    /* Masque appos sur l'identificateur           // Mask code */
    uint16_t  wParam;         /* (NWC_FIXED_LEN...) Paramtres supplmentaires // Further parameters */
} tNwcSpyAddr;

typedef struct
{
    uint16_t  wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t   bData[NWC_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tNwcMsg;

typedef enum
{
    NWC_NO_ERR              =   0x0000, /* Pas d'erreur                                 // No error */
    NWC_ERR_TOUT_AS         =   0x0001, /* Time out AS                                  // AS Time out */
    NWC_ERR_TOUT_BS         =   0x0002, /* Time out BS                                  // BS Time out */
    NWC_ERR_TOUT_AR         =   0x0003, /* Time out AR                                  // AR Time out */
    NWC_ERR_TOUT_CR         =   0x0004, /* Time out CR                                  // CR Time out */
    NWC_ERR_SN              =   0x0005, /* Squence invalide                            // Invalid SN */
    NWC_ERR_FIFO_OVF        =   0x0010, /* Plus de place dans la fifo de trnasmission   // Fifo overflow */
    NWC_ERR_MEMORY          =   0x0011, /* Manque d'espace mmoire                      // Not enough memory */
    NWC_ERR_INV_PDU         =   0x0012, /* Format de PDU invalide                       // Invalid PDU format */
    NWC_ERR_INV_STATE       =   0x0013  /* Etat de rception incorrecte                 // Invalid State sequence */
} tNwcError;

typedef struct
{
    uint16_t  wBus;               /* Numro de bus                                // Bus number */
    uint16_t  wChannel;           /* Numro de canal                              // Channel number */
    tMuxTypeEvent   eTypeEvent;         /* Type d'vnement retourn  l'application    // Event type */
    uint32_t   dwIdent;            /* Identificateur du message                    // CAN identifier value */
    tCanTypeId      eTypeId;            /* Type d'identifcateur STD ou XTD              // Identifier type (standard (11 bits) or extended (29 bits) */
    uint32_t   dwTimeStamp;        /* Heure de l'vnement en multiple de 0.1 ms   // Time of event in 100 Sec */
    uint16_t  wTimePrecision;     /* Prcision de la datation                     // Time accuracy */
    tNwcService     eService;           /* Service de la requte                        // NWC services */
    tNwcError       eError;             /* Type d'erreur                                // Error type */
    uint32_t   dwReserved1;        /* Rserv pour utilisation future              // Reserved */
    uint32_t   dwReserved2;        /* Rserv pour utilisation future              // Reserved */
    uint16_t  wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t   bData[NWC_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tNwcEvent;

typedef struct 
{
	uint8_t bData[6];				/* Buffer de donne								// Data buffer*/
    uint32_t   dwReserved1;        /* Rserv pour utilisation future              // Reserved */
    uint32_t   dwReserved2;        /* Rserv pour utilisation future              // Reserved */
} tNwcBytePadding;
/* Etat de la voie // Channel State */
#define NWC_CHANNEL_STATE_STARTED         0x0001  /* Canal dmarr                            // Channel is activated */
#define NWC_CHANNEL_STATE_BUSY            0x0002  /* Canal en cours de communication          // Channel is currently transmitting ou receiving */

/*******************************************************************************
; Routines de segmentations ISO 15765-2 // ISO 15765-2 prototypes
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL
/* Autorise les fonctions ISO 15765-2                                       // Register ISO 15765 functions */
_MUXSPEC tMuxStatus _MUXAPI NwcRegister(char *szString, char *szKey);
/* Nbre de canaux de communication disponible                               // Channel communicaion available */
_MUXSPEC tMuxStatus _MUXAPI NwcGetChannelCount(uint16_t wCard, uint16_t wBus, uint16_t *wChannelCount);
/* Ouverture d'un canal de communication                                    // Open a channel communicaion */
_MUXSPEC tMuxStatus _MUXAPI NwcChannelOpen(uint16_t wCard, uint16_t wBus, uint16_t *wChannel);
/* Configuration d'un canal de communication                                // Channel communicaion configuration */
_MUXSPEC tMuxStatus _MUXAPI NwcChannelConfig(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwcConfig *hNwcChannelConfig);
/* Paramtres de communication d'un canal                                   // Channel comm. parameter */
_MUXSPEC tMuxStatus _MUXAPI NwcChannelParam(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwcParam *hNwcChannelParam);
/* Paramtres les adresses d'un canal                                       // Channel addr. parameter */
_MUXSPEC tMuxStatus _MUXAPI NwcChannelAddr(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwcAddr *hNwcChannelAddr);
/* Autorise la communication sur le canal                                   // Channel start communication */
_MUXSPEC tMuxStatus _MUXAPI NwcChannelStart(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
/* Arrte la communication sur le canal                                     // Channel stop communication */
_MUXSPEC tMuxStatus _MUXAPI NwcChannelStop(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
/* Ferme le canal de communication                                          // Close a channel communication */
_MUXSPEC tMuxStatus _MUXAPI NwcChannelClose(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
/* Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application */
_MUXSPEC tMuxStatus _MUXAPI NwcSetNotification(uint16_t wCard, uint16_t wBus, void * hWinEvent);
/* Dmarrage de la communication                                            // Start communication */
_MUXSPEC tMuxStatus _MUXAPI NwcActivate(uint16_t wCard, uint16_t wBus);
/* Etat du bus decommunication                                              // Bus state communication */
_MUXSPEC tMuxStatus _MUXAPI NwcIsBusActive(uint16_t wCard, uint16_t wBus, uint16_t *wState);
/* Arrt de la communication                                                // Stop communication */
_MUXSPEC tMuxStatus _MUXAPI NwcDeactivate(uint16_t wCard, uint16_t wBus);
/* Emission d'un message                                                    // Transmit a message */
_MUXSPEC tMuxStatus _MUXAPI NwcChannelSendMsg(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwcMsg *hNwcChannelMsg);
/* Emission d'un message                                                    // Transmit a message */
_MUXSPEC tMuxStatus _MUXAPI NwcChannelSendAsyncMsg(uint16_t wCard, uint16_t wBus, uint16_t wChannel, uint16_t wChannelRx, uint16_t wParam, tNwcMsg *hNwcChannelMsg);
/* Rcupration d'un vnement en provenance du rseau                      // Get an event from DLL */
_MUXSPEC tMuxStatus _MUXAPI NwcGetEvent(uint16_t wCard, uint16_t wBus, tNwcEvent *hNwcEvent);
/* Retourne les identifcateurs utiliss                                     // Get CAN identifier in use */
_MUXSPEC tMuxStatus _MUXAPI NwcGetIdent(tNwcConfig *pstNwcConfig,tNwcAddr *pstNwcAddr);
/* Etat de la FIFO                                                          // Counts of event in the receive queue */
_MUXSPEC tMuxStatus _MUXAPI NwcGetFifoRxLevel(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
/* Dmarrage de la communication                                            // Start communication */
_MUXSPEC tMuxStatus _MUXAPI NwcConfigSpyMode(uint16_t wCard, uint16_t wBus, tNwcSpyAddr *hNwcSpyAddr);
/* Etat du canal de communication                                           // Channel communication state */
_MUXSPEC tMuxStatus _MUXAPI NwcGetChannelState(uint16_t wCard, uint16_t wBus, uint16_t wChannel, uint16_t *wChannelState, tNwcError *eLastTxStatus);
/* Personnalisation des octets de bourrage de trame							// padding byte customization  */
_MUXSPEC tMuxStatus _MUXAPI NwcChannelSetBytePadding(uint16_t wCard,uint16_t wBus, uint16_t wChannel, tNwcBytePadding *hNwcBytePadding );
#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tNwcRegister)(char *szString, char *szKey);
typedef tMuxStatus (__stdcall * tNwcGetChannelCount)(uint16_t wCard, uint16_t wBus, uint16_t *wChannelCount);
typedef tMuxStatus (__stdcall * tNwcChannelOpen)(uint16_t wCard, uint16_t wBus, uint16_t *wChannel);
typedef tMuxStatus (__stdcall * tNwcChannelConfig)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwcConfig *hNwcChannelConfig);
typedef tMuxStatus (__stdcall * tNwcChannelParam)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwcParam *hNwcChannelParam);
typedef tMuxStatus (__stdcall * tNwcChannelAddr)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwcAddr *hNwcChannelAddr);
typedef tMuxStatus (__stdcall * tNwcChannelStart)(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
typedef tMuxStatus (__stdcall * tNwcChannelStop)(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
typedef tMuxStatus (__stdcall * tNwcChannelClose)(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
typedef tMuxStatus (__stdcall * tNwcSetNotification)(uint16_t wCard, uint16_t wBus, void * hWinEvent);
typedef tMuxStatus (__stdcall * tNwcActivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tNwcIsBusActive)(uint16_t wCard, uint16_t wBus, uint16_t *wState);
typedef tMuxStatus (__stdcall * tNwcDeactivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tNwcChannelSendMsg)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwcMsg *hNwcChannelMsg);
typedef tMuxStatus (__stdcall * tNwcChannelSendAsyncMsg)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, uint16_t wChannelRx, uint16_t wParam, tNwcMsg *hNwcChannelMsg);
typedef tMuxStatus (__stdcall * tNwcGetIdent)(tNwcConfig *pstNwcConfig,tNwcAddr *pstNwcAddr);
typedef tMuxStatus (__stdcall * tNwcGetEvent)(uint16_t wCard, uint16_t wBus, tNwcEvent *hNwcEvent);
typedef tMuxStatus (__stdcall * tNwcGetFifoRxLevel)(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
typedef tMuxStatus (__stdcall * tNwcConfigSpyMode)(uint16_t wCard, uint16_t wBus, tNwcSpyAddr *hNwcSpyAddr);
typedef tMuxStatus (__stdcall * tNwcGetChannelState)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, uint16_t *wChannelState, tNwcError *eLastTxStatus);
typedef tMuxStatus (__stdcall * tNwcChannelSetBytePadding)(uint16_t wCard,uint16_t wBus, uint16_t wChannel, tNwcBytePadding *hNwcBytePadding);
#endif
#ifdef __cplusplus
	}
#endif


/******************************************************************************
; Dclaration pour les routines J1939  // J1939 functions
******************************************************************************/
#define	J19_MAX_DATA	        1785	// Nbre de donnes max J1939                      // Maximum J1939 data length //
#define J19_NB_CHANNEL  32

typedef enum
{
	J19_SVC_TRANSMIT_DATA   =   0,      // Transmission de donnes                      // Transmit message //
	J19_SVC_RECEIVE_DATA    =   1       // Rception de donnes                         // Receive message //
} tJ19Service;

#define J19_CAN_NO_EVENT		0x0000
#define J19_CAN_EVENT           0x0001      // Indicateur si remont des evtx par le CAN
#define J19_RTS_NO_EVENT		0x0000
#define J19_RTS_EVENT           0x0002      // Indicateur si remont des evts FF
#define J19_SPY_MODE			0x0004

typedef enum
{
    J19_NO_ERR              =   0x0000, /* Pas d'erreur                                 // No error */
	J19_ERR_TR		        =   0x0001, /* */
	J19_ERR_TH		        =   0x0002, /* */
	J19_ERR_T1              =   0x0003, /* */
	J19_ERR_T2              =   0x0004, /* */
    J19_ERR_T3              =   0x0005, /* */
	J19_ERR_T4				=	0x0006,
	J19_ERR_BAM				=   0x0007,
	J19_ERR_CA				=	0x0008,
	J19_ERR_SN				= 	0x0009,
	J19_ERR_FIFO_OVF        =   0x0010,
    J19_ERR_MEMORY          =   0x0011,
} tJ19Error;

typedef struct
{
	uint16_t  wBus;               // Numro de bus                                // Bus number //
	uint16_t  wChannel;           // Numro de canal                              // Channel number //
	tMuxTypeEvent   eTypeEvent;         // Type d'vnement retourn  l'application    // Event type //
	uint32_t   dwIdent;            // Identificateur du message                    // CAN identifier value //
	tCanTypeId      eTypeId;            // Type d'identifcateur STD ou XTD              // Identifier type (standard (11 bits) or extended (29 bits) //
	uint32_t   dwTimeStamp;        // Heure de l'vnement en multiple de 0.1 ms   // Time of event in 100 Sec //
	uint16_t  wTimePrecision;     // Prcision de la datation                     // Time accuracy //
	tJ19Service     eService;           // Service de la requte                        // NWC services //
	tJ19Error       eError;             // Type d'erreur                                // Error type //
	uint32_t   dwPGN;              // numro du PGN					            // PGN Number //
	uint8_t	bSA;				// adresse source								// source addres//
	uint8_t	bReserved1;         // Rserv pour utilisation future              // Reserved //
	uint16_t  dwReserved2;        // Rserv pour utilisation future              // Reserved //
	uint16_t  wDataLen;           // Taille des donnes                           // Data length //
	uint8_t   bData[J19_MAX_DATA];// Buffer de donne                             // Data buffer //
} tJ19Event;

typedef struct
{
	tJ19Service     eJ19Service;    // Sens de la requte // Networw services //
	uint16_t  wParam;         //
} tJ19Config;

typedef struct
{
	uint8_t bPriority;
	uint32_t dwPGN;
	uint8_t bSA;
}tJ19Addr;

typedef struct
{
	uint16_t  wDataLen;           /* Taille des donnes                           // Data length */
	uint8_t   bData[J19_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tJ19Msg;

typedef struct
{
	uint16_t wTr;
	uint16_t wTh;
	uint16_t wT1;
	uint16_t wT2;
	uint16_t wT3;
	uint16_t wT4;
} tJ19Param;

typedef enum
{
    J1939_NO_ERR            =   0x0000, /* Pas d'erreur                                     // No error */
    J1939_ERR_TOUT_R_CM     =   0x0001, /* Dpassement du temps TR en mode point  point    // Gap of more than TR in peer to peer mode */
    J1939_ERR_TOUT_R_BM     =   0x0002, /* Dpassement du temps TR en mode diffusion        // Gap of more than TR in broadcast mode */
    J1939_ERR_TOUT_H        =   0x0003, /* Dpassement du temps TH                          // Gap of more than TH */
    J1939_ERR_TOUT_1_CM     =   0x0004, /* Dpassement du temps T1 en mode point  point    // Gap of more than T1 in peer to peer mode */
    J1939_ERR_TOUT_1_BM     =   0x0005, /* Dpassement du temps T1 en mode diffusion        // Gap of more than T1 in broadcast mode */
    J1939_ERR_TOUT_2        =   0x0006, /* Dpassement du temps T2                          // Gap of more than T2 */
    J1939_ERR_TOUT_3        =   0x0007, /* Dpassement du temps T3                          // Gap of more than T3 */
    J1939_ERR_TOUT_4        =   0x0008, /* Dpassement du temps T4                          // Gap of more than T4 */
    J1939_ERR_CA_R1         =   0x0109, /* Abandon de la connexion pour la raison n1       // Connection Abort for reason 1 */
    J1939_ERR_CA_R2         =   0x020A, /* Abandon de la connexion pour la raison n2       // Connection Abort for reason 2 */
    J1939_ERR_CA_R3         =   0x030A, /* Abandon de la connexion pour la raison n3       // Connection Abort for reason 3 */
    J1939_ERR_CA_R4         =   0x040A, /* Abandon de la connexion pour la raison n4       // Connection Abort for reason 4 */
    J1939_ERR_CA_R5         =   0x050A, /* Abandon de la connexion pour la raison n5       // Connection Abort for reason 5 */
    J1939_ERR_CA_R6         =   0x060A, /* Abandon de la connexion pour la raison n6       // Connection Abort for reason 6 */
    J1939_ERR_CA_R7         =   0x070A, /* Abandon de la connexion pour la raison n7       // Connection Abort for reason 7 */
    J1939_ERR_CA_R8         =   0x080A, /* Abandon de la connexion pour la raison n8       // Connection Abort for reason 8 */
    J1939_ERR_CA_R9         =   0x090A, /* Abandon de la connexion pour la raison n9       // Connection Abort for reason 9 */
    J1939_ERR_CA_R250       =   0xFA0A, /* Abandon de la connexion pour la raison n250     // Connection Abort for reason 250 */
    J1939_ERR_BA_R1         =   0x010B, /* Abandon de la rception de diffusion (raison 1)  // Broadcast reception abort for reason 1 */
    J1939_ERR_BA_R2         =   0x020B, /* Abandon de la rception de diffusion (raison 2)  // Broadcast reception abort for reason 2 */
    J1939_ERR_BA_R6         =   0x060B, /* Abandon de la rception de diffusion (raison 6)  // Broadcast reception abort for reason 6 */
    J1939_ERR_BA_R7         =   0x070B, /* Abandon de la rception de diffusion (raison 7)  // Broadcast reception abort for reason 7 */
    J1939_ERR_BA_R8         =   0x080B, /* Abandon de la rception de diffusion (raison 8)  // Broadcast reception abort for reason 8 */
    J1939_ERR_BA_R9         =   0x090B, /* Abandon de la rception de diffusion (raison 9)  // Broadcast reception abort for reason 9 */
    J1939_ERR_FIFO_OVF      =   0x0010, /* Plus de place dans la fifo de transmission       // Fifo overflow */
    J1939_ERR_MEMORY        =   0x0011, /* Manque d'espace mmoire                          // Not enough memory */
} tJ1939Error;

typedef struct
{
    uint8_t   bPriority;      /* Priorit du message [0-7]                        // Message priority */
    uint8_t   bSA;            /* Adresse source                                   // Source address */
    uint16_t  wSTmin;         /* Dlai entre 2 blocs                              // Separation time */
    uint16_t  wSTminb;        /* Dlai entre 2 blocs (BAM)                        // Separation time for BAM */
    uint16_t  wTr;            /* Dlai jusqu' transmission du DT ou de 1er CTS   // Time until transmission of the next DT or the first CTS */
    uint16_t  wTh;            /* Dlai jusqu' transmission du CTS suivant        // Time until transmission of the next CTS */
    uint16_t  wT1;            /* Dlai jusqu' rception du DT suivant            // Time until reception of the next DT */
    uint16_t  wT2;            /* Dlai jusqu' rception du 1er DT d'un bloc      // Time until reception of the first DT of a bloc */
    uint16_t  wT3;            /* Dlai jusqu' rception du CTS                   // Time until reception of the CTS flow control */
    uint16_t  wT4;            /* Dlai jusqu' rception du CTS suivant           // Time until reception of the next CTS */
    uint16_t  wOptions;       /* Options diverses                                 // Miscellaneous options */
} tJ1939Param;

typedef struct
{
    uint16_t        wBus;               /* Numro de bus                                // Bus number */
    uint16_t        wReserved;          /* Rserv pour utilisation future              // Reserved */
    tMuxTypeEvent   eTypeEvent;         /* Type d'vnement retourn  l'application    // Event type */
    uint32_t        dwIdent;            /* Identificateur du message                    // CAN identifier value */
    tCanTypeId      eTypeId;            /* Type d'identifcateur STD ou XTD              // Identifier type (standard (11 bits) or extended (29 bits) */
    uint32_t        dwTimeStamp;        /* Heure de l'vnement en multiple de 0.1 ms   // Time of event in 100 Sec */
    uint16_t        wTimePrecision;     /* Prcision de la datation                     // Time accuracy */
    tJ19Service     eService;           /* Service de la requte                        // J1939 services */
    tJ1939Error     eError;             /* Type d'erreur                                // Error type */
    uint32_t        dwReserved1;        /* Rserv pour utilisation future              // Reserved */
    uint32_t        dwReserved2;        /* Rserv pour utilisation future              // Reserved */
    uint16_t        wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t         bData[J19_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tJ1939Event;

typedef struct
{
    uint32_t    dwIdent;            /* Identificateur du message                    // CAN identifier value */
    tCanTypeId  eTypeId;            /* Type d'identificateur STD ou XTD             // Identifier type (standard (11 bits) or extended (29 bits) */
    uint8_t     bSA;                /* Adresse source                               // Source address */
    uint8_t     bReserved;          /* Mettre  0 (rserv pour utilisation future) // Must be set to 0 (Reserved for future used) */
    uint16_t    wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t     bData[J19_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tJ1939Msg;

/******************************************************************************
; Routines de segmentations J1939 // J1939 prototypes
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL
_MUXSPEC tMuxStatus _MUXAPI J19Register(char *szString, char *szKey);
_MUXSPEC tMuxStatus _MUXAPI J19ChannelOpen(uint16_t wCard, uint16_t wBus, uint16_t *wChannel);
_MUXSPEC tMuxStatus _MUXAPI J19ChannelAddr(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tJ19Addr * hJ19ChannelAddr);
_MUXSPEC tMuxStatus _MUXAPI J19ChannelParam(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tJ19Param *hJ19ChannelParam);
_MUXSPEC tMuxStatus _MUXAPI J19ChannelConfig(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tJ19Config *hJ19ChannelConfig);
_MUXSPEC tMuxStatus _MUXAPI J19ChannelStart(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
_MUXSPEC tMuxStatus _MUXAPI J19ChannelStop(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
_MUXSPEC tMuxStatus _MUXAPI J19ChannelClose(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
_MUXSPEC tMuxStatus _MUXAPI J19Activate(uint16_t wCard, uint16_t wBus);
_MUXSPEC tMuxStatus _MUXAPI J19IsBusActive(uint16_t wCard, uint16_t wBus, uint16_t *wState);
_MUXSPEC tMuxStatus _MUXAPI J19ConfigBus(uint16_t wCard, uint16_t wBus, uint16_t wParam);
_MUXSPEC tMuxStatus _MUXAPI J19Deactivate(uint16_t wCard, uint16_t wBus);
_MUXSPEC tMuxStatus _MUXAPI J19ChannelSendMsg(uint16_t wCard, uint16_t wBus,uint16_t wChannel, tJ19Msg *hJ19ChannelMsg);
_MUXSPEC tMuxStatus _MUXAPI J19ChannelSendNMEAFastPacket(uint16_t wCard, uint16_t wBus,uint16_t wChannel, tJ19Msg *hJ19ChannelMsg);
_MUXSPEC tMuxStatus _MUXAPI J19SetNotification(uint16_t wCard, uint16_t wBus, void * hWinEvent);
_MUXSPEC tMuxStatus _MUXAPI J19GetEvent(uint16_t wCard, uint16_t wBus, tJ19Event *hJ19Event);
_MUXSPEC tMuxStatus _MUXAPI J19GetFifoRxLevel(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
_MUXSPEC tMuxStatus _MUXAPI J19StoreNMEAFastPacket(uint16_t wCard, uint16_t wBus, uint32_t dwIdent, uint16_t wSize);
_MUXSPEC tMuxStatus _MUXAPI J1939SetParam(uint16_t wCard, uint16_t wBus, tJ1939Param *hJ19Param);
_MUXSPEC tMuxStatus _MUXAPI J1939IsBusActive(uint16_t wCard, uint16_t wBus, uint16_t *wState);
_MUXSPEC tMuxStatus _MUXAPI J1939SendMsg(uint16_t wCard, uint16_t wBus, tJ1939Msg *hJ19Msg);
_MUXSPEC tMuxStatus _MUXAPI J1939SetNotification(uint16_t wCard, uint16_t wBus, void * hWinEvent);
_MUXSPEC tMuxStatus _MUXAPI J1939GetEvent(uint16_t wCard, uint16_t wBus, tJ1939Event *hJ19Event);
_MUXSPEC tMuxStatus _MUXAPI J1939GetFifoRxLevel(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);

#else
typedef tMuxStatus  (__stdcall * tJ19Register)(char *szString, char *szKey);
typedef tMuxStatus  (__stdcall * tJ19ChannelOpen)(uint16_t wCard, uint16_t wBus, uint16_t *wChannel);
typedef tMuxStatus  (__stdcall * tJ19ChannelAddr)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tJ19Addr * hJ19ChannelAddr);
typedef tMuxStatus  (__stdcall * tJ19ChannelParam)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tJ19Param *hJ19ChannelParam);
typedef tMuxStatus  (__stdcall * tJ19ChannelConfig)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tJ19Config *hJ19ChannelConfig);
typedef tMuxStatus  (__stdcall * tJ19ChannelStart)(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
typedef tMuxStatus  (__stdcall * tJ19ChannelStop)(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
typedef tMuxStatus  (__stdcall * tJ19ChannelClose)(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
typedef tMuxStatus  (__stdcall * tJ19Activate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus  (__stdcall * tJ19IsBusActive)(uint16_t wCard, uint16_t wBus, uint16_t *wState);
typedef tMuxStatus  (__stdcall * tJ19ConfigBus)(uint16_t wCard, uint16_t wBus, uint16_t wParam);
typedef tMuxStatus  (__stdcall * tJ19Deactivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus  (__stdcall * tJ19ChannelSendMsg)(uint16_t wCard, uint16_t wBus,uint16_t wChannel, tJ19Msg *hJ19ChannelMsg);
typedef tMuxStatus  (__stdcall * tJ19ChannelSendNMEAFastPacket)(uint16_t wCard, uint16_t wBus,uint16_t wChannel, tJ19Msg *hJ19ChannelMsg);
typedef tMuxStatus  (__stdcall * tJ19SetNotification)(uint16_t wCard, uint16_t wBus, void * hWinEvent);
typedef tMuxStatus  (__stdcall * tJ19GetEvent)(uint16_t wCard, uint16_t wBus, tJ19Event *hJ19Event);
typedef tMuxStatus  (__stdcall * tJ19GetFifoRxLevel)(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
typedef tMuxStatus  (__stdcall * tJ19StoreNMEAFastPacket)(uint16_t wCard, uint16_t wBus, uint32_t dwIdent, uint16_t wSize);
typedef tMuxStatus  (__stdcall * tJ1939SetParam)(uint16_t wCard, uint16_t wBus, tJ1939Param *hJ19Param);
typedef tMuxStatus  (__stdcall * tJ1939IsBusActive)(uint16_t wCard, uint16_t wBus, uint16_t *wState);
typedef tMuxStatus  (__stdcall * tJ1939SendMsg)(uint16_t wCard, uint16_t wBus, tJ1939Msg *hJ19Msg);
typedef tMuxStatus  (__stdcall * tJ1939SetNotification)(uint16_t wCard, uint16_t wBus, void * hWinEvent);
typedef tMuxStatus  (__stdcall * tJ1939GetEvent)(uint16_t wCard, uint16_t wBus, tJ1939Event *hJ19Event);
typedef tMuxStatus  (__stdcall * tJ1939GetFifoRxLevel)(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
#endif
#ifdef __cplusplus
	}
#endif


/*******************************************************************************
; Dclaration pour les routines LIN  // LIN functions
*******************************************************************************/
#define	LIN_MAX_DATA	        		8		/* Nbre de donnes max LIN                      // Maximum LIN data length */

#define LIN_PERIODIC_PARAM_ENABLE		1		/* Active la priodique							// Enable periodic frame */
#define LIN_PERIODIC_PARAM_DISABLE		0		/* Desactive la periodique						// Disable periodic frame */
#define LIN_PERIODIC_PARAM_WITHEVENTS	2		/* Active la remonte des vnements			// Enable the events */
#define LIN_PERIODIC_PARAM_NOEVENTS		0		/* Desactive la remonte des vnements			// Disable the events */

typedef enum
{
    LIN_OPER_ANA_FIFO       =   0       /* Mode analyse, stockage fifo                  // Analyse mode, event is stored in fifo mode */
} tLinOperMode;

typedef struct
{
    tLinOperMode    eLinOperMode;       /* Type d'interface avec l'application          // Operating mode with API */
    uint16_t  wFifoSize;          /* Taille de la FIFO                            // FIFO Size */
} tLinOper;
typedef enum
{
    LIN_BAUD_2400   =   2400L,	    	/* 2400 baud */
    LIN_BAUD_9600   =   9600L,	    	/* 9600 baud */
	LIN_BAUD_10400	=	10400L,			/* 10400 baud */
    LIN_BAUD_19200  =   19200L,	    	/* 19200 baud */
    LIN_BAUD_20833  =   20833L,	    	/* 20833 baud */
	LIN_BAUD_38400	=	38400L	 	    /* 38400 baud */
} tLinBaudRate;
typedef enum
{
    LIN_GEN_NO_ERR          =   0x0000, /* Pas d'erreur                                 // No error */
    LIN_GEN_ERR_P0          =   0x0001, /* Erreur du bit de parit P0                   // P0 parity error */
    LIN_GEN_ERR_P1          =   0x0002, /* Erreur du bit de parit P1                   // P1 parity error */
    LIN_GEN_ERR_CRC         =   0x0003, /* Erreur de CRC                                // CRC error */
    LIN_GEN_ERR_SYNCH       =   0x0004, /* Erreur de caractre de synchro               // Synchro char error */
    LIN_GEN_ERR_DATP1       =   0x0005, /* + 1 octet de donne                          // +1 byte in data field */
    LIN_GEN_ERR_DATP2       =   0x0006, /* + 2 octets de donnes                        // +2 bytes in data field */
    LIN_GEN_ERR_DATL1       =   0x0007, /* - 1 octet de donne                          // -1 byte in data field */
    LIN_GEN_ERR_DATL2       =   0x0008, /* - 2 octets de donnes                        // -2 bytes in data field */
//	LIN_GEN_FREE_ID         =   0x0009,  /* Identificateur libre                         // Free ident */
    LIN_GEN_FREE_ID         =   0x0100, /* Identificateur libre                         // Free ident */
	LIN_GEN_CLASSIC_CRC     =   0x0200  /* Force le checksum classique                  // Classic checksum */
}
tLinGenErr;
typedef enum
{
    LIN_NO_ERR              =   0x0000, /* Pas d'erreur                                 // No error */
    LIN_ERR_BIT             =   0x0001, /* Erreur de bit                                // Bit error */
    LIN_ERR_CRC             =   0x0002, /* Erreur dans le calcul du CRC                 // CRC error */
    LIN_ERR_TIMEOUT         =   0x0003, /* Time out rponse esclave                     // Slave not responding */
    LIN_ERR_PARITY          =   0x0004, /* Erreur de parit                             // Parity error */
    LIN_ERR_SYNCHRO         =   0x0005, /* Erreur de rception du car de synchro        // Inconsistent synch bit error */
    LIN_ERR_LENGTH          =   0x0006, /* Erreur de rception de la longueur           // Length requested error */
    LIN_ERR_TO_TX           =   0x0007, /* Time out en transmission                     // Timeout while transmitting */
    LIN_ERR_TO_SYNCHRO      =   0x0008, /* Time out sur rx du car de synchro            // Timeout waiting synchro field */
    LIN_ERR_TO_IDENT        =   0x0009, /* Time out sur rx du car ident                 // Timeout waiting ident field */
    LIN_ERR_TO_DATA         =   0x000A, /* Time out sur rx des donnes                  // Timeout waiting data field */
    LIN_ERR_TO_CRC          =   0x000B  /* Time out sur rx CRC                          // Timeout waiting CRC field */
} tLinError;
typedef enum
{
    LIN_SVC_TRANSMIT_DATA   =   0,      /* Transmission de donnes                      // Transmit message */
    LIN_SVC_RECEIVE_DATA    =   1,      /* Rception de donnes                         // Receive message */
    LIN_SVC_REQUEST_IFR     =   2,      /* Demande de rponse dans la trame             // Reply IFR message */
    LIN_SVC_UPDATE_IFR      =   3,      /* Mise  jour pour rponse dans la trame       // Update IFR (without transmission) */
    LIN_SVC_WAKEUP          =   4       /* Indication rception signal de wakeup        // Wake up signal detected */
} tLinService;
typedef enum
{
    LIN_BUS_NOMINAL         =   0,      /* Etat nominal                                 // Nominal state */
    LIN_BUS_ERROR           =   1,      /* Etat erreur                                  // Error state */
    LIN_BUS_IDLE            =   2       /* Etat bus idle                                // Bus idle state */
} tLinChipState;
typedef enum
{
    LIN_FALSE               =   0,      /* Boolen faux                                 // FALSE */
    LIN_TRUE                =   1       /* Boolen vrai                                 // TRUE */
} tLinBoolean;
typedef struct
{
    uint16_t  wBusLoad;           /* Valeur de la charge bus                      // Bus load value */
    uint16_t  wReserved;          /* Rserv pour utilisation future              // Reserved for future use */
    uint32_t   dwTxRq;             /* Demande de transmission                      // Tx request */
    uint32_t   dwTxOk;             /* Fin de transmission correcte                 // End of Tx Ok */
    uint32_t   dwRxOk;             /* Rception correcte                           // Rx Ok */
    uint32_t   dwErrBit;           /* Erreur de type Bit                           // Bit error */
    uint32_t   dwErrCrc;           /* Erreur de CRC                                // CRC error */
    uint32_t   dwErrTimeOut;       /* Erreur de time-out                           // Timeout error */
    uint32_t   dwErrSynchro;       /* Erreur de caractre de synchro               // Inconsistent synch bit error */
    uint32_t   dwErrIdent;         /* Erreur de caractre ident                    // Ident error */
    uint32_t   dwErrOther;         /* Erreur autre                                 // Other error */
    uint32_t   dwErrFifoOvf;       /* Perte de message                             // FIFO Rx overflow */
} tLinStat;

typedef struct
{
    tLinBaudRate    eBaudRate;          /* Dbit du bus                                 // Baud rate */
} tLinBus;

typedef struct
{
    tLinBoolean     eDefDelayBusIdle;   /* Utilisation des dlais par dfaut            // Default delay for bus idle */
    uint32_t   dwDelayBusIdle;     /* Delai avant bus idle                         // Delay before detect bus idle */
    uint16_t  wSpecialModes;      /* Rserv pour utilisation futures             // Reserved for future used */
} tLinParam;

typedef struct
{
    uint16_t  wBus;               /* Numro de bus                                // Bus number */
    uint16_t  wHandleMsg;         /* Index de comm. sur le msg (Infos DLL)        // Communication handle returned by DLL */
    tMuxTypeEvent   eTypeEvent;         /* Type d'vnement retourn  l'application    // Event type */
    uint16_t  wIdent;             /* Identificateur du message                    // LIN identifier value */
    uint32_t   dwTimeStamp;        /* Heure de l'vnement en multiple de 0.1 ms   // Time of event in 100 Sec */
    uint16_t  wTimePrecision;     /* Prcision de la datation                     // Time accuracy */
    tLinService     eService;           /* Service de la requte                        // LIN services */
    tLinError       eError;             /* Type d'erreur                                // Error type */
    tLinChipState   eChipState;         /* Etat du composants                           // Chip state */
    uint16_t  wBusLoad;           /* Valeur de la charge bus                      // Bus load value */
    uint32_t   dwReserved1;        /* Rserv pour utilisation future              // Reserved */
    uint32_t   dwReserved2;        /* Rserv pour utilisation future              // Reserved */
    uint16_t  wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t   bData[LIN_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tLinEvent;

typedef struct
{
    uint16_t  wHandleMsg;         /* Index de comm. sur le msg (Infos DLL)        // Communication handle returned by DLL */
    uint16_t  wIdent;             /* Identificateur LIN du message                // LIN Identifier value */
    tLinService     eService;           /* Service de la requte                        // LIN services */
    uint32_t   lPeriod;            /* Periodicit en ms                            // Period */
    tLinBoolean     eLevel3Enable;      /* Gestion des couches de communication         // Enable communication management */
    tLinGenErr      eLinGenErr;         /* Gestion erron du protocole                 // Generate protocol error */
    uint32_t   dwReserved1;        /* Mettre  0 (rserv pour utilisation future) // Must be set to 0 (Reserved for future used) */
    uint32_t   dwReserved2;        /* Mettre  0 (rserv pour utilisation future) // Must be set to 0 (Reserved for future used) */
    uint16_t  wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t   bData[LIN_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tLinMsg;

typedef struct
{
	uint16_t	wOffset;			/* Offset du message periodic					// Offset du message periodic */
	uint16_t	wParam;				/* Paramtre pour la priodique					// Parameters for the periodic */
    tLinMsg			hLinMsg;			/* Message  mettre							// Message to send */
} tLinPeriodicMsg;

/*******************************************************************************
; Routines LIN // LIN prototypes
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL
/* Configuration du mode de fonctionnement des buffers                      // Select the operating mode */
_MUXSPEC tMuxStatus _MUXAPI LinConfigOper(uint16_t wCard, uint16_t wBus, tLinOper *hLinOper);
/* Configuration du bus                                                     // Bus parameter */
_MUXSPEC tMuxStatus _MUXAPI LinConfigBus(uint16_t wCard, uint16_t wBus, tLinBus *hLinBus);
/* Paramtres de configuration                                              // Uart parameter */
_MUXSPEC tMuxStatus _MUXAPI LinConfigUart(uint16_t wCard, uint16_t wBus, tUartConfig *hUartConfig);
/* Configuration des paramtres supplmentaires                             // Extra parameter */
_MUXSPEC tMuxStatus _MUXAPI LinConfigParam(uint16_t wCard, uint16_t wBus, tLinParam *hLinParam);
/* Configuration des statistques                                            // Statistics configuration */
_MUXSPEC tMuxStatus _MUXAPI LinConfigStat(uint16_t wCard, uint16_t wBus, uint16_t wBusLoadTime);
/* Configuration de la version                                              // Version setup */
_MUXSPEC tMuxStatus _MUXAPI LinSetVersion(uint16_t wCard, uint16_t wBus, uint32_t dwVersion);
/* Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application */
_MUXSPEC tMuxStatus _MUXAPI LinSetNotification(uint16_t wCard, uint16_t wBus, void * hWinEvent);
/* Dmarrage de la communication                                            // Start communication */
_MUXSPEC tMuxStatus _MUXAPI LinActivate(uint16_t wCard, uint16_t wBus);
/* Etat du bus de communication                                             // Bus state communication */
_MUXSPEC tMuxStatus _MUXAPI LinIsBusActive(uint16_t wCard, uint16_t wBus, uint16_t *wState);
/* Configuration de l'impdance de ligne Maitre ou Esclave                  // Master or Slave Bus line configuration */
_MUXSPEC tMuxStatus _MUXAPI LinConfigTransceiver(uint16_t wCard, uint16_t wBus, uint16_t wEnable, uint16_t wRMaster);
/* Cration de message priodique                                           // Periodic Messages configuration */
_MUXSPEC tMuxStatus _MUXAPI LinConfigPeriodic(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tLinMsg *hLinMsg);
/* Cration d'une liste de message periodide								// Periodic message list configuration */
_MUXSPEC tMuxStatus _MUXAPI LinConfigPeriodicList(uint16_t wCard, uint16_t wBus, uint16_t wPeriodicCount, tLinPeriodicMsg *hLinPeriodicMsgList);
/* Arrt de la communication                                                // Stop communication */
_MUXSPEC tMuxStatus _MUXAPI LinDeactivate(uint16_t wCard, uint16_t wBus);
/* Emission d'un message                                                    // Transmit a message */
_MUXSPEC tMuxStatus _MUXAPI LinSendMsg(uint16_t wCard, uint16_t wBus, tLinMsg *hLinMsg);
/* Emission d'une liste de message											// Transmit a list of message */
_MUXSPEC tMuxStatus _MUXAPI LinSendMsgList(uint16_t wCard, uint16_t wBus, uint16_t wMsgCount, tLinMsg *hLinMsgList);
/* Rcupration d'un vnement en provenance du rseau                      // Get an event from DLL */
_MUXSPEC tMuxStatus _MUXAPI LinGetEvent(uint16_t wCard, uint16_t wBus, tLinEvent *hLinEvent);

/* Lecture des statistiques                                                 // Statistics information */
_MUXSPEC tMuxStatus _MUXAPI LinGetStat(uint16_t wCard, uint16_t wBus, tLinStat *hLinStat);
/* Rcupration de l'tat du contrleur de protocole                        // CAN controller state */
_MUXSPEC tMuxStatus _MUXAPI LinGetBusState(uint16_t wCard, uint16_t wBus, tLinChipState *eLinChipState, uint8_t *bTxErrCount, uint8_t *bRxErrCount);
/* Emission d'un message de mise en veille du bus                           // Sleep mode command message */
_MUXSPEC tMuxStatus _MUXAPI LinSetSleepMode(uint16_t wCard, uint16_t wBus);
/* Emission d'un signal de rveil                                           // WakeUp signal */
_MUXSPEC tMuxStatus _MUXAPI LinSetWakeUpMode(uint16_t wCard, uint16_t wBus);
/* Purge de la file d'attente de rception                                  // Flush FIFO rx */
_MUXSPEC tMuxStatus _MUXAPI LinClearFifoRx(uint16_t wCard, uint16_t wBus);
/* Purge du buffer d'mission des IFR                                  		// Flush FIFO IFR */
_MUXSPEC tMuxStatus _MUXAPI LinClearBufferIFR(uint16_t wCard, uint16_t wBus);
/* Etat de la FIFO                                                          // Counts of event in the receive queue */
_MUXSPEC tMuxStatus _MUXAPI LinGetFifoRxLevel(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);

#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tLinConfigOper)(uint16_t wCard, uint16_t wBus, tLinOper *hLinOper);
typedef tMuxStatus (__stdcall * tLinConfigBus)(uint16_t wCard, uint16_t wBus, tLinBus *hLinBus);
typedef tMuxStatus (__stdcall * tLinConfigUart)(uint16_t wCard, uint16_t wBus, tUartConfig *hUartConfig);
typedef tMuxStatus (__stdcall * tLinConfigParam)(uint16_t wCard, uint16_t wBus, tLinParam *hLinParam);
typedef tMuxStatus (__stdcall * tLinConfigStat)(uint16_t wCard, uint16_t wBus, uint16_t wBusLoadTime);
typedef tMuxStatus (__stdcall * tLinSetVersion)(uint16_t wCard, uint16_t wBus, uint32_t dwVersion);
typedef tMuxStatus (__stdcall * tLinSetNotification)(uint16_t wCard, uint16_t wBus, void * hWinEvent);
typedef tMuxStatus (__stdcall * tLinActivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tLinIsBusActive)(uint16_t wCard, uint16_t wBus, uint16_t *wState);
typedef tMuxStatus (__stdcall * tLinConfigTransceiver)(uint16_t wCard, uint16_t wBus, uint16_t wEnable, uint16_t wRMaster);
typedef tMuxStatus (__stdcall * tLinConfigPeriodic)(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tLinMsg *hLinMsg);
typedef tMuxStatus (__stdcall * tLinConfigPeriodicList)(uint16_t wCard, uint16_t wBus, uint16_t wPeriodicCount, tLinPeriodicMsg *hLinPeriodicMsgList);
typedef tMuxStatus (__stdcall * tLinDeactivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tLinSendMsg)(uint16_t wCard, uint16_t wBus, tLinMsg *hLinMsg);
typedef tMuxStatus (__stdcall * tLinSendMsgList)(uint16_t wCard, uint16_t wBus, uint16_t wMsgCount, tLinMsg *hLinMsgList);
typedef tMuxStatus (__stdcall * tLinGetEvent)(uint16_t wCard, uint16_t wBus, tLinEvent *hLinEvent);
typedef tMuxStatus (__stdcall * tLinGetStat)(uint16_t wCard, uint16_t wBus, tLinStat *hLinStat);
typedef tMuxStatus (__stdcall * tLinGetBusState)(uint16_t wCard, uint16_t wBus, tLinChipState *eLinChipState, uint8_t *bTxErrCount, uint8_t *bRxErrCount);
typedef tMuxStatus (__stdcall * tLinSetSleepMode)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tLinSetWakeUpMode)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tLinClearFifoRx)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tLinClearBufferIFR)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tLinGetFifoRxLevel)(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
#endif

#ifdef __cplusplus
	}
#endif

/*******************************************************************************
; Dclaration pour les routines NWL // NWL definitions
*******************************************************************************/
#define	NWL_MAX_DATA	        4095	/* Nbre de donnes max NWL                      // Maximum NWL data length */

typedef enum
{
    NWL_SVC_TRANSMIT_DATA   =   0,      /* Transmission de donnes (Matre)             // Transmit message */
    NWL_SVC_RECEIVE_DATA    =   1,      /* Rception de donnes (Esclave)               // Receive message */
    NWL_SVC_REQUEST_IFR     =   2,      /* Rception de donnes (Matre)                // Receive message */
    NWL_SVC_UPDATE_IFR      =   3       /* Transmission de donnes (Esclave)            // Transmit message */
} tNwlService;

typedef struct
{
    uint16_t wN_Cs;           /* Dlai entre 2 blocs // Separation time */
    uint16_t wN_As;           /* Dlai max de transmission cot transmetteur // Time for transmission (transmitter side) */
    uint16_t wN_Cr;           /* Dlai jusqu' rception du CF // Time until reception of next CF */
    uint16_t wP2min;          /* Dlai REQ / REP  MASTER : time-out UCE : [50-500ms] // Time out between master request and slave(s) response(s) */
    uint16_t wP2max;          /* Dlai REQ / REP  MASTER : time-out UCE : [50-500ms] // Time out between master request and slave(s) response(s) */
    uint16_t uwReserved1;		   // Reserved for future use
    uint16_t uwReserved2;		   // Reserved for future use
    uint16_t uwReserved3;		   // Reserved for future use
} tNwlParam;

#define NWL_LIN_NO_EVENT    0x0000  /* Pas de remont des vnements LIN // LIN events are ignored */
#define NWL_LIN_EVENT       0x0001  /* Remont des vnements LIN // LIN events are stored in LIN FIFO */
#define NWL_FF_NO_EVENT     0x0000  /* Pas de remont des vnements FF // FF events are ignored */
#define NWL_FF_EVENT        0x0002  /* Remont des vnements FF // FF events are stored in NWL FIFO */

typedef struct
{
    tNwlService     eNwlService;    /* Sens de la requte // Networw services */
    uint16_t uwReserved1;		   // Reserved for future use
    uint16_t uwReserved2;		   // Reserved for future use
    uint16_t  wParam;         /* Paramtres supplmentaires // Further parameters */
} tNwlConfig;

typedef struct
{
    uint16_t  wNad;           /* Identificateur du noeud // Node address */
    uint32_t   dwReserved1;    /* Rserv pour utilisation future              // Reserved */
    uint32_t   dwReserved2;    /* Rserv pour utilisation future              // Reserved */
} tNwlAddr;

typedef struct
{
    uint16_t  wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t   bData[NWL_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tNwlMsg;

typedef enum
{
    NWL_NO_ERR              =   0x0000, /* Pas d'erreur                                 // No error */
    NWL_ERR_TOUT_AS         =   0x0001, /* Time out AS                                  // AS Time out */
    NWL_ERR_TOUT_CR         =   0x0002, /* Time out CR                                  // CR Time out */
    NWL_ERR_TOUT_P2         =   0x0003, /* Time out P2                                  // P2 Time out */
    NWL_ERR_SN              =   0x0004, /* Squence invalide                            // Invalid SN */
    NWL_ERR_FIFO_OVF        =   0x0005, /* Plus de place dans la fifo de transmission   // Fifo overflow */
    NWL_ERR_MEMORY          =   0x0006, /* Manque d'espace mmoire                      // Not enough memory */
    NWL_ERR_INV_PDU         =   0x0007, /* Format de PDU invalide                       // Invalid PDU format */
    NWL_ERR_INV_STATE       =   0x0008  /* Etat de rception incorrecte                 // Invalid State sequence */
} tNwlError;

typedef struct
{
    uint16_t  wBus;               /* Numro de bus                                // Bus number */
    uint16_t  wChannel;           /* Numro de canal                              // Channel number */
    tMuxTypeEvent   eTypeEvent;         /* Type d'vnement retourn  l'application    // Event type */
    uint16_t  wNad;               /* Identificateur du message                    // LIN identifier value */
    uint32_t   dwTimeStamp;        /* Heure de l'vnement en multiple de 0.1 ms   // Time of event in 100 Sec */
    uint16_t  wTimePrecision;     /* Prcision de la datation                     // Time accuracy */
    tNwlService     eService;           /* Service de la requte                        // NWL services */
    tNwlError       eError;             /* Type d'erreur                                // Error type */
    uint32_t   dwReserved1;        /* Rserv pour utilisation future              // Reserved */
    uint32_t   dwReserved2;        /* Rserv pour utilisation future              // Reserved */
    uint16_t  wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t   bData[NWL_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tNwlEvent;

/* Etat de la voie // Channel State */
#define NWL_CHANNEL_STATE_STARTED         0x0001  /* Canal dmarr                            // Channel is activated */
#define NWL_CHANNEL_STATE_BUSY            0x0002  /* Canal en cours de communication          // Channel is currently transmitting ou receiving */

/*******************************************************************************
; Routines de segmentations ISO 15765-2 // ISO 15765-2 prototypes
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL
/* Nbre de canaux de communication disponible                               // Channel communicaion available */
_MUXSPEC tMuxStatus _MUXAPI NwlGetChannelCount(uint16_t wCard, uint16_t wBus, uint16_t *wChannelCount);
/* Ouverture d'un canal de communication                                    // Open a channel communicaion */
_MUXSPEC tMuxStatus _MUXAPI NwlChannelOpen(uint16_t wCard, uint16_t wBus, uint16_t *wChannel);
/* Configuration d'un canal de communication                                // Channel communicaion configuration */
_MUXSPEC tMuxStatus _MUXAPI NwlChannelConfig(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwlConfig *hNwlChannelConfig);
/* Paramtres de communication d'un canal                                   // Channel comm. parameter */
_MUXSPEC tMuxStatus _MUXAPI NwlChannelParam(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwlParam *hNwlChannelParam);
/* Paramtres les adresses d'un canal                                       // Channel addr. parameter */
_MUXSPEC tMuxStatus _MUXAPI NwlChannelAddr(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwlAddr *hNwlChannelAddr);
/* Autorise la communication sur le canal                                   // Channel start communication */
_MUXSPEC tMuxStatus _MUXAPI NwlChannelStart(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
/* Arrte la communication sur le canal                                     // Channel stop communication */
_MUXSPEC tMuxStatus _MUXAPI NwlChannelStop(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
/* Ferme le canal de communication                                          // Close a channel communication */
_MUXSPEC tMuxStatus _MUXAPI NwlChannelClose(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
/* Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application */
_MUXSPEC tMuxStatus _MUXAPI NwlSetNotification(uint16_t wCard, uint16_t wBus, void * hWinEvent);
/* Dmarrage de la communication                                            // Start communication */
_MUXSPEC tMuxStatus _MUXAPI NwlActivate(uint16_t wCard, uint16_t wBus);
/* Etat du bus decommunication                                              // Bus state communication */
_MUXSPEC tMuxStatus _MUXAPI NwlIsBusActive(uint16_t wCard, uint16_t wBus, uint16_t *wState);
/* Arrt de la communication                                                // Stop communication */
_MUXSPEC tMuxStatus _MUXAPI NwlDeactivate(uint16_t wCard, uint16_t wBus);
/* Emission d'un message                                                    // Transmit a message */
_MUXSPEC tMuxStatus _MUXAPI NwlChannelSendMsg(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwlMsg *hNwlChannelMsg);
/* Rception d'un message                                                    // Receive a message */
_MUXSPEC tMuxStatus _MUXAPI NwlChannelReceiveMsg(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
/* Rcupration d'un vnement en provenance du rseau                      // Get an event from DLL */
_MUXSPEC tMuxStatus _MUXAPI NwlGetEvent(uint16_t wCard, uint16_t wBus, tNwlEvent *hNwlEvent);
/* Etat de la FIFO                                                          // Counts of event in the receive queue */
_MUXSPEC tMuxStatus _MUXAPI NwlGetFifoRxLevel(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
/* Etat du canal de communication                                           // Channel communication state */
_MUXSPEC tMuxStatus _MUXAPI NwlGetChannelState(uint16_t wCard, uint16_t wBus, uint16_t wChannel, uint16_t *wChannelState, tNwlError *eLastTxStatus);
#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tNwlGetChannelCount)(uint16_t wCard, uint16_t wBus, uint16_t *wChannelCount);
typedef tMuxStatus (__stdcall * tNwlChannelOpen)(uint16_t wCard, uint16_t wBus, uint16_t *wChannel);
typedef tMuxStatus (__stdcall * tNwlChannelConfig)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwlConfig *hNwlChannelConfig);
typedef tMuxStatus (__stdcall * tNwlChannelParam)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwlParam *hNwlChannelParam);
typedef tMuxStatus (__stdcall * tNwlChannelAddr)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwlAddr *hNwlChannelAddr);
typedef tMuxStatus (__stdcall * tNwlChannelStart)(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
typedef tMuxStatus (__stdcall * tNwlChannelStop)(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
typedef tMuxStatus (__stdcall * tNwlChannelClose)(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
typedef tMuxStatus (__stdcall * tNwlSetNotification)(uint16_t wCard, uint16_t wBus, void * hWinEvent);
typedef tMuxStatus (__stdcall * tNwlActivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tNwlIsBusActive)(uint16_t wCard, uint16_t wBus, uint16_t *wState);
typedef tMuxStatus (__stdcall * tNwlDeactivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tNwlChannelSendMsg)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, tNwlMsg *hNwlChannelMsg);
typedef tMuxStatus (__stdcall * tNwlChannelReceiveMsg)(uint16_t wCard, uint16_t wBus, uint16_t wChannel);
typedef tMuxStatus (__stdcall * tNwlGetEvent)(uint16_t wCard, uint16_t wBus, tNwlEvent *hNwlEvent);
typedef tMuxStatus (__stdcall * tNwlGetFifoRxLevel)(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
typedef tMuxStatus (__stdcall * tNwlGetChannelState)(uint16_t wCard, uint16_t wBus, uint16_t wChannel, uint16_t *wChannelState, tNwlError *eLastTxStatus);
#endif
#ifdef __cplusplus
	}
#endif

/*******************************************************************************
; Dclaration pour les routines VAN  // VAN functions
*******************************************************************************/
#define	VAN_MAX_DATA	        		28		/* Nbre de donnes max VAN                      // Maximum VAN data length */

#define VAN_PERIODIC_PARAM_ENABLE		1		/* Active la priodique							// Enable periodic frame */
#define VAN_PERIODIC_PARAM_DISABLE		0		/* Desactive la periodique						// Disable periodic frame */
#define VAN_PERIODIC_PARAM_WITHEVENTS	2		/* Active la remonte des vnements			// Enable the events */
#define VAN_PERIODIC_PARAM_NOEVENTS		0		/* Desactive la remonte des vnements			// Disable the events */

typedef enum
{
    VAN_OPER_ANA_FIFO       =   0,      /* Mode analyse, stockage fifo                  // Analyse mode, event is stored in fifo mode */
    VAN_OPER_ANA_BUFF       =   1,      /* Mode analyse, stockage buffer                // Analyse mode, event is stored in buffer mode */
    VAN_OPER_SIMU_FIFO      =   2,      /* Mode simulation, stockage fifo               // Simulation mode, event is stored in fifo mode */
    VAN_OPER_SIMU_BUFF      =   3       /* Mode simulation, stockage buffer             // Simulation mode, event is stored in buffer mode */
} tVanOperMode;

typedef struct
{
    tVanOperMode    eVanOperMode;       /* Type d'interface avec l'application          // Operating mode with API */
    uint16_t  wFifoSize;          /* Taille de la FIFO                            // FIFO Size */
} tVanOper;

typedef enum
{
    VAN_BAUD_5      =   5208L,	    	/* 5,21  kTS */
    VAN_BAUD_7	    =   7812L,	    	/* 7,81  kTS */
    VAN_BAUD_10	    =   10416L,	    	/* 10,42 kTS */
    VAN_BAUD_15	    =   15625L,	    	/* 15,63 kTS */
    VAN_BAUD_20	    =   20833L,	    	/* 20,83 kTS */
    VAN_BAUD_31	    =   31250L,	    	/* 31,25 kTS */
    VAN_BAUD_41	    =   41666L,	    	/* 41,57 kTS */
    VAN_BAUD_62	    =   62500L,		    /* 62,5  kTS */
    VAN_BAUD_83	    =   83333L,		    /* 83,33 kTS */
    VAN_BAUD_125	=   125000L,		/* 125   kTS */
    VAN_BAUD_166	=   166666L,		/* 166,67kTS */
    VAN_BAUD_250	=   250000L,		/* 250   kTS */
    VAN_BAUD_333	=   333333L,		/* 333,33kTS */
    VAN_BAUD_500	=   500000L,		/* 500   kTS */
    VAN_BAUD_666	=   666666L,		/* 666,67kTS */
    VAN_BAUD_1000	=   1000000L 		/* 1000  kTS */
} tVanBaudRate;
typedef enum
{
    VAN_LINE_NOT_INVERTED   =   0,      /* Ligne non inverse                           // Line is not inverted */
    VAN_LINE_INVERTED       =   1       /* Ligne inverse                               // Line is inverted */
} tVanLine;
typedef enum
{
    VAN_CODING_MANCHESTER   =   0,      /* Codage manchester comprim                   // Data is transmitted or received in enhanced manchester code */
    VAN_CODING_PULSED       =   1       /* Codage mode puls                            // Data is transmitted or received in pulsed mode */
} tVanCoding;
typedef enum
{
    VAN_MODULE_SYNCHRONOUS  =   0,      /* Module synchrone (en attente de SOF)         // Synchronous access module (ECU is waiting SOF before transmitted) */
    VAN_MODULE_AUTONOMOUS   =   1       /* Module autonome                              // Autonomous module */
} tVanModuleType;
typedef enum
{
    VAN_FALSE               =   0,      /* Boolen faux                                 // FALSE */
    VAN_TRUE                =   1       /* Boolen vrai                                 // TRUE  */
} tVanBoolean;
typedef enum
{
    VAN_RX_FORCED_RXD0      =   0,      /* Communication fore sur RXD0                // Communication is forced on RXD0 (differential) */
    VAN_RX_FORCED_RXD1      =   2,      /* Communication fore sur RXD1                // Communication is forced on RXD2 (datab) */
    VAN_RX_FORCED_RXD2      =   1,      /* Communication fore sur RXD2                // Communication is forced on RXD1 (data) */
    VAN_RX_AUTOMATIC        =   3       /* Communication en mode automatique            // Automatic selection */
} tVanRxMode;
typedef enum
{
    VAN_SVC_TRANSMIT_DATA   =   0,      /* Transmission de donnes                      // Transmit message */
    VAN_SVC_RECEIVE_DATA    =   1,      /* Rception de donnes                         // Receive message */
    VAN_SVC_REQUEST_IFR     =   2,      /* Demande de rponse dans la trame             // Reply IFR message */
    VAN_SVC_UPDATE_IFR      =   3,      /* Mise  jour pour rponse dans la trame       // Update IFR (without transmission) */
    VAN_SVC_TX_DIFFERED     =   4,      /* Transmission d'une rponse diffre          // Transmit differed message */
    VAN_SVC_RX_DIFFERED     =   5       /* Rception d'une rponse diffre             // Receive differed message */
} tVanService;
typedef enum
{
    VAN_NO_ERR              =   0x0000, /* Pas d'erreur                                 // No error */
    VAN_ERR_BOC             =   0x0001, /* Buffer occup                                // Buffer occupied */
    VAN_ERR_BOV             =   0x0002, /* Dpassement du buffer                        // Buffer overflow */
    VAN_ERR_TYPE            =   0x0003, /* Erreur de service VAN                        // Erreur type mismatch */
    VAN_ERR_FCSE            =   0x0004, /* Erreur de CRC                                // CRC error */
    VAN_ERR_ACKE            =   0x0005, /* Erreur d'acquittement                        // ACK error */
    VAN_ERR_CV              =   0x0006, /* Viol de code                                 // Code violation */
    VAN_ERR_FV              =   0x0007, /* Viol de trame                                // Frame violation */
    VAN_ERR_NOIFR           =   0x0100  /* Plus de place pour IFR                       // No buffer for IFR */
} tVanError;
typedef enum
{
    VAN_RX_NOMINAL          =   0,      /* Communication en mode diffrentiel           // Nominal mode */
    VAN_RX_FAULT_ON_DATA    =   1,      /* Communication sur Datab                      // Communication on Datab */
    VAN_RX_FAULT_ON_DATAB   =   2,      /* Communication sur Data                       // Communication on Data */
    VAN_RX_MAJOR_ERROR      =   3       /* Pas de communication                         // Major error */
} tVanChipState;
typedef enum
{
    VAN_SLEEP_MODE          =   0,      /* Mise en veille du rseau (Matre)            // VAN sleep (master node) */
    VAN_NO_SLEEP_MODE       =   1       /* Rveil du rseau (Matre)                    // VAN wakeup (master node) */
} tVanSleepMode;
typedef enum
{
    VAN_WAKEUP_MODE         =   1,      /* Rveil du rseau (Esclave)                   // VAN wakeup (slave node) */
    VAN_NO_WAKEUP_MODE      =   0       /* Pas de rveil du rseau (Esclave)            // No action */
} tVanWakeUpMode;

typedef struct
{
    uint16_t  wBusLoad;           /* Valeur de la charge bus                      // Bus load value */
    uint16_t  wReserved;          /* Rserv pour utilisation future              // Reserved for future use */
    uint32_t   dwTxRq;             /* Demande de transmission                      // Tx request */
    uint32_t   dwTxOk;             /* Fin de transmission correcte                 // End of Tx Ok */
    uint32_t   dwTxErr;            /* Fin de transmission incorrecte               // Error end of tx */
    uint32_t   dwRxOk;             /* Rception correcte                           // Rx Ok */
    uint32_t   dwRxErr;            /* Rception en erreur                          // Error during reception */
    uint32_t   dwErrBoc;           /* Buffer occup                                // Buffer occupied error */
    uint32_t   dwErrBov;           /* Dpassement de buffer                        // Buffer overflow error */
    uint32_t   dwErrType;          /* Erreur de service VAN                        // Type mismatch error */
    uint32_t   dwErrFcse;          /* Erreur de CRC                                // CRC Error */
    uint32_t   dwErrAcke;          /* Erreur d'acquittement                        // ACK error */
    uint32_t   dwErrCv;            /* Viol de code                                 // Code violation */
    uint32_t   dwErrFv;            /* Viol de trame                                // Frame violation */
    uint32_t   dwErrFifoOvf;       /* Perte de message                             // FIFO Rx overflow */
} tVanStat;

typedef struct
{
    tVanBaudRate    eBaudRate;          /* Dbit du bus                                 // Baud rate */
    tVanLine        eLineInvertTx;      /* Inversion de la ligne TX                     // Invert TxD output */
    tVanLine        eLineInvertRx;      /* Inversion de la ligne RX                     // Invert Rx input */
    tVanCoding      eLineCoding;        /* Mode puls ou manchester                     // Enhanced manchester or plused mode */
    uint16_t  wMaxRetries;        /* Nbre de rptition                           // Number of retries */
    tVanModuleType  eModuleType;        /* Type de module                               // Module type */
    tVanBoolean     eTIPEnable;         /* Validation du diag en mission               // Enable transmission diagnosis */
    tVanBoolean     eSDCEnable;         /* Validation de l'horloge SDC                  // Enable synchronous diagnosis clock */
    uint16_t  wSDCValue;          /* Valeur de l'horloge SDC                      // Diagnosis clock value */
    tVanRxMode      eRxMode;            /* Mode de rception                            // Rx Line mode operation */
} tVanBus;

typedef struct
{
    uint16_t  wBus;               /* Numro de bus                                // Bus number */
    uint16_t  wHandleMsg;         /* Index de comm. sur le msg (Infos DLL)        // Communication handle returned by DLL */
    tMuxTypeEvent   eTypeEvent;         /* Type d'vnement retourn  l'application    // Event type */
    uint16_t  wIdent;             /* Identificateur du message                    // VAN identifier value */
    uint32_t   dwTimeStamp;        /* Heure de l'vnement en multiple de 0.1 ms   // Time of event in 100 Sec */
    uint16_t  wTimePrecision;     /* Prcision de la datation                     // Time accuracy */
    tVanService     eService;           /* Service de la requte                        // VAN services */
    tVanBoolean     eAckEnable;         /* Acquittement                                 // Acknowledgment indication */
    tVanError       eError;             /* Type d'erreur                                // Error type */
    tVanChipState   eChipState[2];      /* Etat de la comm. des composants 1 et 2       // Current Rx. line mode*/
    uint16_t  wBusLoad;           /* Valeur de la charge bus                      // Bus load value */
    uint32_t   dwReserved1;        /* Rserv pour utilisation future              // Reserved */
    uint32_t   dwReserved2;        /* Rserv pour utilisation future              // Reserved */
    uint16_t  wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t   bData[VAN_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tVanEvent;

typedef struct
{
    uint16_t  wHandleMsg;         /* Index de comm. sur le msg (Infos DLL)        // Communication handle returned by DLL */
    uint16_t  wIdent;             /* Identificateur VAN du message                // VAN Identifier value */
    uint16_t  wMask;				/* Masque appos sur l'identificateur           // Mask associated with VAN identifier */
    tVanService     eService;           /* Service de la requte                        // VAN services */
    tVanBoolean     eAckEnable;         /* Demande d'acquittement                       // Request acknowlegment */
    uint32_t   lPeriod;            /* Periodicit en ms                            // Period */
    tVanBoolean     eLevel3Enable;      /* Gestion des couches de communication         // Enable communication management */
    uint16_t  wNumChip;           /* Num. de composant li avec le msg (Infos DLL)// Chip number associated with the message returned by DLL */
    uint16_t  wNumChannel;        /* Num. de canal dans le composant (Infos DLL)  // Channel number inside the chip returned by DLL */
    uint16_t  wMaxSize;           /* Taille max par message (Infos DLL)           // Maximum size (Reserved for DLL) */
    uint32_t   dwReserved1;        /* Mettre  0 (rserv pour utilisation future) // Must be set to 0 (Reserved for future used) */
    uint32_t   dwReserved2;        /* Mettre  0 (rserv pour utilisation future) // Must be set to 0 (Reserved for future used) */
    uint16_t  wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t   bData[VAN_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tVanMsg;

typedef struct
{
	uint16_t	wOffset;			/* Offset de la priodique						// Periodic offset */
	uint16_t	wParam;				/* Paramtre de la priodique					// Periodic parameters */
	tVanMsg			hVanMsg;			/* Message  emettre							// Frame to send */
} tVanPeriodicMsg;

typedef struct
{
    uint16_t  wSizeTx;            /* Taille max. des tx et demande d'IFR          // Maximum data length for Tx and reply request */
    uint16_t  wSizeRx;            /* Taille max. des rx (donnes et diffre)     // Maximum data length for Rx data and differed */
    uint16_t  wSizeIfr;           /* Taille max. des IFR                          // Maximum data length for IFR */
    uint16_t  wFiltIdent;         /* Identificateur pour filtrage                 // Acceptance code */
    uint16_t  wFiltMask;          /* Masque pour filtrage                         // Acceptance mask */
    tVanBoolean     eAckEnable;         /* Validation / dvalidation de l'acquittement  // Enable or disable acknowlegment */
    tVanBoolean     eRxAll;             /* Rception des ident non dclars             // All messages or only programmed message are given to the application */
    uint16_t  wSpecialModes;      /* Rserv pour utilisation futures             // Reserved for future used */
} tVanParam;

/*******************************************************************************
; Routines VAN // VAN prototypes
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL
/* Configuration du mode de fonctionnement des buffers                      // Select the operating mode */
_MUXSPEC tMuxStatus _MUXAPI VanConfigOper(uint16_t wCard, uint16_t wBus, tVanOper *hVanOper);
/* Configuration du bus                                                     // Bus parameter */
_MUXSPEC tMuxStatus _MUXAPI VanConfigBus(uint16_t wCard, uint16_t wBus, tVanBus *hVanBus);
/* Configuration des paramtres supplmentaires                             // Extra parameter */
_MUXSPEC tMuxStatus _MUXAPI VanConfigParam(uint16_t wCard, uint16_t wBus, tVanParam *hVanParam);
/* Configuration des statistques                                            // Statistics configuration */
_MUXSPEC tMuxStatus _MUXAPI VanConfigStat(uint16_t wCard, uint16_t wBus, uint16_t wBusLoadTime);
/* Cration des messages de communication                                   // Messages configuration */
_MUXSPEC tMuxStatus _MUXAPI VanCreateMsg(uint16_t wCard, uint16_t wBus, tVanMsg *hVanMsg);
/* Cration de message priodique                                           // Periodic Messages configuration */
_MUXSPEC tMuxStatus _MUXAPI VanConfigPeriodic(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tVanMsg *hVanMsg);
/* Configuration d'une liste de message periodique							// Periodic messages list configuration */
_MUXSPEC tMuxStatus _MUXAPI VanConfigPeriodicList(uint16_t wCard, uint16_t wBus, uint16_t wPeriodicCount, tVanPeriodicMsg *hVanPeriodicMsgList);
/* Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application */
_MUXSPEC tMuxStatus _MUXAPI VanSetNotification(uint16_t wCard, uint16_t wBus, void * hWinEvent);
/* Dmarrage de la communication                                            // Start communication */
_MUXSPEC tMuxStatus _MUXAPI VanActivate(uint16_t wCard, uint16_t wBus);
/* Etat du bus decommunication                                              // Bus state communication */
_MUXSPEC tMuxStatus _MUXAPI VanIsBusActive(uint16_t wCard, uint16_t wBus, uint16_t *wState);
/* Arrt de la communication                                                // Stop communication */
_MUXSPEC tMuxStatus _MUXAPI VanDeactivate(uint16_t wCard, uint16_t wBus);
/* Emission d'un message ou mise  jour pour rponse dans la trame          // Transmit a message or update an IFR */
_MUXSPEC tMuxStatus _MUXAPI VanSendMsg(uint16_t wCard, uint16_t wBus, tVanMsg *hVanMsg);
/* Emission de plusieurs message											// Transmit several messages */
_MUXSPEC tMuxStatus _MUXAPI VanSendMsgList(uint16_t wCard, uint16_t wBus, uint16_t wMsgCount, tVanMsg *hVanMsgList);
/* Rcupration d'un vnement en provenance du rseau                      // Get an event from DLL */
_MUXSPEC tMuxStatus _MUXAPI VanGetEvent(uint16_t wCard, uint16_t wBus, tVanEvent *hVanEvent);

/* Lecture des statistiques                                                 // Statistics information */
_MUXSPEC tMuxStatus _MUXAPI VanGetStat(uint16_t wCard, uint16_t wBus, tVanStat *hVanStat);
/* Lecture du mode de communication des composants                          // Give information about Rx communication mode */
_MUXSPEC tMuxStatus _MUXAPI VanGetBusState(uint16_t wCard, uint16_t wBus, tVanChipState *eVanChip0State, tVanChipState *eVanChip1State);
/* Active la broche sleep de l'interface de ligne REMX (Matre)             // REMX SleepB pins setup (used by a master node to sleep or wakeup the bus */
_MUXSPEC tMuxStatus _MUXAPI VanSetSleepMode(uint16_t wCard, uint16_t wBus, tVanSleepMode eVanSleepMode);
/* Active la broche wake up de l'interface de ligne REMX (Esclave)          // REMX WakeUp pins setup (used by a slave node to wakeup the bus */
_MUXSPEC tMuxStatus _MUXAPI VanSetWakeUpMode(uint16_t wCard, uint16_t wBus, tVanWakeUpMode eVanWakeUpMode);
/* Rcupre l'tat de la broche SREG de l'interface de ligne                // REMX SREG pins status (used by a master node to power slave) */
_MUXSPEC tMuxStatus _MUXAPI VanGetSleepMode(uint16_t wCard, uint16_t wBus, tVanSleepMode *eVanSleepMode);
/* Validation / dvalidation du diagnostic en mission                      // Diagnostic when transmission in progress */
_MUXSPEC tMuxStatus _MUXAPI VanSetTIP(uint16_t wCard, uint16_t wBus, tVanBoolean eTIPEnable);
/* Retourne la valeur en fonction du dbit et de l'horloge en dsire       // Returned SDC value depending on baudrate and SDC time desired */
_MUXSPEC tMuxStatus _MUXAPI VanGetSDCValue(tVanBaudRate eBaudRate,uint32_t dwSDCTimeMs,uint32_t *dwSDCValue);
/* Purge de la file d'attente de rception                                  // Flush FIFO rx */
_MUXSPEC tMuxStatus _MUXAPI VanClearFifoRx(uint16_t wCard, uint16_t wBus);
/* Etat de la FIFO                                                          // Counts of event in the receive queue */
_MUXSPEC tMuxStatus _MUXAPI VanGetFifoRxLevel(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);

/* Lecture d'un octet sur un composant VAN                                  // Read byte from the VAN controller */
_MUXSPEC tMuxStatus _MUXAPI VanReadByte(uint16_t wCard, uint16_t wBus, uint16_t wChip, uint16_t wOffset,uint8_t *bData);
/* Ecriture d'un octet sur un composant VAN                                 // Write byte to the VAN controller */
_MUXSPEC tMuxStatus _MUXAPI VanWriteByte(uint16_t wCard, uint16_t wBus, uint16_t wChip, uint16_t wOffset,uint8_t bData);
#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tVanConfigOper)(uint16_t wCard, uint16_t wBus, tVanOper *hVanOper);
typedef tMuxStatus (__stdcall * tVanConfigBus)(uint16_t wCard, uint16_t wBus, tVanBus *hVanBus);
typedef tMuxStatus (__stdcall * tVanConfigParam)(uint16_t wCard, uint16_t wBus, tVanParam *hVanParam);
typedef tMuxStatus (__stdcall * tVanConfigStat)(uint16_t wCard, uint16_t wBus, uint16_t wBusLoadTime);
typedef tMuxStatus (__stdcall * tVanCreateMsg)(uint16_t wCard, uint16_t wBus, tVanMsg *hVanMsg);
typedef tMuxStatus (__stdcall * tVanConfigPeriodic)(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tVanMsg *hVanMsg);
typedef tMuxStatus (__stdcall * tVanConfigPeriodicList)(uint16_t wCard, uint16_t wBus, uint16_t wPeriodicCount, tVanPeriodicMsg *hVanPeriodicMsgList);
typedef tMuxStatus (__stdcall * tVanSetNotification)(uint16_t wCard, uint16_t wBus, void * hWinEvent);
typedef tMuxStatus (__stdcall * tVanActivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tVanIsBusActive)(uint16_t wCard, uint16_t wBus, uint16_t *wState);
typedef tMuxStatus (__stdcall * tVanDeactivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tVanSendMsg)(uint16_t wCard, uint16_t wBus, tVanMsg *hVanMsg);
typedef tMuxStatus (__stdcall * tVanSendMsgList)(uint16_t wCard, uint16_t wBus, uint16_t wMsgCount, tVanMsg *hVanMsgList);
typedef tMuxStatus (__stdcall * tVanGetEvent)(uint16_t wCard, uint16_t wBus, tVanEvent *hVanEvent);
typedef tMuxStatus (__stdcall * tVanGetStat)(uint16_t wCard, uint16_t wBus, tVanStat *hVanStat);
typedef tMuxStatus (__stdcall * tVanGetBusState)(uint16_t wCard, uint16_t wBus, tVanChipState *eVanChip0State, tVanChipState *eVanChip1State);
typedef tMuxStatus (__stdcall * tVanSetSleepMode)(uint16_t wCard, uint16_t wBus, tVanSleepMode eVanSleepMode);
typedef tMuxStatus (__stdcall * tVanSetWakeUpMode)(uint16_t wCard, uint16_t wBus, tVanWakeUpMode eVanWakeUpMode);
typedef tMuxStatus (__stdcall * tVanGetSleepMode)(uint16_t wCard, uint16_t wBus, tVanSleepMode *eVanSleepMode);
typedef tMuxStatus (__stdcall * tVanSetTIP)(uint16_t wCard, uint16_t wBus, tVanBoolean eTIPEnable);
typedef tMuxStatus (__stdcall * tVanGetSDCValue)(tVanBaudRate eBaudRate,uint32_t dwSDCTimeMs,uint32_t *dwSDCValue);
typedef tMuxStatus (__stdcall * tVanClearFifoRx)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tVanGetFifoRxLevel)(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
typedef tMuxStatus (__stdcall * tVanReadByte)(uint16_t wCard, uint16_t wBus, uint16_t wChip, uint16_t wOffset,uint8_t *bData);
typedef tMuxStatus (__stdcall * tVanWriteByte)(uint16_t wCard, uint16_t wBus, uint16_t wChip, uint16_t wOffset,uint8_t bData);
#endif

#ifdef __cplusplus
	}
#endif

/*******************************************************************************
; Dclaration pour les routines ISO9141 // ISO 9141 definitions
*******************************************************************************/
#define	ISO_MAX_DATA	        		260		            /* Nbre de donnes max KWP2000-2F           // Maximum KWP2000-2F message length */
#define	ISO14230_MAX_DATA	    		(ISO_MAX_DATA-5)	/* Nbre de donnes max ISO14230             // Maximum ISO14230 message length */

#define ISO_PERIODIC_PARAM_ENABLE		1		/* Active la priodique							// Enable periodic frame */
#define ISO_PERIODIC_PARAM_DISABLE		0		/* Desactive la periodique						// Disable periodic frame */
#define ISO_PERIODIC_PARAM_WITHEVENTS	2		/* Active la remonte des vnements			// Enable the events */
#define ISO_PERIODIC_PARAM_NOEVENTS		0		/* Desactive la remonte des vnements			// Disable the events */

typedef enum
{
	ISO_OPER_TESTER         =   0,      /* Mode testeur                             	// Tester mode */
	ISO_OPER_ANALYZER       =   1,      /* Mode analyseur                           	// Analyzer mode */
	ISO_OPER_SIMU           =   2,      /* Mode simulation d'UCE                    	// Simulation mode */
	ISO_OPER_FREE           =   3       /* Mode libre                    	        // Free mode */
} tIsoOperMode;

typedef struct
{
	tIsoOperMode    eIsoOperMode;       /* Type d'interface avec l'application          // Operating mode with API */
    uint16_t  wFifoSize;          /* Taille de la FIFO                            // FIFO Size */
} tIsoOper;

typedef struct
{
    uint16_t  wFiltTP;			/* Filtre du TesterPresent                      // Tester Present filter */
    uint16_t  wSpecialModes;      /* Rserv pour utilisation futures             // Reserved for future used */
} tIsoParam;

typedef struct
{
    uint16_t  wBusLoad;           /* Valeur de la charge bus                      // Bus load value */
    uint16_t  wReserved;          /* Rserv pour utilisation future              // Reserved for future use */
    uint32_t   dwTxRq;             /* Demande de transmission                      // Tx request */
    uint32_t   dwTxOk;             /* Fin de transmission correcte                 // End of Tx Ok */
    uint32_t   dwTxErr;            /* Fin de transmission incorrecte               // Error end of tx */
    uint32_t   dwRxOk;             /* Rception correcte                           // Rx Ok */
    uint32_t   dwRxErr;            /* Rception en erreur                          // Error during reception */
    uint32_t   dwErrBreak;         /* Erreur de type Break                         // Break error */
    uint32_t   dwErrFE;            /* Erreur de format                             // Framing error */
    uint32_t   dwErrPE;            /* Erreur de parit                             // Parity error */
    uint32_t   dwErrOE;            /* Erreur de dpassement                        // Overrun error */
    uint32_t   dwErrFifoOvf;       /* Perte de message                             // FIFO Rx overflow */
} tIsoStat;

typedef enum
{
    ISO_PARITY_NOCHANGE 	=   0,      /* Adresse envoye telle quelle             // 8 bits address - transmit without any change */
    ISO_PARITY_ODD          =   1,      /* Force la parit impaire                  // 7 bits address - transmit with odd parity */
    ISO_PARITY_EVEN         =   2       /* Force la parit paire                    // 7 bits address - transmit with even parity */
} tIso5BdsAddrParity;

typedef enum
{                                       /* Dbit possible avec l'UART               // Serial baud rate */
    ISO_BAUD_5	    	=   5,
    ISO_BAUD_9600	    =   9600,
    ISO_BAUD_10400	    =   10400,
	ISO_BAUD_19200	    =   19200,
	ISO_BAUD_38400		=	38400,
    ISO_BAUD_62500	    =   62500,
    ISO_BAUD_125000     =   125000
} tIsoBaudRate;

typedef struct
{
    /* Paramtres pour initialisation  5 bauds */
    uint16_t      wW0;            /* Dlai bus idle avant init. TESTER > 300ms    UCE : time-out (attente ligne K stable avant mission code  5 bauds) */
                                        /* Bus high idle time prior to transmission of address byte */
    uint16_t      wW1;            /* Dlai avant code synchro   TESTER : time-out UCE : [60,250ms] */
                                        /* Time out between address byte and synchronisation pattern */
    uint16_t      wW2;            /* Dlai avant mot clef1      TESTER : time-out UCE : [5,50ms] */
                                        /* Time out between synchronisation pattern and key byte 1 */
    uint16_t      wW3;            /* Dlai avant mot clef2      TESTER : time-out UCE : [0,20ms] */
                                        /* Time out between key byte 1 and key byte 2 */
    uint16_t      wW4a;           /* Dlai avant mot clef2B     TESTER : [25,50ms]UCE : time-out */
                                        /* Time between key byte 2 and inverted key byte 2 */
    uint16_t      wW4b;           /* Dlai avant code AdresB    TESTER : time-out UCE : [25,50ms] */
                                        /* Time out between inv. key byte 2 and inv. address */
    uint16_t      wW5;            /* Dlai avant rpt. init    TESTER > 300ms    UCE : time-out (attente ligne K stable avant mission code  5 bauds) */
                                        /* Time out before retry of initialization */
    uint16_t      wP0;            /* Dlai avant 1re requte   TESTER : [5,250ms]UCE : time-out */
                                        /* Time out between initialization and the first request */
    tIso5BdsAddrParity  eParity;        /* Codage de l'adresse  5 bauds */
                                        /* Parity for 5bauds address during initialisation */
    /* Paramtres pour initialisation rapide */
    uint16_t      wTIdle;         /* Dlai bus idle avant init. TESTER > 300ms    UCE : time-out (attente ligne K stable avant mission squence d'init) */
                                        /* Bus high idle time prior to transmission of init. */
    uint16_t      wTInitL;        /* Dure du pattern ligne L   TESTER : 25ms */
                                        /* Time for wakeup pattern bus low */
    uint16_t      wTWup;          /* Dure totale de la squnce TESTER : 50ms */
    /* Paramtre de communication */
    tIsoBaudRate        eBaudRate;      /* Dbit (10400 bauds) */
                                        /* Serial baud rate communication */
    uint16_t      wP1;            /* Time-out interbyte REP     TESTER : time-out UCE : [0-10ms] */
                                        /* Inter byte time out for ECU response */
    uint16_t      wP2;            /* Dlai REQ / REP            TESTER : time-out UCE : [1-250ms] */
                                        /* Time out between tester request and ECU response(s) */
    uint16_t      wP3;            /* Dlai REP / REQ            TESTER : [1,5000ms]TypeI ou [5,5000ms]TypeII UCE : time-out[4750,5250ms] */
                                        /* Time between ECU response and tester request */
    uint16_t      wP4;            /* Time-out interbyte REQ     TESTER : [0,10ms]TypeI ou [5,10ms]TypeII UCE : time-out[20-25ms] */
                                        /* Inter byte time for tester request */
} tIsoBus;

typedef enum
{
    ISO_MSG_NORMAL      =   0x00,       /* Emission d'un msg                        // Message transmission */
    ISO_MSG_INIT5BDS    =   0x01,       /* Emission d'un msg avec une init.  5 bds // Message transmission with 5 bauds init. */
    ISO_MSG_INITFAST    =   0x02,       /* Emission d'un msg avec une init. rapide  // Message transmission with fast init. */
    ISO_MSG_WAITRESP    =   0xFFFF      /* Attente d'une nouvelle rponse sans Tx   // Wait a new frame without reception */
} tIsoTypeMsg;

typedef enum
{
    ISO_HEADER_NOADDR   =   0x00,       /* Aucune information d'adresse             // No address information */
    ISO_HEADER_CARB     =   0x40,       /* Mode d'exception (CARB)                  // Reserved for CARB */
    ISO_HEADER_PHYS     =   0x80,       /* Avec information d'adresse physique      // Physical address */
    ISO_HEADER_FUNCT    =   0xC0        /* Avec information d'adresse fonctionnel   // Functionnal address */
} tIsoTypeHeader;

typedef enum
{
    ISO_NO_ERR              =   0,      /* Pas d'erreur                             // No error */
    ISO_ERR_FE              =   1,      /* Erreur stop bit                          // Framing error */
    ISO_ERR_PE              =   2,      /* Erreur bit de parit                     // Parity error */
    ISO_ERR_OE              =   3,      /* Erreur dpassement                       // Overrun error */
    ISO_ERR_BREAK           =   4,      /* Dtection d'un break                     // Break detection */
	ISO_ERR_NOECHO			=	5,		/* Time out en mission						// Tx time out */
	ISO_ERR_BADECHO			=	6,		/* Echo incorrect							// Bad echo */
    ISO_ERR_TO_SYNCHRO      =   10,     /* Time out code synchro                    // Time out waiting synchro char */
    ISO_ERR_BAD_SYNCHRO     =   11,     /* Valeur du code synchro incorrecte        // Bad Synchro value */
    ISO_ERR_TO_KEY1         =   12,     /* Time out mot clef 1                      // Time out waiting key word 1 char */
    ISO_ERR_BAD_KEY1        =   13,     /* Valeur du mot clef 1 incorrecte          // Bad key word 1 value */
    ISO_ERR_TO_KEY2         =   14,     /* Time out mot clef 2                      // Time out waiting key word 2 char */
    ISO_ERR_BAD_KEY2        =   15,     /* Valeur du mot clef 2 incorrecte          // Bad key word 2 value */
    ISO_ERR_TO_ADDR         =   16,     /* Time out code addresse inverse          // Time out waiting address code */
    ISO_ERR_BAD_ADDR        =   17,     /* Valeur du code adresse incorrecte        // Bad address code value */
    ISO_ERR_TO_RESP         =   18,     /* Time out attente de rponse              // Time out waiting response */
    ISO_ERR_RX_OVER         =   19,     /* Longueur de la rponse trop longue       // Response data length overflow */
    ISO_ERR_TO_RESPn        =   20,     /* Time out attente de multi-rponse        // Time out waiting multiple response */
    ISO_ERR_BAD_LEN         =   21,     /* Longueur de la rponse incorrecte        // Incorrect response data length */
    ISO_ERR_BAD_CRC         =   22      /* CRC de la rponse incorrecte				// Bad CRC response */
} tIsoError;

typedef struct
{
    tIsoTypeMsg     eTypeMsg;           /* Type de message                          // Message type */
    uint16_t  wCodeAddr;          /* Code adresse pour init  5 bauds         // source address for 5 bauds init */
    uint32_t   lPeriod;            /* Priodicit en ms                        // Priod */
    uint16_t  wDataLen;           /* Taille des donnes                       // Data length */
    uint8_t   bData[ISO_MAX_DATA];/* Buffer de donne                         // Data buffer */
} tIsoMsg;

typedef struct
{
    uint16_t  wDataLen;           /* Taille des donnes                       // Data length */
    uint16_t  wTimeOut;           /* Valeur de timeout                        // Timeout value */
    uint8_t   bData[ISO_MAX_DATA];/* Donnes  comparer                       // Data to compare */
    uint8_t   bMask[ISO_MAX_DATA];/* Masque de donne                         // Data Mask */
} tIsoTrigMsg;

typedef struct
{
    tIsoTypeMsg     eTypeMsg;           /* Type de message                          // Message type */
	tIsoTypeHeader	eIsoTypeHeader;		/* Format du message d'entte				// Header format */
    uint32_t   lPeriod;            /* Mettre  0 (rserv utilisation future)  // Must be set to 0 (Reserved for future used) */
	uint16_t  wCodeAddr;          /* Code adresse pour init  5 bauds         // source address for 5 bauds init */
	uint16_t  wSrcAddr;           /* Adresse source							// Source address */
	uint16_t  wDstAddr;           /* Adresse cible							// Dest address */
    uint16_t  wDataLen;           /* Taille des donnes                       // Data length */
    uint8_t   bData[ISO14230_MAX_DATA];/* Buffer de donne                    // Data buffer */
} tIso14230Msg;

typedef struct
{
    uint16_t  wBus;               /* Numro de bus                            // Bus number */
    tMuxTypeEvent   eTypeEvent;         /* Type d'vnement                         // Event type */
    uint32_t   dwTimeStamp;        /* Heure de l'vnement en multiple de 0.1ms// Time of event in 100 Sec */
    uint16_t  wTimePrecision;     /* Prcision de la datation                 // Time accuracy */
    tIsoError       eError;             /* Indication du type d'erreur              // Error type */
    uint8_t   bData;              /* Octet de donne                          // Data */
    uint8_t   bDummy;             /* Octet de remplissage                     // Dummy field */
} tIsoChar;

typedef struct
{
    uint16_t  wBus;               /* Numro de bus                                // Bus number */
    tMuxTypeEvent   eTypeEvent;         /* Type d'vnement                             // Event type */
    uint32_t   dwTimeStamp;		/* Heure de l'vnement en multiple de 0.1ms// Time of event in 100 Sec */
    uint16_t  wTimePrecision;     /* Prcision de la datation                     // Time accuracy */
    tIsoError       eError;             /* Indication du type d'erreur                  // Error type */
    uint16_t  wBusLoad;           /* Valeur de la charge bus                      // Bus load value */
    uint16_t  wKeyWord;           /* Mot clef reu lors de l'init  5 bauds       // Keyword received during 5 bauds init. */
    uint16_t  wReserved1;         /* Rserv pour utilisation future              // Reserved */
    uint32_t   dwReserved2;        /* Rserv pour utilisation future              // Reserved */
    uint16_t  wDataLen;           /* Taille des donnes                           // Data length */
    uint8_t   bData[ISO_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tIsoEvent;

/*******************************************************************************
; Routines ISO9141 // ISO9141 prototypes
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL
/* Configuration du mode de fonctionnement de l'application                 // Select the operating mode */
_MUXSPEC tMuxStatus _MUXAPI IsoConfigOper(uint16_t wCard, uint16_t wBus, tIsoOper *hIsoOper);
/* Configuration des paramtres de communication                            // Bus parameters */
_MUXSPEC tMuxStatus _MUXAPI IsoConfigBus(uint16_t wCard, uint16_t wBus, tIsoBus *hIsoBus);
/* Configuration des paramtres                                             // Uart parameters */
_MUXSPEC tMuxStatus _MUXAPI IsoConfigUart(uint16_t wCard, uint16_t wBus, tUartConfig *hUartConfig);
/* Configuration des paramtres supplmentaires                             // Extra parameter */
_MUXSPEC tMuxStatus _MUXAPI IsoConfigParam(uint16_t wCard, uint16_t wBus, tIsoParam *hIsoParam);
/* Configuration des statistques                                            // Statistics configuration */
_MUXSPEC tMuxStatus _MUXAPI IsoConfigStat(uint16_t wCard, uint16_t wBus, uint16_t wBusLoadTime);
/* Dmarrage de la communication                                            // Start communication */
_MUXSPEC tMuxStatus _MUXAPI IsoActivate(uint16_t wCard, uint16_t wBus);
/* Etat du bus de communication                                             // Bus state communication */
_MUXSPEC tMuxStatus _MUXAPI IsoIsBusActive(uint16_t wCard, uint16_t wBus, uint16_t *wState);
/* Arrt de la communication                                                // Stop communication */
_MUXSPEC tMuxStatus _MUXAPI IsoDeactivate(uint16_t wCard, uint16_t wBus);
/* Cration de message priodique                                           // Periodic Messages configuration */
_MUXSPEC tMuxStatus _MUXAPI IsoConfigPeriodic(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tIsoMsg *hIsoMsg);
/* Cration de message priodique                                           // Periodic Messages configuration */
_MUXSPEC tMuxStatus _MUXAPI Iso14230ConfigPeriodic(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tIso14230Msg *hIso14230Msg);
/* Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application */
_MUXSPEC tMuxStatus _MUXAPI IsoSetNotification(uint16_t wCard, uint16_t wBus, void * hWinEvent);
/* Emission d'un message (requte avec ou sans squence d'initialisation)   // Transmit a message with or without init. sequence */
_MUXSPEC tMuxStatus _MUXAPI IsoSendMsg(uint16_t wCard, uint16_t wBus, tIsoMsg *hIsoMsg);
/* Emission d'un message (requte avec ou sans squence d'initialisation)   // Transmit a message with or without init. sequence */
_MUXSPEC tMuxStatus _MUXAPI Iso14230SendMsg(uint16_t wCard, uint16_t wBus, tIso14230Msg *hIso14230Msg);
/* Rcupration d'un vnement en provenance du bus (mode analyzer)         // Get response event */
_MUXSPEC tMuxStatus _MUXAPI IsoGetEvent(uint16_t wCard, uint16_t wBus, tIsoEvent *hIsoEvent);
/* Attente d'une nouvelle rponse                                           // Wait next response */
_MUXSPEC tMuxStatus _MUXAPI IsoWaitResponse(uint16_t wCard, uint16_t wBus, uint16_t wTimeOut);
/* Attente d'une rponse pr-dfinie et mission d'un message   			// Wait a predefined response before transmitting the request */
_MUXSPEC tMuxStatus _MUXAPI IsoSendResp(uint16_t wCard, uint16_t wBus, tIsoTrigMsg *hIsoTrigMsg, tIsoMsg *hIsoMsg);
/* Programmation d'un nouveau dbit                                         // Change baud rate */
_MUXSPEC tMuxStatus _MUXAPI IsoChangeBaudRate(uint16_t wCard, uint16_t wBus, tIsoBaudRate eBaudRateTx, tIsoBaudRate eBaudRateRx);
/* Lecture des statistiques                                                 // Statistics information */
_MUXSPEC tMuxStatus _MUXAPI IsoGetStat(uint16_t wCard, uint16_t wBus, tIsoStat *hIsoStat);
/* Purge de la file d'attente de rception                                  // Flush FIFO rx */
_MUXSPEC tMuxStatus _MUXAPI IsoClearFifoRx(uint16_t wCard, uint16_t wBus);
/* Etat de la FIFO                                                          // Counts of event in the receive queue */
_MUXSPEC tMuxStatus _MUXAPI IsoGetFifoRxLevel(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
/* Taille des evts dans la FIFO                                             // Data length of event in the receive queue */
_MUXSPEC tMuxStatus _MUXAPI IsoSetDataRxLevel(uint16_t wCard, uint16_t wBus, uint16_t wLevel);
/* Lecture d'un octet sur un composant UART                                 // Read byte from the UART */
_MUXSPEC tMuxStatus _MUXAPI IsoReadByte(uint16_t wCard, uint16_t wBus, uint16_t wOffset,uint8_t *bData);
/* Ecriture d'un octet sur un composant UART                                // Write byte to the UART */
_MUXSPEC tMuxStatus _MUXAPI IsoWriteByte(uint16_t wCard, uint16_t wBus, uint16_t wOffset,uint8_t bData);
#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tIsoConfigOper)(uint16_t wCard, uint16_t wBus, tIsoOper *hIsoOper);
typedef tMuxStatus (__stdcall * tIsoConfigBus)(uint16_t wCard, uint16_t wBus, tIsoBus *hIsoBus);
typedef tMuxStatus (__stdcall * tIsoConfigUart)(uint16_t wCard, uint16_t wBus, tUartConfig *hUartConfig);
typedef tMuxStatus (__stdcall * tIsoConfigParam)(uint16_t wCard, uint16_t wBus, tIsoParam *hIsoParam);
typedef tMuxStatus (__stdcall * tIsoConfigStat)(uint16_t wCard, uint16_t wBus, uint16_t wBusLoadTime);
typedef tMuxStatus (__stdcall * tIsoActivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tIsoIsBusActive)(uint16_t wCard, uint16_t wBus, uint16_t *wState);
typedef tMuxStatus (__stdcall * tIsoDeactivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tIsoConfigPeriodic)(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tIsoMsg *hIsoMsg);
typedef tMuxStatus (__stdcall * tIso14230ConfigPeriodic)(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tIso14230Msg *hIso14230Msg);
typedef tMuxStatus (__stdcall * tIsoSetNotification)(uint16_t wCard, uint16_t wBus, void * hWinEvent);
typedef tMuxStatus (__stdcall * tIsoSendMsg)(uint16_t wCard, uint16_t wBus, tIsoMsg *hIsoMsg);
typedef tMuxStatus (__stdcall * tIso14230SendMsg)(uint16_t wCard, uint16_t wBus, tIso14230Msg *hIso14230Msg);
typedef tMuxStatus (__stdcall * tIsoGetEvent)(uint16_t wCard, uint16_t wBus, tIsoEvent *hIsoEvent);
typedef tMuxStatus (__stdcall * tIsoWaitResponse)(uint16_t wCard, uint16_t wBus, uint16_t wTimeOut);
typedef tMuxStatus (__stdcall * tIsoSendResp)(uint16_t wCard, uint16_t wBus, tIsoTrigMsg *hIsoTrigMsg, tIsoMsg *hIsoMsg);
typedef tMuxStatus (__stdcall * tIsoChangeBaudRate)(uint16_t wCard, uint16_t wBus, tIsoBaudRate eBaudRateTx, tIsoBaudRate eBaudRateRx);
typedef tMuxStatus (__stdcall * tIsoGetStat)(uint16_t wCard, uint16_t wBus, tIsoStat *hIsoStat);
typedef tMuxStatus (__stdcall * tIsoClearFifoRx)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tIsoGetFifoRxLevel)(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
typedef tMuxStatus (__stdcall * tIsoSetDataRxLevel)(uint16_t wCard, uint16_t wBus, uint16_t wLevel);
typedef tMuxStatus (__stdcall * tIsoReadByte)(uint16_t wCard, uint16_t wBus, uint16_t wOffset,uint8_t *bData);
typedef tMuxStatus (__stdcall * tIsoWriteByte)(uint16_t wCard, uint16_t wBus, uint16_t wOffset,uint8_t bData);
#endif
#ifdef __cplusplus
	}
#endif

/*******************************************************************************
; Dclaration pour les routines J1850 // J1850 definitions
*******************************************************************************/
#define J18_MAX_DATA      11

#define J18_PERIODIC_PARAM_ENABLE		1		/* Active la priodique							// Enable periodic frame */
#define J18_PERIODIC_PARAM_DISABLE		0		/* Desactive la periodique						// Disable periodic frame */
#define J18_PERIODIC_PARAM_WITHEVENTS	2		/* Active la remonte des vnements			// Enable the events */
#define J18_PERIODIC_PARAM_NOEVENTS		0		/* Desactive la remonte des vnements			// Disable the events */

typedef enum
{
	J18_OPER_TESTER         =   0,      /* Mode testeur                             // Tester mode */
	J18_OPER_ANALYZER       =   1,      /* Mode analyseur                           // Analyzer mode */
	J18_OPER_SIMU           =   2       /* Mode simulation d'UCE                    // Simulation mode */
} tJ18OperMode;

typedef struct
{
	tJ18OperMode  eJ18OperMode;         /* Type d'interface avec l'application          // Operating mode with API */
	uint16_t  wFifoSize;              /* Taille de la FIFO                            // FIFO Size */
} tJ18Oper;

typedef struct
{
	uint16_t  wBusLoad;           /* Valeur de la charge bus                      // Bus load value */
	uint16_t  wReserved;          /* Rserv pour utilisation future              // Reserved for future use */
	uint32_t   dwTxRq;             /* Demande de transmission                      // Tx request */
	uint32_t   dwTxOk;             /* Fin de transmission correcte                 // End of Tx Ok */
	uint32_t   dwTxErr;            /* Fin de transmission incorrecte               // Error end of tx */
	uint32_t   dwRxOk;             /* Rception correcte                           // Rx Ok */
	uint32_t   dwRxErr;            /* Rception en erreur                          // Error during reception */
	uint32_t   dwErrFifoOvf;       /* Perte de message                             // FIFO Rx overflow */
} tJ18Stat;

typedef enum
{
	J18_NO_ERR              =   0x0000     /* Pas d'erreur                                 // No error */
} tJ18Error;

typedef enum
{
	J18_BUSTYPE_PWM         =   0x0000,    /* J1850 PWM Bus									// J1850 PWM Bus */
	J18_BUSTYPE_VPW         =   0x0001     /* J1850 PWM Bus									// J1850 PWM Bus */
} tJ18BusType;

typedef enum
{
	J18_BUSSPEED_STD        =   0x0000,    /* J1850 vitesse standard						// J1850 Standard bus speed */
	J18_BUSSPEED_4X         =   0x0001     /* J1850 vitesse X4								// J1850 4X speed */
} tJ18BusSpeed;

typedef struct
{
    tJ18BusType			eType;				/* Type de bus J1850 VPW ou PWM					// Bus Type VPW or PWM */
    tJ18BusSpeed		eSpeed;				/* Mode de l'interface de ligne */
} tJ18Bus;

typedef struct
{
    uint16_t  wHandleMsg;            /* Index de comm. sur le msg (Infos DLL)    // Communication handle returned by DLL */
    uint16_t  wDataLen;              /* Taille des donnes                       // Data length */
    uint32_t   lPeriod;               /* Mettre  0 (rserv pour utilisation future) // Must be set to 0 (Reserved for future used) */
    uint8_t   bData[J18_MAX_DATA];   /* Buffer de donne                         // Data buffer */
} tJ18Msg;

typedef struct
{
    uint16_t  wBus;                  /* Numro de bus                                // Bus number */
    tMuxTypeEvent	eTypeEvent;            /* Type d'vnement                             // Event type */
    uint32_t   dwTimeStamp;	   /* Heure de l'vnement en multiple de 0.1ms// Time of event in 100 Sec */
    tJ18Error       eError;                /* Indication du type d'erreur                  // Error type */
    uint16_t  wBusLoad;              /* Valeur de la charge bus                      // Bus load value */
    uint16_t  wDataLen;              /* Taille des donnes                           // Data length */
    uint16_t  wDummy;
    uint8_t   bData[J18_MAX_DATA];/* Buffer de donne                             // Data buffer */
} tJ18Event;

/*******************************************************************************
; Routines J1850   // J1850   prototypes
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL
/* Configuration du mode de fonctionnement des buffers                      // Select the operating mode */
_MUXSPEC tMuxStatus _MUXAPI J18ConfigOper(uint16_t wCard, uint16_t wBus, tJ18Oper *hJ18Oper);
/* Configuration du bus                                                     // Bus parameter */
_MUXSPEC tMuxStatus _MUXAPI J18ConfigBus(uint16_t wCard, uint16_t wBus, tJ18Bus *hJ18Bus);
/* Dmarrage de la communication                                            // Start communication */
_MUXSPEC tMuxStatus _MUXAPI J18Activate(uint16_t wCard, uint16_t wBus);
/* Etat du bus de communication                                             // Bus state communication */
_MUXSPEC tMuxStatus _MUXAPI J18IsBusActive(uint16_t wCard, uint16_t wBus, uint16_t *wState);
/* Cration de message priodique                                           // Periodic Messages configuration */
_MUXSPEC tMuxStatus _MUXAPI J18ConfigPeriodic(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tJ18Msg *hJ18Msg);
/* Emission d'un message                                                    // Transmit a message */
_MUXSPEC tMuxStatus _MUXAPI J18SendMsg(uint16_t wCard, uint16_t wBus, tJ18Msg *hJ18Msg);
/* Rcupration d'un vnement en provenance du rseau                      // Get an event from DLL */
_MUXSPEC tMuxStatus _MUXAPI J18GetEvent(uint16_t wCard, uint16_t wBus, tJ18Event *hJ18Event);
/* Arrt de la communication                                                // Stop communication */
_MUXSPEC tMuxStatus _MUXAPI J18Deactivate(uint16_t wCard, uint16_t wBus);

/* Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application */
_MUXSPEC tMuxStatus _MUXAPI J18SetNotification(uint16_t wCard, uint16_t wBus, void * hWinEvent);
#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tJ18ConfigOper)(uint16_t wCard, uint16_t wBus, tJ18Oper *hJ18Oper);
typedef tMuxStatus (__stdcall * tJ18ConfigBus)(uint16_t wCard, uint16_t wBus, tJ18Bus *hJ18Bus);
typedef tMuxStatus (__stdcall * tJ18Activate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tJ18IsBusActive)(uint16_t wCard, uint16_t wBus, uint16_t *wState);
typedef tMuxStatus (__stdcall * tJ18SendMsg)(uint16_t wCard, uint16_t wBus, tJ18Msg *hJ18Msg);
typedef tMuxStatus (__stdcall * tJ18GetEvent)(uint16_t wCard, uint16_t wBus, tJ18Event *hJ18Event);
typedef tMuxStatus (__stdcall * tJ18Deactivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tJ18SetNotification)(uint16_t wCard, uint16_t wBus, void * hWinEvent);
#endif
#ifdef __cplusplus
	}
#endif




/*******************************************************************************
; Dclaration pour les routines J1587 // J1587 definitions
*******************************************************************************/
#define J1587_MAX_DATA      				20

#define J1587_PERIODIC_PARAM_ENABLE			1		/* Active la priodique							// Enable periodic frame */
#define J1587_PERIODIC_PARAM_DISABLE		0		/* Desactive la periodique						// Disable periodic frame */
#define J1587_PERIODIC_PARAM_WITHEVENTS		2		/* Active la remonte des vnements			// Enable the events */
#define J1587_PERIODIC_PARAM_NOEVENTS		0		/* Desactive la remonte des vnements			// Disable the events */

typedef enum
{
	J1587_OPER_ANA_FIFO       =   0         /* Mode analyse, stockage fifo      // Analyse mode, event is stored in fifo mode */
} tJ1587OperMode;

typedef struct
{
	tJ1587OperMode  eJ1587OperMode;         /* Type d'interface avec l'application          // Operating mode with API */
	uint16_t  wFifoSize;              /* Taille de la FIFO                            // FIFO Size */
} tJ1587Oper;

typedef enum
{
	J1587_BAUD_9600   =   9600L	    	    /* 9600 bauds */
} tJ1587BaudRate;

typedef struct
{
	uint32_t   dwDelayBusIdle;     /* Delai avant bus idle                         // Delay before detect bus idle */
	uint16_t  wFiltMID;           /* MID pour filtrage                            // MID for filtering */
	uint16_t  wFiltMask;          /* Masque pour filtrage                         // Acceptance mask */
	uint16_t  wFiltPass;          /* Indication si le filtre est passant/bloquant // Filter by pass or block */
	uint16_t  wSpecialModes;      /* Rserv pour utilisation futures             // Reserved for future used */
} tJ1587Param;

typedef struct
{
	uint16_t  wBusLoad;           /* Valeur de la charge bus                      // Bus load value */
	uint16_t  wReserved;          /* Rserv pour utilisation future              // Reserved for future use */
	uint32_t   dwTxRq;             /* Demande de transmission                      // Tx request */
	uint32_t   dwTxOk;             /* Fin de transmission correcte                 // End of Tx Ok */
	uint32_t   dwTxErr;            /* Fin de transmission incorrecte               // Error end of tx */
	uint32_t   dwRxOk;             /* Rception correcte                           // Rx Ok */
	uint32_t   dwRxErr;            /* Rception en erreur                          // Error during reception */
	uint32_t   dwErrBreak;         /* Erreur de type Break                         // Break error */
	uint32_t   dwErrFE;            /* Erreur de format                             // Framing error */
	uint32_t   dwErrPE;            /* Erreur de parit                             // Parity error */
	uint32_t   dwErrOE;            /* Erreur de dpassement                        // Overrun error */
	uint32_t   dwErrFifoOvf;       /* Perte de message                             // FIFO Rx overflow */
} tJ1587Stat;

typedef enum
{
	J1587_NO_ERR              =   0x0000,   /* Pas d'erreur                                 // No error */
	J1587_ERR_BIT             =   0x0001,   /* Erreur de bit                                // Bit error */
	J1587_ERR_CRC             =   0x0002    /* Erreur dans le calcul du CRC                 // CRC error */
} tJ1587Error;

typedef struct
{
	tJ1587BaudRate    eBaudRate;            /* Dbit du bus                                 // Baud rate */
} tJ1587Bus;

typedef enum
{
	J1587_BUS_NOMINAL         =   0,      /* Etat nominal                                 // Nominal state */
	J1587_BUS_ERROR           =   1,      /* Etat erreur                                  // Error state */
	J1587_BUS_IDLE            =   2       /* Etat bus idle                                // Bus idle state */
} tJ1587ChipState;

typedef struct
{
	uint16_t  wHandleMsg;             /* Index de comm. sur le msg (Infos DLL)    // Communication handle returned by DLL */
	uint16_t  wPriority;              /* Priorit du message [1-8]                // Message priority */
	uint32_t   lPeriod;                /* Periodicit en ms                        // Period */
	uint32_t   dwReserved1;            /* Rserv pour utilisation future          // Reserved */
	uint32_t   dwReserved2;            /* Rserv pour utilisation future          // Reserved */
	uint16_t  wMID;                   /* Identificateur du message                // Message identifier */
	uint16_t  wDataLen;               /* Taille des donnes                       // Data length */
	uint8_t   bData[J1587_MAX_DATA];  /* Buffer de donne                         // Data buffer */
} tJ1587Msg;

typedef struct
{
	uint16_t  wBus;                   /* Numro de bus                                // Bus number */
	uint16_t  wHandleMsg;             /* Index de comm. sur le msg (Infos DLL)        // Communication handle returned by DLL */
	tMuxTypeEvent   eTypeEvent;             /* Type d'vnement retourn  l'application    // Event type */
	uint32_t   dwTimeStamp;            /* Heure de l'vnement en multiple de 0.1 ms   // Time of event in 100 Sec */
	uint16_t  wTimePrecision;         /* Prcision de la datation                     // Time accuracy */
	tJ1587Error     eError;                 /* Type d'erreur                                // Error type */
	tJ1587ChipState eChipState;             /* Etat du composants                           // Chip state */
	uint16_t  wBusLoad;               /* Valeur de la charge bus                      // Bus load value */
	uint32_t   dwReserved1;            /* Rserv pour utilisation future              // Reserved */
	uint32_t   dwReserved2;            /* Rserv pour utilisation future              // Reserved */
	uint16_t  wMID;                   /* Identificateur du message                // Message identifier */
	uint16_t  wDataLen;               /* Taille des donnes               // Data length */
	uint8_t   bData[J1587_MAX_DATA];  /* Buffer de donne                 // Data buffer */
} tJ1587Event;

/*******************************************************************************
; Routines J1587   // J1587   prototypes
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL
/* Configuration du mode de fonctionnement des buffers                      // Select the operating mode */
_MUXSPEC tMuxStatus _MUXAPI J1587ConfigOper(uint16_t wCard, uint16_t wBus, tJ1587Oper *hJ1587Oper);
/* Configuration du bus                                                     // Bus parameter */
_MUXSPEC tMuxStatus _MUXAPI J1587ConfigBus(uint16_t wCard, uint16_t wBus, tJ1587Bus *hJ1587Bus);
/* Configuration des paramtres supplmentaires                             // Extra parameter */
_MUXSPEC tMuxStatus _MUXAPI J1587ConfigParam(uint16_t wCard, uint16_t wBus, tJ1587Param *hJ1587Param);
/* Configuration des statistques                                            // Statistics configuration */
_MUXSPEC tMuxStatus _MUXAPI J1587ConfigStat(uint16_t wCard, uint16_t wBus, uint16_t wBusLoadTime);
/* Cration de message priodique                                           // Periodic Messages configuration */
_MUXSPEC tMuxStatus _MUXAPI J1587ConfigPeriodic(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tJ1587Msg *hJ1587Msg);
/* Dmarrage de la communication                                            // Start communication */
_MUXSPEC tMuxStatus _MUXAPI J1587Activate(uint16_t wCard, uint16_t wBus);
/* Etat du bus de communication                                             // Bus state communication */
_MUXSPEC tMuxStatus _MUXAPI J1587IsBusActive(uint16_t wCard, uint16_t wBus, uint16_t *wState);
/* Emission d'un message                                                    // Transmit a message */
_MUXSPEC tMuxStatus _MUXAPI J1587SendMsg(uint16_t wCard, uint16_t wBus, tJ1587Msg *hJ1587Msg);
/* Rcupration d'un vnement en provenance du rseau                      // Get an event from DLL */
_MUXSPEC tMuxStatus _MUXAPI J1587GetEvent(uint16_t wCard, uint16_t wBus, tJ1587Event *hJ1587Event);
/* Arrt de la communication                                                // Stop communication */
_MUXSPEC tMuxStatus _MUXAPI J1587Deactivate(uint16_t wCard, uint16_t wBus);

/* Rcupration de l'tat du contrleur de protocole                        // CAN controller state */
_MUXSPEC tMuxStatus _MUXAPI J1587GetBusState(uint16_t wCard, uint16_t wBus, tJ1587ChipState *eJ1587ChipState, uint8_t *bTxErrCount, uint8_t *bRxErrCount);
/* Lecture des statistiques                                                 // Statistics information */
_MUXSPEC tMuxStatus _MUXAPI J1587GetStat(uint16_t wCard, uint16_t wBus, tJ1587Stat *hJ1587Stat);
/* Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application */
_MUXSPEC tMuxStatus _MUXAPI J1587SetNotification(uint16_t wCard, uint16_t wBus, void * hWinEvent);
/* Purge de la file d'attente de rception                                  // Flush FIFO rx */
_MUXSPEC tMuxStatus _MUXAPI J1587ClearFifoRx(uint16_t wCard, uint16_t wBus);
/* Etat de la FIFO                                                          // Counts of event in the receive queue */
_MUXSPEC tMuxStatus _MUXAPI J1587GetFifoRxLevel(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tJ1587ConfigOper)(uint16_t wCard, uint16_t wBus, tJ1587Oper *hJ1587Oper);
typedef tMuxStatus (__stdcall * tJ1587ConfigBus)(uint16_t wCard, uint16_t wBus, tJ1587Bus *hJ1587Bus);
typedef tMuxStatus (__stdcall * tJ1587ConfigParam)(uint16_t wCard, uint16_t wBus, tJ1587Param *hJ1587Param);
typedef tMuxStatus (__stdcall * tJ1587ConfigStat)(uint16_t wCard, uint16_t wBus, uint16_t wBusLoadTime);
typedef tMuxStatus (__stdcall * tJ1587ConfigPeriodic)(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tJ1587Msg *hJ1587Msg);
typedef tMuxStatus (__stdcall * tJ1587Activate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tJ1587IsBusActive)(uint16_t wCard, uint16_t wBus, uint16_t *wState);
typedef tMuxStatus (__stdcall * tJ1587SendMsg)(uint16_t wCard, uint16_t wBus, tJ1587Msg *hJ1587Msg);
typedef tMuxStatus (__stdcall * tJ1587GetEvent)(uint16_t wCard, uint16_t wBus, tJ1587Event *hJ1587Event);
typedef tMuxStatus (__stdcall * tJ1587Deactivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tJ1587GetBusState)(uint16_t wCard, uint16_t wBus, tJ1587ChipState *eJ1587ChipState, uint8_t *bTxErrCount, uint8_t *bRxErrCount);
typedef tMuxStatus (__stdcall * tJ1587GetStat)(uint16_t wCard, uint16_t wBus, tJ1587Stat *hJ1587Stat);
typedef tMuxStatus (__stdcall * tJ1587SetNotification)(uint16_t wCard, uint16_t wBus, void * hWinEvent);
typedef tMuxStatus (__stdcall * tJ1587ClearFifoRx)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tJ1587GetFifoRxLevel)(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
#endif
#ifdef __cplusplus
	}
#endif

/*******************************************************************************
; Dclaration pour les routines NMEA0183 // NMEA0183 definitions
*******************************************************************************/
#define	NMEA0183_MAX_DATA	      77    /* Nbre de donnes max NMEA0183       // Maximum NMEA0183 message length */
typedef enum
{
    NMEA0183_OPER_ANA_FIFO       =   0      /* Mode analyse, stockage fifo      // Analyse mode, event is stored in fifo mode */
} tNMEA0183OperMode;

typedef struct
{
    tNMEA0183OperMode  eNMEA0183OperMode;   /* Type d'interface avec l'application          // Operating mode with API */
    uint16_t  wFifoSize;              /* Taille de la FIFO                            // FIFO Size */
} tNMEA0183Oper;

typedef enum
{
    NMEA0183_BAUD_4800   =   4800L	    	/* 4800 bauds */
} tNMEA0183BaudRate;

typedef struct
{
    uint32_t   dwDelayBusIdle;     /* Delai avant bus idle                         // Delay before detect bus idle */
    uint32_t   dwDelayMsgTimeout;  /* Delai avant message en time out              // Delay before time out message */
    uint16_t  wControlCrc;        /* Vrification du CRC dans le message          // Check if CRC is present */
    uint16_t  wSpecialModes;      /* Rserv pour utilisation futures             // Reserved for future used */
} tNMEA0183Param;

typedef struct
{
    uint16_t  wBusLoad;           /* Valeur de la charge bus                      // Bus load value */
    uint16_t  wReserved;          /* Rserv pour utilisation future              // Reserved for future use */
    uint32_t   dwTxRq;             /* Demande de transmission                      // Tx request */
    uint32_t   dwTxOk;             /* Fin de transmission correcte                 // End of Tx Ok */
    uint32_t   dwTxErr;            /* Fin de transmission incorrecte               // Error end of tx */
    uint32_t   dwRxOk;             /* Rception correcte                           // Rx Ok */
    uint32_t   dwRxErr;            /* Rception en erreur                          // Error during reception */
    uint32_t   dwErrBreak;         /* Erreur de type Break                         // Break error */
    uint32_t   dwErrFE;            /* Erreur de format                             // Framing error */
    uint32_t   dwErrPE;            /* Erreur de parit                             // Parity error */
    uint32_t   dwErrOE;            /* Erreur de dpassement                        // Overrun error */
    uint32_t   dwErrFifoOvf;       /* Perte de message                             // FIFO Rx overflow */
} tNMEA0183Stat;

typedef enum
{
    NMEA0183_NO_ERR              =   0x0000, /* Pas d'erreur                                 // No error */
    NMEA0183_ERR_RX_OVER         =   0x0001, /* Longueur du message trop long			     // Message data length overflow */
    NMEA0183_ERR_INV_PDU         =   0x0002, /* Format de message invalide                   // Invalid PDU format */
    NMEA0183_ERR_BAD_CRC         =   0x0003, /* CRC incorrect                                // Invalid CRC */
    NMEA0183_ERR_BAD_EOS         =   0x0004, /* <CR>ou <LF> erreur                           // End of sequence error */
    NMEA0183_ERR_TO_MSG          =   0x0005  /* Timeout d'attente du message                 // Message timeout */
} tNMEA0183Error;

typedef struct
{
    tNMEA0183BaudRate    eBaudRate;          /* Dbit du bus                                 // Baud rate */
} tNMEA0183Bus;

typedef enum
{
    NMEA0183_BUS_NOMINAL         =   0,      /* Etat nominal                                 // Nominal state */
    NMEA0183_BUS_ERROR           =   1,      /* Etat erreur                                  // Error state */
    NMEA0183_BUS_IDLE            =   2       /* Etat bus idle                                // Bus idle state */
} tNMEA0183ChipState;

typedef enum
{
    NMEA0183_GEN_RAW	    =   0x0000, /* Messages brutes                              // Raw message */
    NMEA0183_GEN_NO_CRC     =   0x0001, /* Uniquement les caractre $ et CR,LF          // $,CR and LF only */
    NMEA0183_GEN_CRC        =   0x0002  /* $,CR,LF et CRC + CRC delimiter               // $, CR , LF and CRC field + delimiter */
}
tNMEA0183GenErr;

typedef struct
{
    uint16_t  wHandleMsg;             /* Index de comm. sur le msg (Infos DLL)    // Communication handle returned by DLL */
    tNMEA0183GenErr eNMEA0183GenErr;        /* Type d'mission					        // Sending mode */
    uint32_t   lPeriod;                /* Periodicit en ms                        // Period */
    uint32_t   dwReserved1;            /* Rserv pour utilisation future          // Reserved */
    uint32_t   dwReserved2;            /* Rserv pour utilisation future          // Reserved */
    uint16_t  wDataLen;               /* Taille des donnes                       // Data length */
    uint8_t   bData[NMEA0183_MAX_DATA];    /* Buffer de donne                    // Data buffer */
} tNMEA0183Msg;

typedef struct
{
    uint16_t  wBus;                   /* Numro de bus                                // Bus number */
    uint16_t  wHandleMsg;             /* Index de comm. sur le msg (Infos DLL)        // Communication handle returned by DLL */
    tMuxTypeEvent   eTypeEvent;             /* Type d'vnement retourn  l'application    // Event type */
    uint32_t   dwTimeStamp;            /* Heure de l'vnement en multiple de 0.1 ms   // Time of event in 100 Sec */
    tNMEA0183Error  eError;                 /* Type d'erreur                                // Error type */
    tNMEA0183ChipState eChipState;             /* Etat du composants                           // Chip state */
    uint16_t  wBusLoad;               /* Valeur de la charge bus                      // Bus load value */
    uint32_t   dwReserved1;            /* Rserv pour utilisation future              // Reserved */
    uint32_t   dwReserved2;            /* Rserv pour utilisation future              // Reserved */
    uint16_t  wDataLen;               /* Taille des donnes               // Data length */
    uint8_t   bData[NMEA0183_MAX_DATA];  /* Buffer de donne                 // Data buffer */
} tNMEA0183Event;

/*******************************************************************************
; Routines NMEA0183   // NMEA0183  prototypes
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL

#define NMEA0183_PERIODIC_PARAM_ENABLE			1		/* Active la priodique							// Enable periodic frame */
#define NMEA0183_PERIODIC_PARAM_DISABLE			0		/* Desactive la periodique						// Disable periodic frame */
#define NMEA0183_PERIODIC_PARAM_WITHEVENTS		2		/* Active la remonte des vnements			// Enable the events */
#define NMEA0183_PERIODIC_PARAM_NOEVENTS		0		/* Desactive la remonte des vnements			// Disable the events */

/* Configuration du mode de fonctionnement des buffers                      // Select the operating mode */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183ConfigOper(uint16_t wCard, uint16_t wBus, tNMEA0183Oper *hNMEA0183Oper);
/* Configuration du bus                                                     // Bus parameter */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183ConfigBus(uint16_t wCard, uint16_t wBus, tNMEA0183Bus *hNMEA0183Bus);
/* Configuration des paramtres                                             // Uart parameters */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183ConfigUart(uint16_t wCard, uint16_t wBus, tUartConfig *hUartConfig);
/* Configuration des paramtres supplmentaires                             // Extra parameter */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183ConfigParam(uint16_t wCard, uint16_t wBus, tNMEA0183Param *hNMEA0183Param);
/* Configuration des statistques                                            // Statistics configuration */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183ConfigStat(uint16_t wCard, uint16_t wBus, uint16_t wBusLoadTime);
/* Cration de message priodique                                           // Periodic Messages configuration */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183ConfigPeriodic(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tNMEA0183Msg *hNMEA0183Msg);
/* Dmarrage de la communication                                            // Start communication */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183Activate(uint16_t wCard, uint16_t wBus);
/* Etat du bus de communication                                             // Bus state communication */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183IsBusActive(uint16_t wCard, uint16_t wBus, uint16_t *wState);
/* Emission d'un message                                                    // Transmit a message */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183SendMsg(uint16_t wCard, uint16_t wBus, tNMEA0183Msg *hNMEA0183Msg);
/* Rcupration d'un vnement en provenance du rseau                      // Get an event from DLL */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183GetEvent(uint16_t wCard, uint16_t wBus, tNMEA0183Event *hNMEA0183Event);
/* Arrt de la communication                                                // Stop communication */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183Deactivate(uint16_t wCard, uint16_t wBus);

/* Rcupration de l'tat du contrleur de protocole                        // CAN controller state */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183GetBusState(uint16_t wCard, uint16_t wBus, tNMEA0183ChipState *eNMEA0183ChipState, uint8_t *bTxErrCount, uint8_t *bRxErrCount);
/* Lecture des statistiques                                                 // Statistics information */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183GetStat(uint16_t wCard, uint16_t wBus, tNMEA0183Stat *hNMEA0183Stat);
/* Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183SetNotification(uint16_t wCard, uint16_t wBus, void * hWinEvent);
/* Purge de la file d'attente de rception                                  // Flush FIFO rx */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183ClearFifoRx(uint16_t wCard, uint16_t wBus);
/* Etat de la FIFO                                                          // Counts of event in the receive queue */
_MUXSPEC tMuxStatus _MUXAPI NMEA0183GetFifoRxLevel(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tNMEA0183ConfigOper)(uint16_t wCard, uint16_t wBus, tNMEA0183Oper *hNMEA0183Oper);
typedef tMuxStatus (__stdcall * tNMEA0183ConfigBus)(uint16_t wCard, uint16_t wBus, tNMEA0183Bus *hNMEA0183Bus);
typedef tMuxStatus (__stdcall * tNMEA0183ConfigUart)(uint16_t wCard, uint16_t wBus, tUartConfig *hUartConfig);
typedef tMuxStatus (__stdcall * tNMEA0183ConfigParam)(uint16_t wCard, uint16_t wBus, tNMEA0183Param *hNMEA0183Param);
typedef tMuxStatus (__stdcall * tNMEA0183ConfigStat)(uint16_t wCard, uint16_t wBus, uint16_t wBusLoadTime);
typedef tMuxStatus (__stdcall * tNMEA0183ConfigPeriodic)(uint16_t wCard, uint16_t wBus, uint16_t wOffset, uint16_t wParam, tNMEA0183Msg *hNMEA0183Msg);
typedef tMuxStatus (__stdcall * tNMEA0183Activate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tNMEA0183IsBusActive)(uint16_t wCard, uint16_t wBus, uint16_t *wState);
typedef tMuxStatus (__stdcall * tNMEA0183SendMsg)(uint16_t wCard, uint16_t wBus, tNMEA0183Msg *hNMEA0183Msg);
typedef tMuxStatus (__stdcall * tNMEA0183GetEvent)(uint16_t wCard, uint16_t wBus, tNMEA0183Event *hNMEA0183Event);
typedef tMuxStatus (__stdcall * tNMEA0183Deactivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tNMEA0183GetBusState)(uint16_t wCard, uint16_t wBus, tNMEA0183ChipState *eNMEA0183ChipState, uint8_t *bTxErrCount, uint8_t *bRxErrCount);
typedef tMuxStatus (__stdcall * tNMEA0183GetStat)(uint16_t wCard, uint16_t wBus, tNMEA0183Stat *hNMEA0183Stat);
typedef tMuxStatus (__stdcall * tNMEA0183SetNotification)(uint16_t wCard, uint16_t wBus, void * hWinEvent);
typedef tMuxStatus (__stdcall * tNMEA0183ClearFifoRx)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tNMEA0183GetFifoRxLevel)(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
#endif
#ifdef __cplusplus
	}
#endif

/*******************************************************************************
; Dclaration pour les routines WinCE // WinCE definitions
*******************************************************************************/
#ifdef _WIN32_WCE	// Only Under Windows CE
typedef enum
{
	WINCE_FALSE		=	0,						/* Faux		// False */
	WINCE_TRUE		=	1						/* Vrai		// True */
}tWINCEBoolean;

typedef enum
{
	WINCE_POWERMODE_USESYSTEM_SETTINGS		= 0,	/* Utilise les options d'nergie dfinit par le systme // Use all power management settings defined by the operating system */
	WINCE_POWERMODE_PREVENT_POWERDOWN		= 1		/* Empche la mise en veille du pocket pc ds qu'une carte est ouverte // Prevent automatic power down as soon as a card is opened */
//	WINCE_POWERMODE_POWERDOWN_EXECPTDEVICE	= 2		/* Le pocket de mets en veille sauf la carte USB // Pocket can power down but not the USB device */
}tWINCEPowerMode;

typedef enum
{
	WINCE_BACKLIGHT_USESYSTEM_SETTINGS	= 0,		/* Utilise les options d'clairage dfinit par le systme // Use all backlight settings defined by the operating system */
	WINCE_BACKLIGHT_PREVENT_POWERDOWN	= 1			/* Empche la mise en veille de l'clairage ds qu'une carte est ouverte // Prevent automatic backlight power saving as soon as a card is opened */
}tWINCEBacklightMode;

typedef struct
{
	tWINCEPowerMode		ePowerMode;					/* Mode de gestion de l'alimentation	// Power mode management type */
	tWINCEBacklightMode	eBacklightMode;				/* Mode de gestion de l'clairage		// Backligth mode management type */
	tWINCEBoolean		eSendEvents;				/* Remonte les vements 				// Send all event */
}tWINCEParam;

typedef enum
{
	WINCE_ACLINE_OFFLINE	= 0,					/* L'alimentation secteur n'est pas branche	// AC line if offline */
	WINCE_ACLINE_ONLINE		= 1						/* L'alimentation secteur est branche			// AC line if online */
}tWINCEACLineState;

/* Etats de la batterie						// Battery state flags */
/* Peut tre une combinaison de ces valeurs	// Can be a combination of these values */
#define WINCE_BATTSTATE_HIGH			1			/* La batterie est pleine	// Battery is full */
#define WINCE_BATTSTATE_LOW				2			/* La batterie est faible	// Battery is low */
#define WINCE_BATTSTATE_CRITICAL		4			/* La batterie est critique	// Battery is critical */
#define WINCE_BATTSTATE_CHARGING		8			/* La batterie se recharge	// Battery is charging */
#define WINCE_BATTSTATE_NOBATTERY		128			/* Aucune batterie			// There is no battery */
#define WINCE_BATTSTATE_UNKNOWN			255			/* Etat inconnu				// Unknown state */

/* Dure de vie de la batterie	// Battery life time constants */
#define WINCE_BATTLIFETIME_UNKNOWN		0xFFFFFFFF

typedef struct
{
	tWINCEACLineState	eACLineState;				/* Etat de l'alimentation secteur				// AC Line state */
	uint16_t		wBatteryState;				/* Etat de la batterie (WINCE_BATTSTATE_xxx)	// Batterie state (WINCE_BATTSTATE_xxx) */
	uint16_t		wBatteryLifePercent;		/* Etat de la batterie en pourcentage			// Percentage of full battery charge remaining */
	uint32_t		dwBatteryLifeTime;			/* Dure de vie de la batterie					// Battery life time */
}tWINCEPowerState;

typedef struct
{
	tMuxTypeEvent		eTypeEvent;					/* Type d'vnement retourn  l'application    // Event type */
	uint32_t		dwTimeStamp;				/* Heure de l'vnement en multiple de 0.1 ms   // Time of event in 100 Sec */
	tWINCEPowerState	hPowerState;				/* Etat de l'alimentation						// Power State */
}tWINCEEvent;

/*******************************************************************************
; Routines WinCE // WinCE functions
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL
/* Configuration de mode de fonctionnement sous Windows CE  // Setup how it should works under Windows CE */
_MUXSPEC tMuxStatus _MUXAPI WINCEConfigParam(uint16_t wCard, tWINCEParam *hWINCEParam);
/* Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application */
_MUXSPEC tMuxStatus _MUXAPI WINCESetNotification(uint16_t wCard, void * hWinEvent);
/* Activation de la gestion de WinCE // Activate the WinCE engine */
_MUXSPEC tMuxStatus _MUXAPI WINCEActivate(uint16_t wCard);
/* Arrt de la gestion de WinCE // Deactivate the WinCE engine */
_MUXSPEC tMuxStatus _MUXAPI WINCEDeactivate(uint16_t wCard);
/* Etat de l'alimentation	// Power state */
_MUXSPEC tMuxStatus _MUXAPI WINCEGetPowerState(uint16_t wCard, tWINCEPowerState *hPowerState);
/* Recupre les evenement en cours // Get the last events */
_MUXSPEC tMuxStatus _MUXAPI WINCEGetEvent(uint16_t wCard, tWINCEEvent *hEvent);
/* Indique si le driver  t dcharg // Return if the driver has been unloaded */
_MUXSPEC tMuxStatus _MUXAPI WINCEIsDriverUnloaded(uint16_t wCard, uint16_t *wIsDriverUnloaded);
#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tWINCEConfigParam)(uint16_t wCard, tWINCEParam *hWINCEParam);
typedef tMuxStatus (__stdcall * tWINCESetNotification)(uint16_t wCard, void * hWinEvent);
typedef tMuxStatus (__stdcall * tWINCEActivate)(uint16_t wCard);
typedef tMuxStatus (__stdcall * tWINCEDeactivate)(uint16_t wCard);
typedef tMuxStatus (__stdcall * tWINCEGetPowerState)(uint16_t wCard, tWINCEPowerState *hPowerState);
typedef tMuxStatus (__stdcall * tWINCEGetEvent)(uint16_t wCard, tWINCEEvent *hEvent);
typedef tMuxStatus (__stdcall * tWINCEIsDriverUnloaded)(uint16_t wCard, uint16_t *wIsDriverUnloaded);
#endif
#ifdef __cplusplus
	}
#endif	// __cplusplus
#endif	// _WIN32_WCE



/*******************************************************************************
; Routines de gestions des E/S // IO and User functions
*******************************************************************************/
#define SPI_CODE_READ       0x0000
#define SPI_CODE_WRITE      0x0001

#define SPI_MAX_DATA        16
typedef struct
{
    uint16_t  wCode;                  /* Code fonction                            // Function code */
    uint16_t  wDataLen;               /* Taille des donnes                       // Data length */
    uint8_t   bData[SPI_MAX_DATA];    /* Buffer de donne                         // Data buffer */
} tSPIInfo;

#define I2C_CODE_READ       0x0000
#define I2C_CODE_WRITE      0x0001

#define I2C_MAX_DATA        50
typedef struct
{
    uint16_t  wCode;                  /* Code fonction                            // Function code */
    uint16_t  wSlave;                 /* Adresse esclave                          // Slave address */
    uint16_t  wDataLen;               /* Taille des donnes                       // Data length */
    uint8_t   bData[I2C_MAX_DATA];    /* Buffer de donne                         // Data buffer */
} tI2CInfo;

#define PROPRIETARY_MAX_DATA        0x1000
typedef struct
{
    uint16_t  wDataLen;                       /* Taille des donnes                       // Data length */
    uint8_t   bData[PROPRIETARY_MAX_DATA];    /* Buffer de donne                         // Data buffer */
} tProprietaryInfo;

#define PRY_MAX_DATA        		38		// pour faire un vnement de 64 octets
typedef struct
{
    uint16_t  wBus;                   /* Numro de bus                                // Bus number */
    uint16_t  wHandleMsg;             /* Index de comm. sur le msg (Infos DLL)        // Communication handle returned by DLL */
    tMuxTypeEvent   eTypeEvent;         /* Type d'vnement retourn  l'application    // Event type */
    uint32_t   dwTimeStamp;            /* Heure de l'vnement en multiple de 0.1 ms   // Time of event in 100 Sec */
    uint16_t  wError;                 /* Type d'erreur                                // Error type */
    uint16_t  dwReserved1;            /* Rserv pour utilisation future              // Reserved */
    uint16_t  dwReserved2;            /* Rserv pour utilisation future              // Reserved */
    uint32_t   dwReserved3;            /* Rserv pour utilisation future              // Reserved */
    uint32_t   dwReserved4;            /* Rserv pour utilisation future              // Reserved */
    uint16_t  wDataLen;               /* Taille des donnes               // Data length */
    uint8_t   bData[PRY_MAX_DATA];    /* Buffer de donne                 // Data buffer */
} tPryEvent;

#define TRG_BUS_NONE        0
#define TRG_BUS_CAN         1
#define TRG_BUS_LIN         2
#define TRG_BUS_ISO         3
#define TRG_BUS_VAN         4
#define TRG_BUS_J1587       5
#define TRG_BUS_NMEA0183    6

#define TRG_TYPE_IDENT      0				/* Trigger sur identificateur dtect */
#define TRG_TYPE_ERROR      1				/* Trigger sur trame d'erreur */
typedef struct
{
uint16_t  wTypeBus;					/* Type de bus (CAN, VAN...)                    // Bus type */
uint16_t  wBus;						/* Numro de bus                                // Bus number */
uint16_t  wTypeTrigger;				/* Type de trigger                              // Trigger condition */
uint16_t  wDummy;
    union                                   /* Parameters */
    {
        struct
        {
        uint32_t   dwIdent;            /* Identificateur du message                    // CAN identifier value */
        tCanTypeId      eTypeId;            /* Type d'identifcateur STD ou XTD              // Identifier type (standard (11 bits) or extended (29 bits) */
        } hCan;
        struct
        {
        uint8_t   bDummy[50];
        } hDummy;
    }u;
} tTrigger;
#define IO_FALLING_EDGE     0x0001
#define IO_RISING_EDGE      0x0002


#define ANA_CODE_READ           0x0000
#define ANA_CODE_WRITE          0x0001
#define ANA_CODE_SET_MODE       0x0002
#define ANA_CODE_SET_CHANNEL    0x0003

#define ANA_MAX_COUNT       32

typedef struct
{
    uint16_t  wCode;                  /* Code fonction                            // Function code */
    uint16_t  wMode;
    union                                   /* Parameters */
    {
        struct
        {
            int32_t   lFactor[ANA_MAX_COUNT]; /* Facteur                                  // Factor */
            int32_t   lOffset[ANA_MAX_COUNT]; /* Offset                                   // Offset */
        } hReadWrite;
        struct
        {
            uint16_t  wChannel;               /* Canal de communication                   // Message offset */
            uint16_t  wPeriod;                /* Priodicit du message                   // Message periodicity */
            uint32_t   dwIdent;                /* Identificateur du message                // Message identifier */
            uint16_t  wTypeBus;               /* Type de bus (CAN, VAN...)                // Bus type */
            uint16_t  wBus;                   /* Numro de bus                            // Bus number */
        } hSetChannel;
    }u;
} tAnaTransfer;


//#define UART_CODE_READ		0x0000
//#define UART_CODE_WRITE		0x0001
//#define UART_CODE_CONFIG	0x0002
//#define UART_CODE_OPEN		0x0003
//#define UART_CODE_CLOSE		0x0004
//
//#define UART_MAX_DATA       1024
//
//typedef struct
//{
//    uint16_t  wCode;                  /* Code fonction                            // Function code */
//    uint16_t  wLength;
//    union                                   /* Parameters */
//    {
//        struct
//        {
//			uint32_t   dwBaudrate;  
//			uint16_t	wStopBit;                                 
//			uint16_t	wParityType;                                 
//			uint16_t	wDataBit;                                 
//        } hConfig;
//     	uint8_t	bData[UART_MAX_DATA];/* Buffer de donne                         // Data buffer */
//    }u;
//} tUartTransfer;


#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL
/* Gestion des sorties logiques                                             // Set diagital output state */
_MUXSPEC tMuxStatus _MUXAPI IOSetOutput(uint16_t wCard, uint16_t wOutputValue, uint16_t wOutputMask);
/* Gestion des entres logiques                                             // Read digital input value */
_MUXSPEC tMuxStatus _MUXAPI IOGetInput(uint16_t wCard, uint16_t *wInputValue);
/* Nombre d'entres/sorties logiques                                        // get input / output count */
_MUXSPEC tMuxStatus _MUXAPI IOGetCount(uint16_t wCard, uint16_t *wInputCount, uint16_t *wOutputCount);
/* Configure les remontes d'entres                                        // Configure trigger input */
_MUXSPEC tMuxStatus _MUXAPI IOConfigInput(uint16_t wCard, uint16_t wInput, uint16_t wEdge);
/* Configure les sorties trigger                                            // Trigger output setup */
_MUXSPEC tMuxStatus _MUXAPI IOConfigOutput(uint16_t wCard, uint16_t wOutput, tTrigger *hTrigger);
/* Communication sur la liaison SPI                                         // SPI communication protocol */
_MUXSPEC tMuxStatus _MUXAPI SPITransfer(uint16_t wCard, tSPIInfo *hSPIInfo);
/* Communication sur la liaison I2C                                         // I2C communication protocol */
_MUXSPEC tMuxStatus _MUXAPI I2CTransfer(uint16_t wCard, tI2CInfo *hI2CInfo);
/* Appel de fonction propritaire                                           // Proprietary function */
_MUXSPEC tMuxStatus _MUXAPI FctProprietary(uint16_t wCard, tProprietaryInfo *hProprietaryInfo);
/* Activation */
_MUXSPEC tMuxStatus _MUXAPI PryActivate(uint16_t wCard, uint16_t wBus);
/* Dsactivation */
_MUXSPEC tMuxStatus _MUXAPI PryDeactivate(uint16_t wCard, uint16_t wBus);
/* Rcupration d'un vnement en provenance du rseau                      // Get an event from DLL */
_MUXSPEC tMuxStatus _MUXAPI PryGetEvent(uint16_t wCard, uint16_t wBus, tPryEvent *hPryEvent);
/* Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application */
_MUXSPEC tMuxStatus _MUXAPI PrySetNotification(uint16_t wCard, uint16_t wBus, void * hWinEvent);
/* Purge de la file d'attente de rception                                  // Flush FIFO rx */
_MUXSPEC tMuxStatus _MUXAPI PryClearFifoRx(uint16_t wCard, uint16_t wBus);
/* Etat de la FIFO                                                          // Counts of event in the receive queue */
_MUXSPEC tMuxStatus _MUXAPI PryGetFifoRxLevel(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
/* Configuration des voies analogiques                                      // Analog channels configuration */
_MUXSPEC tMuxStatus _MUXAPI ANATransfer(uint16_t wCard, tAnaTransfer *hAnaTransfer);
/* Lecture de la valeur des convertisseurs									//	Read the analogic register value */
_MUXSPEC tMuxStatus _MUXAPI ANAGetInput(uint16_t wCard, uint16_t wChannel, uint16_t *wInputValue);
/* Activation des entres PWM                                               // PWM input configuration */
_MUXSPEC tMuxStatus _MUXAPI PWMInputActivate(uint16_t wCard, uint16_t wNum, uint16_t wBusType, uint16_t wBus, uint16_t wPeriod, uint16_t wTimeOut);
/* Dsactivation des entres PWM                                            // PWM input configuration */
_MUXSPEC tMuxStatus _MUXAPI PWMInputDeactivate(uint16_t wCard, uint16_t wNum);
/* Configuration des sorties PWM                                            // PWM output configuration */
_MUXSPEC tMuxStatus _MUXAPI PWMOutputConfig(uint16_t wCard, uint16_t wNum, uint16_t wPrescaler, uint16_t wPeriod);
/* Activation des sorties PWM                                               // PWM output start */
_MUXSPEC tMuxStatus _MUXAPI PWMOutputActivate(uint16_t wCard, uint16_t wNum, uint16_t wValue);
/* Arrt des sorties PWM                                                    // PWM output stop */
_MUXSPEC tMuxStatus _MUXAPI PWMOutputDeactivate(uint16_t wCard, uint16_t wNum);
#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tIOSetOutput)(uint16_t wCard, uint16_t wOutputValue, uint16_t wOutputMask);
typedef tMuxStatus (__stdcall * tIOGetInput)(uint16_t wCard, uint16_t *wInputValue);
typedef tMuxStatus (__stdcall * tIOGetCount)(uint16_t wCard, uint16_t *wInputCount, uint16_t *wOutputCount);
typedef tMuxStatus (__stdcall * tIOConfigInput)(uint16_t wCard, uint16_t wInput, uint16_t wEdge);
typedef tMuxStatus (__stdcall * tIOConfigOutput)(uint16_t wCard, uint16_t wOutput, tTrigger *hTrigger);
typedef tMuxStatus (__stdcall * tSPITransfer)(uint16_t wCard, tSPIInfo *hSPIInfo);
typedef tMuxStatus (__stdcall * tI2CTransfer)(uint16_t wCard, tI2CInfo *hI2CInfo);
typedef tMuxStatus (__stdcall * tFctProprietary)(uint16_t wCard, tProprietaryInfo *hProprietaryInfo);
typedef tMuxStatus (__stdcall * tPryActivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tPryDeactivate)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tPryGetEvent)(uint16_t wCard, uint16_t wBus, tPryEvent *hPryEvent);
typedef tMuxStatus (__stdcall * tPrySetNotification)(uint16_t wCard, uint16_t wBus, void * hWinEvent);
typedef tMuxStatus (__stdcall * tPryClearFifoRx)(uint16_t wCard, uint16_t wBus);
typedef tMuxStatus (__stdcall * tPryGetFifoRxLevel)(uint16_t wCard, uint16_t wBus, uint16_t wParam, uint16_t *wCount, uint16_t *wMaxCount);
typedef tMuxStatus (__stdcall * tANATransfer)(uint16_t wCard, tAnaTransfer *hAnaTransfer);
typedef tMuxStatus (__stdcall * tANAGetInput)(uint16_t wCard, uint16_t wChannel, uint16_t *wInputValue);
typedef tMuxStatus (__stdcall * tPWMInputActivate)(uint16_t wCard, uint16_t wNum, uint16_t wBusType, uint16_t wBus, uint16_t wPeriod, uint16_t wTimeOut);
typedef tMuxStatus (__stdcall * tPWMInputDeactivate)(uint16_t wCard, uint16_t wNum);
typedef tMuxStatus (__stdcall * tPWMOutputConfig)(uint16_t wCard, uint16_t wNum, uint16_t wPrescaler, uint16_t wPeriod);
typedef tMuxStatus (__stdcall * tPWMOutputActivate)(uint16_t wCard, uint16_t wNum, uint16_t wValue);
typedef tMuxStatus (__stdcall * tPWMOutputDeactivate)(uint16_t wCard, uint16_t wNum);
#endif
#ifdef __cplusplus
	}
#endif
/*******************************************************************************
; Routines de gestion du timer
*******************************************************************************/
#ifdef __cplusplus
	extern "C" {
#endif
#ifndef MUX_DYNAMIC_DLL
/* Configuration du timer en millisecondes                                  // Milliseconde Timer configuration */
_MUXSPEC tMuxStatus _MUXAPI TimerSet(uint16_t wCard, uint16_t wTimerValue);
/* Initialisation du handle pour notifier un vnement  l'application      // Set a communication handle to notify an event to the application */
_MUXSPEC tMuxStatus _MUXAPI TimerSetNotification(uint16_t wCard, void * hWinEvent);
/* Lecture de l'horloge                                                     // Time reading */
_MUXSPEC tMuxStatus _MUXAPI TimerRead(uint16_t wCard, uint32_t *dwTimerValue, uint16_t *wTimeError, uint16_t *wMaxTimePrecision);
#else
/* Dclaration pour chargement dynamic      // Dynamic loading definition */
typedef tMuxStatus (__stdcall * tTimerSet)(uint16_t wCard, uint16_t wTimerValue);
typedef tMuxStatus (__stdcall * tTimerSetNotification)(uint16_t wCard, void * hWinEvent);
typedef tMuxStatus (__stdcall * tTimerRead)(uint16_t wCard, uint32_t *dwTimerValue, uint16_t *wTimeError, uint16_t *wMaxTimePrecision);
#endif
#ifdef __cplusplus
	}
#endif

/*******************************************************************************
; Routines de gestion des fichiers en flash
*******************************************************************************/
#define	FILE_MAX_DATA			4096

//	Handle sur un fichier		//	file Handle
typedef uint16_t	tFlashFile;

typedef enum _tFlashFileWhence
{
	FLASHFILE_WHENCE_BEGINING  	=	0,			//	Debut du fichier			   	//	Begining of the file
	FLASHFILE_WHENCE_CURRENT	=	1,			//	Emplacement courant du fichier	//	Current position of the file
	FLASHFILE_WHENCE_END		=	2			//	Fin du fichier					//	End of the file
} tFlashFileWhence ;


typedef enum _tFlashFATKind
{
	FLASHFATK_Unknown			=	0,			//	Type inconnu					//	Unknown kind
	FLASHFATK_FAT12				=	1,			//	FAT	12
	FLASHFATK_FAT16				=	2,			//	FAT	16
	FLASHFATK_FAT32				=	3			//	FAT	32
} tFlashFATKind ;

typedef struct _tFlashInformations
{
	uint32_t	dwTotalSpace;				//	Capacit de la Flash en clusters					//	Capacity of the Flash card in clusters
	uint32_t	dwFreeSpace;				//	Capacit restante en clusters 						//	Free capacity in clusters
	uint8_t	bLogicalUnit;				//	Numro du lecteur logique							// Logical Unit Number
	uint8_t	bReserved;					//	Rserv												// Reserved
	uint32_t	dwClusterSize;				//	Taille d'un cluster                					//  Cluster size
	uint32_t	dwClusterCount;				//	Nombre total de cluster								//	How many cluster ?
	char			szVolumeLabel[16];			//	Nom du volume										//	Volume name
	uint32_t	dwVolumeID;					//	Volume ID											//	Volume ID
	tFlashFATKind 	tFATKind;					//	Type de FAT (12,16,32,...)							//	FAT kind (12,16,32,...)
	char			szCFCardSN[20];				//  Numro de srie de la carte CompactFlash en ASCII	//Compact Flash serial number
	char			szCFCardModel[40];			//  Nom de la CF en ASCII 								//Compact Flash model name
	uint16_t	wPioMode;					//  Mode PIO (de 0  6) si 0xFFFF -> pas d'info 		//PIO mode
} tFlashInformations ;

typedef struct _tFlashFileDownloadData
{
	uint16_t	wReserved;					//	Rserv								//	Reserved
	void			*pvFatfile;					//	Rserv								//	Reserved
	uint16_t	tError;						//	Rserv								//	Reserved
	void			*pvUserData;				//	Pointeur sur des infos utilisateur		//	User data
	uint32_t	dwPacketCount;				//	N du paquet reu						//	Packet number
	uint32_t	dwBaudRate;					//	Dbit du transfert						//	Baudrate
	uint32_t	dwBytesDone;				//	Nombre d'octets dj rcupr			//	Number of bytes already downloaded
	uint32_t	dwTotalBytes;				//	Nombre d'octets total					//	total byte to download
	uint32_t	dwDataSize;					//	Nombre d'octet reu ce coup ci		//	Number of bytes read this time
	uint8_t	bData[ FILE_MAX_DATA ];		//	Donnes lus							//	Data
} tFlashFileDownloadData ;

typedef uint16_t ( *tFlashFileDownload_Callback )( tFlashFileDownloadData *tDownloadData );

#ifdef __cplusplus
	extern "C" {
#endif


#ifndef MUX_DYNAMIC_DLL
//	Ouverture de fichier									//	Open a file
_MUXSPEC tMuxStatus _MUXAPI FlashFileOpen( uint16_t wCard, char *szFileName, char *szMode, tFlashFile *hFile );
//	Fermeture de fichier									//	Close a file
_MUXSPEC tMuxStatus _MUXAPI FlashFileClose( uint16_t wCard, tFlashFile *hFile );
//	Lecture depuis un fichier								//	Read a buffer from a file
_MUXSPEC tMuxStatus _MUXAPI FlashFileRead( uint16_t wCard, void *vBuffer, uint16_t wSize, tFlashFile *hFile );
//	Ecriture dans un fichier								//	Write a buffer to a file
_MUXSPEC tMuxStatus _MUXAPI FlashFileWrite( uint16_t wCard, void *vBuffer, uint16_t wSize, tFlashFile *hFile );
//	Dplacement dans un fichier							//	Seek into a file
_MUXSPEC tMuxStatus _MUXAPI FlashFileSeek( uint16_t wCard, tFlashFileWhence hWhence, int32_t iOffset, tFlashFile *hFile );
//	Indique la position dans un fichier						// Tell the current file position
_MUXSPEC tMuxStatus _MUXAPI FlashFileTell( uint16_t wCard, uint32_t *dwPosition, tFlashFile *hFile );
//	Indique la taille d'un fichier						// Tell the size of a file
_MUXSPEC tMuxStatus _MUXAPI FlashFileGetSize( uint16_t wCard, uint32_t *dwSize, tFlashFile *hFile );
//	Informations sur la mmoire flash						//	Informations about flash card
_MUXSPEC tMuxStatus _MUXAPI FlashGetInformations( uint16_t wCard, tFlashInformations *tInfos );
//	Recherche le 1er fichier correspondant au masque	//	Find the first file mathcing the mask
_MUXSPEC tMuxStatus _MUXAPI FlashFindFirstFile( uint16_t wCard, char *szMask, char *szFoundFile );
//	Recherche le fichier suivant						//	Find the next file
_MUXSPEC tMuxStatus _MUXAPI FlashFindNextFile( uint16_t wCard, char *szFoundFile );
//	Efface le fichier									//	Delete the file
_MUXSPEC tMuxStatus _MUXAPI FlashFileDelete( uint16_t wCard, char *szFileName );
//	Tlcharge un fichier le plus rapidement possible		//	Download a file using the faster way available
_MUXSPEC tMuxStatus _MUXAPI FlashFileDownload( uint16_t wCard, char *szFileName, uint32_t dwOffset, uint32_t dwSize, tFlashFileDownload_Callback tCallBack, void *pvUserData );
//	Rpare un fichier corrompu							//	Repair a corrupted file
_MUXSPEC tMuxStatus _MUXAPI FlashFileRepair( uint16_t wCard, char *szFileName );
//	formate la flash									//	Format flash memory
_MUXSPEC tMuxStatus _MUXAPI FlashFormat( uint16_t wCard, char *szVolumeLabel, tFlashFATKind tFATKind, uint16_t wSectorPerCluster );
//	Informations sur le nombre de session				// Informations about session count
_MUXSPEC tMuxStatus _MUXAPI FlashFileCountSession( uint16_t wCard, uint32_t *wTotalSession, uint16_t *wEmptySession );
//	Recherche le 1er fichier correspondant au filtre	//	Find the first file mathcing the filter
_MUXSPEC tMuxStatus _MUXAPI FlashFindFirstFileInFilter( uint16_t wCard, char *szMask, char *szFoundFile, uint32_t * ulDateStart, uint32_t *ulDateStop );
//	Recherche le fichier suivant correspondant au filtre	//	Find the next file mathcing the filter
_MUXSPEC tMuxStatus _MUXAPI FlashFindNextFileInFilter( uint16_t wCard, char *szFoundFile);
#else
//	Ouverture de fichier									//	Open a file
typedef tMuxStatus (__stdcall * tFlashFileOpen)( uint16_t wCard, char *szFileName, char *szMode, tFlashFile *hFile );
//	Fermeture de fichier									//	Close a file
typedef tMuxStatus (__stdcall * tFlashFileClose)( uint16_t wCard, tFlashFile *hFile );
//	Lecture depuis un fichier								//	Read a buffer from a file
typedef tMuxStatus (__stdcall * tFlashFileRead)( uint16_t wCard, void *vBuffer, uint16_t wSize, tFlashFile *hFile );
//	Ecriture dans un fichier								//	Write a buffer to a file
typedef tMuxStatus (__stdcall * tFlashFileWrite)( uint16_t wCard, void *vBuffer, uint16_t wSize, tFlashFile *hFile );
//	Dplacement dans un fichier							//	Seek into a file
typedef tMuxStatus (__stdcall * tFlashFileSeek)( uint16_t wCard, tFlashFileWhence hWhence, int32_t iOffset, tFlashFile *hFile );
//	Indique la position dans un fichier						// Tell the current file position
typedef tMuxStatus (__stdcall * tFlashFileTell)( uint16_t wCard, uint32_t *dwPosition, tFlashFile *hFile );
//	Indique la taille d'un fichier						// Tell the size of a file
typedef tMuxStatus (__stdcall * tFlashFileGetSize)( uint16_t wCard, uint32_t *dwSize, tFlashFile *hFile );
//	Informations sur la mmoire flash					//	Informations about flash card
typedef tMuxStatus (__stdcall * tFlashGetInformations)( uint16_t wCard, tFlashInformations *tInfos );
//	Informations sur la mmoire flash						//	Informations about flash card
typedef tMuxStatus (__stdcall * tFlashFindFirstFile )( uint16_t wCard, char *szMask, char *szFoundFile );
//	Recherche le fichier suivant						//	Find the next file
typedef tMuxStatus (__stdcall * tFlashFindNextFile )( uint16_t wCard, char *szFoundFile );
//	Efface le fichier									//	Delete the file
typedef tMuxStatus (__stdcall * tFlashFileDelete )( uint16_t wCard, char *szFileName );
//	Tlcharge un fichier le plus rapidement possible		//	Download a file using the faster way available
typedef tMuxStatus (__stdcall * tFlashFileDownload )( uint16_t wCard, char *szFileName, uint32_t dwOffset, uint32_t dwSize, tFlashFileDownload_Callback tCallBack, void *pvUserData );
//	Rpare un fichier corrompu							//	Repair a corrupted file
typedef tMuxStatus (__stdcall * tFlashFileRepair )( uint16_t wCard, char *szFileName );
//	formate la flash									//	Format flash memory
typedef tMuxStatus (__stdcall * tFlashFormat)( uint16_t wCard, char *szVolumeLabel, tFlashFATKind tFATKind, uint16_t wSectorPerCluster );
//	Informations sur le nombre de session				// Informations about session count
typedef tMuxStatus (__stdcall * tFlashFileCountSession)( uint16_t wCard, uint32_t *wTotalSession, uint16_t *wEmptySession );
//	Recherche le 1er fichier correspondant au filtre	//	Find the first file mathcing the filter
typedef tMuxStatus (__stdcall * tFlashFindFirstFileInFilter)( uint16_t wCard, char *szMask, char *szFoundFile, uint32_t * ulDateStart, uint32_t *ulDateStop );
//	Recherche le fichier suivant correspondant au filtre	//	Find the next file mathcing the filter
typedef tMuxStatus (__stdcall * tFlashFindNextFileInFilter)( uint16_t wCard, char *szFoundFile );
#endif

#ifdef __cplusplus
	}
#endif

/*******************************************************************************
;	Routines de gestion des priphriques USB
*******************************************************************************/
#define	USB_MAX_DEVICES		32
#define	USB_MAX_PIPES		32

typedef enum _tUSBPipeDirection
{
	USB_PipeDir_In				= 1,					//	Pipe en lecture				//	Read pipe
	USB_PipeDir_Out		   		= 2,					//	Pipe en ecriture			//	Write pipe
	USB_PipeDir_InOut			= 3						//	Pipe en lecture/ecriture   	//	Read/Write pipe
} tUSBPipeDirection ;

typedef enum _tUSBPipeType
{
	USB_PipeType_Control		= 0,					//	Pipe de control		//	Control pipe
	USB_PipeType_Isochronous	= 1,					//	Pipe isochrone		//	Isochronous pipe
	USB_PipeType_Bulk	        = 2,					//	Pipe bulk			//	Bulk pipe
	USB_PipeType_Interrupt		= 3						//	Interrupt pipe
} tUSBPipeType ;

typedef struct _tUSBPipe
{
	tUSBPipeDirection	tDirection;						//	Direction du pipe	//	Pipe direction
	tUSBPipeType		tType;							//	Type de pipe		//	Pipe type
	uint32_t		dwMaxPacketSize;				//	Taille max des paquets d'change	//	Max size of usb packet data
} tUSBPipe ;

typedef struct _tUSBPipeInfos
{
	tUSBPipe		tPipeList[ USB_MAX_PIPES ];			//	Configuration des pipes	//	configuration of pipes
	uint16_t	wPipeCount;							//	Nombre de pipes	//	Number of pipes	
} tUSBPipeInfos ;

typedef struct _tUSBDeviceID
{
	uint16_t	wVendorID;							//	Vendor ID
	uint16_t	wProductID;							//	Product ID
} tUSBDeviceID ;

typedef struct _tUSBDeviceInfo
{
	uint32_t	dwHubNumber;						//	N du hub		//	Hub number
	uint32_t	dwPortNumber;						//	N du port		//	Port number
	uint32_t	dwFullSpeed;						//	USB Full Speed ?
	uint32_t	dwDeviceAdress;						//	Adresse du priphrique	//	Device address
	uint32_t	dwUniqueID;							//	ID du priphrique		//	Device ID
} tUSBDeviceInfo ;

typedef struct _tUSBDevice
{
	tUSBDeviceID	tID;								//	ID du priphrique	//	Device ID
	tUSBDeviceInfo	tInfos;								//	Informations			
} tUSBDevice ; 

typedef struct _tUSBDeviceList
{
	tUSBDevice		tDeviceList[ USB_MAX_DEVICES ];		//	Liste des priphrique	//	Liste des priphriques
	uint16_t	wDeviceCount;						//	Nombre de priphrique	//	Number of devices
} tUSBDeviceList ;

#ifdef __cplusplus
	extern "C" {
#endif

#ifndef MUX_DYNAMIC_DLL
//	Rcupre la liste des priphrique connects	//	Get the list of connected devices
_MUXSPEC tMuxStatus _MUXAPI USBLIB_GetDeviceList( tUSBDeviceID *tDevFilter, tUSBDeviceList *tDevList );
//	Ouvre un priphrique	//	Open a device
_MUXSPEC tMuxStatus _MUXAPI USBLIB_Open( uint16_t wCard );
//	Ferme un priphrique	//	Ferme a device
_MUXSPEC tMuxStatus _MUXAPI USBLIB_Close( uint16_t wCard );
//	Rcupre les informations sur les pipes	//	Gets informations about pipes
_MUXSPEC tMuxStatus _MUXAPI USBLIB_GetPipesInfos( uint16_t wCard, tUSBPipeInfos *tPipeInfos );
//	Envoi de donnes sur un pipe	//	Sends data on a pipe
_MUXSPEC tMuxStatus _MUXAPI USBLIB_Send( uint16_t wCard, uint16_t wPipe, uint8_t *szData, uint32_t dwDataLen, uint32_t dwTimeOut );
//	Envoi de donnes sur le pipe00	//	Writes data on pipe00
_MUXSPEC tMuxStatus _MUXAPI USBLIB_WritePipe00( uint16_t wCard, uint8_t *byBuffer, uint32_t dwDataLen, uint32_t dwTimeOut, uint8_t *bySetupPacket );
//	Lecture de donnes sur le pipe00	//	Reads datas on pipe00
_MUXSPEC tMuxStatus _MUXAPI USBLIB_ReadPipe00( uint16_t wCard, uint8_t *byBuffer, uint32_t dwDataLen, uint32_t dwTimeOut, uint8_t *bySetupPacket );
//	Lecture de donne sur un pipe	//	Reads data on a pipe
_MUXSPEC tMuxStatus _MUXAPI USBLIB_Read( uint16_t wCard, uint16_t wPipe, uint8_t *szData, uint32_t *pdwDataLen, uint32_t dwTimeOut );
//	Arrt d'une lecture en cours	//	Cancel a read operation in progress
_MUXSPEC tMuxStatus _MUXAPI USBLIB_ReadCancel( uint16_t wCard, uint16_t wPipe );
//	Compte le nombre de endpoint de la carte	// Retrieve the number of endpoints
_MUXSPEC tMuxStatus _MUXAPI USBLIB_GetEndpointNumber( uint16_t wCard, uint32_t *dwNumEndpoint );
//retourne le descripteur usb					//return usb descriptor
_MUXSPEC tMuxStatus _MUXAPI USBLIB_GetHardwareID(uint16_t wCard, char *szHardwareID, uint32_t dwSize);
_MUXSPEC tMuxStatus _MUXAPI USBLIB_GetDeviceIDs( uint16_t card, uint16_t *vendorId, uint16_t *productId, uint16_t *revision );
#else
//	Rcupre la liste des priphrique connects	//	Get the list of connected devices
typedef tMuxStatus (__stdcall * tUSBLIB_GetDeviceList )( tUSBDeviceID *tDevFilter, tUSBDeviceList *tDevList );
//	Ouvre un priphrique	//	Open a device
typedef tMuxStatus (__stdcall * tUSBLIB_Open )( uint16_t wCard );
//	Ferme un priphrique	//	Ferme a device
typedef tMuxStatus (__stdcall * tUSBLIB_Close )( uint16_t wCard );
//	Rcupre les informations sur les pipes	//	Gets informations about pipes
typedef tMuxStatus (__stdcall * tUSBLIB_GetPipesInfos )( uint16_t wCard, tUSBPipeInfos *tPipeInfos );
//	Envoi de donnes sur un pipe	//	Sends data on a pipe
typedef tMuxStatus (__stdcall * tUSBLIB_Send )( uint16_t wCard, uint16_t wPipe, uint8_t *szData, uint32_t dwDataLen, uint32_t dwTimeOut );
//	Envoi de donnes sur le pipe00	//	Writes data on pipe00
typedef tMuxStatus (__stdcall * tUSBLIB_WritePipe00 )( uint16_t wCard, uint8_t *byBuffer, uint32_t dwDataLen, uint32_t dwTimeOut, uint8_t *bySetupPacket );
//	Lecture de donnes sur le pipe00	//	Reads datas on pipe00
typedef tMuxStatus (__stdcall * tUSBLIB_ReadPipe00 )( uint16_t wCard, uint8_t *byBuffer, uint32_t dwDataLen, uint32_t dwTimeOut, uint8_t *bySetupPacket );
//	Lecture de donne sur un pipe	//	Reads data on a pipe
typedef tMuxStatus (__stdcall * tUSBLIB_Read )( uint16_t wCard, uint16_t wPipe, uint8_t *szData, uint32_t *pdwDataLen, uint32_t dwTimeOut );
//	Arrt d'une lecture en cours	//	Cancel a read operation in progress
typedef tMuxStatus (__stdcall * tUSBLIB_ReadCancel )( uint16_t wCard, uint16_t wPipe );
//	Compte le nombre de endpoint de la carte	// Retrieve the number of endpoints
typedef tMuxStatus (__stdcall * tUSBLIB_GetEndpointNumber )( uint16_t wCard, uint32_t *dwNumEndpoint );
//retourne le descripteur usb					//return usb descriptor
typedef tMuxStatus (__stdcall * tUSBLIB_GetHardwareID )(uint16_t wCard, char *szHardwareID, unsigned long dwSize);
typedef tMuxStatus( __stdcall * tUSBLIB_GetDeviceIDs )( uint16_t card, uint16_t *vendorId, uint16_t *productId, uint16_t *revision );
#endif

#ifdef __cplusplus
	}
#endif

#ifdef MUX_DYNAMIC_DLL
/* Dclaration des pointeurs de fonctions vers la DLL   // DLL Function pointer */
#ifndef MUX_DYNAMIC_DLL_EXTERN
 #define _MUX_DLL_EXTERN /**/
#else
 #define _MUX_DLL_EXTERN extern
#endif

tMuxStatus MuxFreeDLL(void);
tMuxStatus MuxLoadDLL(void);
tMuxStatus MuxLoadDLLClient(void);

_MUX_DLL_EXTERN tMuxGetTimings			MuxGetTimings;
_MUX_DLL_EXTERN tMuxGlobalInit			MuxGlobalInit;
_MUX_DLL_EXTERN tMuxSetUserTimerFct		MuxSetUserTimerFct;
_MUX_DLL_EXTERN tMuxCreateEvent			MuxCreateEvent;
_MUX_DLL_EXTERN tMuxCloseEvent			MuxCloseEvent;
_MUX_DLL_EXTERN tMuxWaitOnEvent			MuxWaitOnEvent;
_MUX_DLL_EXTERN tMuxSetEvent			MuxSetEvent;
_MUX_DLL_EXTERN tMuxClientServerMode	MuxClientServerMode;
_MUX_DLL_EXTERN tMuxCheckAlignment		MuxCheckAlignment;
_MUX_DLL_EXTERN tMuxCountCards		    MuxCountCards;
_MUX_DLL_EXTERN tMuxPciCountCards	    MuxPciCountCards;
_MUX_DLL_EXTERN tMuxUsbCountCards	    MuxUsbCountCards;
_MUX_DLL_EXTERN tMuxEthCountCards		MuxEthCountCards;
_MUX_DLL_EXTERN tMuxPciGetCardInfo	    MuxPciGetCardInfo;
_MUX_DLL_EXTERN tMuxUsbGetCardInfo	    MuxUsbGetCardInfo;
_MUX_DLL_EXTERN tMuxEthGetCardInfo	    MuxEthGetCardInfo;
_MUX_DLL_EXTERN tMuxInit			    MuxInit;
_MUX_DLL_EXTERN tMuxOpen			    MuxOpen;
_MUX_DLL_EXTERN tMuxGetVersion		    MuxGetVersion;
_MUX_DLL_EXTERN tMuxGetDescription		MuxGetDescription;

_MUX_DLL_EXTERN tMuxGetInformations		MuxGetInformations;
_MUX_DLL_EXTERN tMuxClose			    MuxClose;
_MUX_DLL_EXTERN tMuxGetLastErrorString	MuxGetLastErrorString;
_MUX_DLL_EXTERN tMuxGetProtectedCode	MuxGetProtectedCode;
_MUX_DLL_EXTERN tMuxUsbDownload	        MuxUsbDownload;
_MUX_DLL_EXTERN tMuxGetInternalInfo	    MuxGetInternalInfo;
_MUX_DLL_EXTERN tMuxIsLicenceActive		MuxIsLicenceActive;
_MUX_DLL_EXTERN tMuxSetProductIDMode	MuxSetProductIDMode;
_MUX_DLL_EXTERN tMuxGetBuildNumber		MuxGetBuildNumber;
_MUX_DLL_EXTERN tMuxGetRTCValue			MuxGetRTCValue;
_MUX_DLL_EXTERN tMuxSetRTCValue			MuxSetRTCValue;
_MUX_DLL_EXTERN tMuxUsbResetPipe		MuxUsbResetPipe;
_MUX_DLL_EXTERN tMuxGetHardwareID		MuxGetHardwareID;
_MUX_DLL_EXTERN tMuxSetEthernet			MuxSetEthernet;
_MUX_DLL_EXTERN tMuxGetEthernet			MuxGetEthernet;


_MUX_DLL_EXTERN tAdminOpenSession		AdminOpenSession;
_MUX_DLL_EXTERN tAdminWriteConfig		AdminWriteConfig;
_MUX_DLL_EXTERN tAdminReadConfig		AdminReadConfig;
_MUX_DLL_EXTERN tAdminGetLicenceCount	AdminGetLicenceCount;
_MUX_DLL_EXTERN tAdminReadLicences		AdminReadLicences;
_MUX_DLL_EXTERN tAdminWriteLicences		AdminWriteLicences;
_MUX_DLL_EXTERN tAdminGetLicenceData	AdminGetLicenceData;
_MUX_DLL_EXTERN tAdminSetLicenceData	AdminSetLicenceData;
_MUX_DLL_EXTERN tAdminReadLicencesData	AdminReadLicencesData;
_MUX_DLL_EXTERN tAdminWriteLicencesData	AdminWriteLicencesData;

_MUX_DLL_EXTERN tSysSetNotification		SysSetNotification;
_MUX_DLL_EXTERN tSysGetEvent			SysGetEvent;

_MUX_DLL_EXTERN tCanConfigOper		    CanConfigOper;
_MUX_DLL_EXTERN tCanConfigBus		    CanConfigBus;
_MUX_DLL_EXTERN tCanConfigParam		    CanConfigParam;
_MUX_DLL_EXTERN tCanConfigRangeFilter	CanConfigRangeFilter;	
_MUX_DLL_EXTERN tCanConfigClock			CanConfigClock;
_MUX_DLL_EXTERN tCanConfigDualFilter    CanConfigDualFilter;
_MUX_DLL_EXTERN tCanConfigStat		    CanConfigStat;
_MUX_DLL_EXTERN tCanConfigTransceiverHS CanConfigTransceiverHS;
_MUX_DLL_EXTERN tCanSelectTransceiverHS CanSelectTransceiverHS;
_MUX_DLL_EXTERN tCanConfigTransceiverLS CanConfigTransceiverLS;
_MUX_DLL_EXTERN tCanConfigTerminationLS CanConfigTerminationLS;
_MUX_DLL_EXTERN tCanReadTransceiverLS   CanReadTransceiverLS;
_MUX_DLL_EXTERN tCanCreateMsg		    CanCreateMsg;
_MUX_DLL_EXTERN tCanReadMsg				CanReadMsg;
_MUX_DLL_EXTERN tCanWriteMsg			CanWriteMsg;
_MUX_DLL_EXTERN tCanConfigPeriodic		CanConfigPeriodic;
_MUX_DLL_EXTERN tCanConfigPeriodicList	CanConfigPeriodicList;
_MUX_DLL_EXTERN tCanSetNotification	    CanSetNotification;
_MUX_DLL_EXTERN tCanActivate		    CanActivate;
_MUX_DLL_EXTERN tCanIsBusActive         CanIsBusActive;
_MUX_DLL_EXTERN tCanDeactivate		    CanDeactivate;
_MUX_DLL_EXTERN tCanSendMsg			    CanSendMsg;
_MUX_DLL_EXTERN tCanSendMsgList			CanSendMsgList;
_MUX_DLL_EXTERN tCanGetEvent		    CanGetEvent;
_MUX_DLL_EXTERN tCanBusOn			    CanBusOn;
_MUX_DLL_EXTERN tCanChangeBaudRate		CanChangeBaudRate;
_MUX_DLL_EXTERN tCanGetStat			    CanGetStat;
_MUX_DLL_EXTERN tCanGetBusState		    CanGetBusState;
_MUX_DLL_EXTERN tCanClearFifoRx		    CanClearFifoRx;
_MUX_DLL_EXTERN tCanGetFifoRxLevel      CanGetFifoRxLevel;
_MUX_DLL_EXTERN tCanReadByte		    CanReadByte;
_MUX_DLL_EXTERN tCanWriteByte		    CanWriteByte;

_MUX_DLL_EXTERN tNwcRegister		    NwcRegister;
_MUX_DLL_EXTERN tNwcGetChannelCount	    NwcGetChannelCount;
_MUX_DLL_EXTERN tNwcChannelOpen 	    NwcChannelOpen;
_MUX_DLL_EXTERN tNwcChannelConfig       NwcChannelConfig;
_MUX_DLL_EXTERN tNwcChannelParam	    NwcChannelParam;
_MUX_DLL_EXTERN tNwcChannelAddr 	    NwcChannelAddr;
_MUX_DLL_EXTERN tNwcChannelStart	    NwcChannelStart;
_MUX_DLL_EXTERN tNwcChannelStop 	    NwcChannelStop;
_MUX_DLL_EXTERN tNwcChannelClose 	    NwcChannelClose;
_MUX_DLL_EXTERN tNwcSetNotification	    NwcSetNotification;
_MUX_DLL_EXTERN tNwcActivate            NwcActivate;
_MUX_DLL_EXTERN tNwcIsBusActive         NwcIsBusActive;
_MUX_DLL_EXTERN tNwcDeactivate          NwcDeactivate;
_MUX_DLL_EXTERN tNwcChannelSendMsg      NwcChannelSendMsg;
_MUX_DLL_EXTERN tNwcChannelSendAsyncMsg NwcChannelSendAsyncMsg;
_MUX_DLL_EXTERN tNwcGetEvent            NwcGetEvent;
_MUX_DLL_EXTERN tNwcGetIdent            NwcGetIdent;
_MUX_DLL_EXTERN tNwcGetFifoRxLevel      NwcGetFifoRxLevel;
_MUX_DLL_EXTERN tNwcConfigSpyMode       NwcConfigSpyMode;
_MUX_DLL_EXTERN tNwcGetChannelState     NwcGetChannelState;
_MUX_DLL_EXTERN tNwcChannelSetBytePadding		NwcChannelSetBytePadding;

_MUX_DLL_EXTERN tJ19Register		    J19Register;
_MUX_DLL_EXTERN tJ19ChannelOpen			J19ChannelOpen;
_MUX_DLL_EXTERN tJ19ChannelAddr			J19ChannelAddr;
_MUX_DLL_EXTERN tJ19ChannelParam		J19ChannelParam;
_MUX_DLL_EXTERN tJ19ChannelConfig		J19ChannelConfig;
_MUX_DLL_EXTERN tJ19ChannelStart		J19ChannelStart;
_MUX_DLL_EXTERN tJ19ChannelStop			J19ChannelStop;
_MUX_DLL_EXTERN tJ19ChannelClose		J19ChannelClose;
_MUX_DLL_EXTERN tJ19Activate			J19Activate;
_MUX_DLL_EXTERN tJ19IsBusActive         J19IsBusActive;
_MUX_DLL_EXTERN tJ19ConfigBus           J19ConfigBus;
_MUX_DLL_EXTERN tJ19Deactivate			J19Deactivate;
_MUX_DLL_EXTERN tJ19ChannelSendMsg		J19ChannelSendMsg;
_MUX_DLL_EXTERN tJ19ChannelSendNMEAFastPacket	J19ChannelSendNMEAFastPacket;
_MUX_DLL_EXTERN tJ19SetNotification		J19SetNotification;
_MUX_DLL_EXTERN tJ19GetEvent			J19GetEvent;
_MUX_DLL_EXTERN tJ19GetFifoRxLevel		J19GetFifoRxLevel;
_MUX_DLL_EXTERN tJ19StoreNMEAFastPacket	J19StoreNMEAFastPacket;
_MUX_DLL_EXTERN tJ1939SetParam          J1939SetParam;
_MUX_DLL_EXTERN tJ1939IsBusActive       J1939IsBusActive;
_MUX_DLL_EXTERN tJ1939SendMsg           J1939SendMsg;
_MUX_DLL_EXTERN tJ1939SetNotification   J1939SetNotification;
_MUX_DLL_EXTERN tJ1939GetEvent          J1939GetEvent;
_MUX_DLL_EXTERN tJ1939GetFifoRxLevel    J1939GetFifoRxLevel;

_MUX_DLL_EXTERN tLinConfigOper          LinConfigOper;
_MUX_DLL_EXTERN tLinConfigBus		    LinConfigBus;
_MUX_DLL_EXTERN tLinConfigUart		    LinConfigUart;
_MUX_DLL_EXTERN tLinConfigParam		    LinConfigParam;
_MUX_DLL_EXTERN tLinConfigStat		    LinConfigStat;
_MUX_DLL_EXTERN tLinSetVersion		    LinSetVersion;
_MUX_DLL_EXTERN tLinSetNotification	    LinSetNotification;
_MUX_DLL_EXTERN tLinActivate		    LinActivate;
_MUX_DLL_EXTERN tLinIsBusActive		    LinIsBusActive;
_MUX_DLL_EXTERN tLinConfigTransceiver   LinConfigTransceiver;
_MUX_DLL_EXTERN tLinConfigPeriodic		LinConfigPeriodic;
_MUX_DLL_EXTERN tLinConfigPeriodicList	LinConfigPeriodicList;
_MUX_DLL_EXTERN tLinDeactivate		    LinDeactivate;
_MUX_DLL_EXTERN tLinSendMsg			    LinSendMsg;
_MUX_DLL_EXTERN tLinSendMsgList		    LinSendMsgList;
_MUX_DLL_EXTERN tLinGetEvent		    LinGetEvent;
_MUX_DLL_EXTERN tLinGetStat			    LinGetStat;
_MUX_DLL_EXTERN tLinGetBusState		    LinGetBusState;
_MUX_DLL_EXTERN tLinSetSleepMode	    LinSetSleepMode;
_MUX_DLL_EXTERN tLinSetWakeUpMode	    LinSetWakeUpMode;
_MUX_DLL_EXTERN tLinClearFifoRx	        LinClearFifoRx;
_MUX_DLL_EXTERN tLinClearBufferIFR	    LinClearBufferIFR;
_MUX_DLL_EXTERN tLinGetFifoRxLevel      LinGetFifoRxLevel;

_MUX_DLL_EXTERN tNwlGetChannelCount	    NwlGetChannelCount;
_MUX_DLL_EXTERN tNwlChannelOpen 	    NwlChannelOpen;
_MUX_DLL_EXTERN tNwlChannelConfig       NwlChannelConfig;
_MUX_DLL_EXTERN tNwlChannelParam	    NwlChannelParam;
_MUX_DLL_EXTERN tNwlChannelAddr 	    NwlChannelAddr;
_MUX_DLL_EXTERN tNwlChannelStart	    NwlChannelStart;
_MUX_DLL_EXTERN tNwlChannelStop 	    NwlChannelStop;
_MUX_DLL_EXTERN tNwlChannelClose 	    NwlChannelClose;
_MUX_DLL_EXTERN tNwlSetNotification	    NwlSetNotification;
_MUX_DLL_EXTERN tNwlActivate            NwlActivate;
_MUX_DLL_EXTERN tNwlIsBusActive         NwlIsBusActive;
_MUX_DLL_EXTERN tNwlDeactivate          NwlDeactivate;
_MUX_DLL_EXTERN tNwlChannelSendMsg      NwlChannelSendMsg;
_MUX_DLL_EXTERN tNwlChannelReceiveMsg   NwlChannelReceiveMsg;
_MUX_DLL_EXTERN tNwlGetEvent            NwlGetEvent;
_MUX_DLL_EXTERN tNwlGetFifoRxLevel      NwlGetFifoRxLevel;
_MUX_DLL_EXTERN tNwlGetChannelState     NwlGetChannelState;

_MUX_DLL_EXTERN tVanConfigOper          VanConfigOper;
_MUX_DLL_EXTERN tVanConfigBus           VanConfigBus;
_MUX_DLL_EXTERN tVanConfigParam         VanConfigParam;
_MUX_DLL_EXTERN tVanConfigStat          VanConfigStat;
_MUX_DLL_EXTERN tVanCreateMsg           VanCreateMsg;
_MUX_DLL_EXTERN tVanConfigPeriodic		VanConfigPeriodic;
_MUX_DLL_EXTERN tVanConfigPeriodicList	VanConfigPeriodicList;
_MUX_DLL_EXTERN tVanSetNotification     VanSetNotification;
_MUX_DLL_EXTERN tVanActivate            VanActivate;
_MUX_DLL_EXTERN tVanIsBusActive         VanIsBusActive;
_MUX_DLL_EXTERN tVanDeactivate          VanDeactivate;
_MUX_DLL_EXTERN tVanSendMsg             VanSendMsg;
_MUX_DLL_EXTERN tVanSendMsgList			VanSendMsgList;
_MUX_DLL_EXTERN tVanGetEvent            VanGetEvent;
_MUX_DLL_EXTERN tVanGetStat             VanGetStat;
_MUX_DLL_EXTERN tVanGetBusState         VanGetBusState;
_MUX_DLL_EXTERN tVanSetSleepMode        VanSetSleepMode;
_MUX_DLL_EXTERN tVanSetWakeUpMode       VanSetWakeUpMode;
_MUX_DLL_EXTERN tVanGetSleepMode        VanGetSleepMode;
_MUX_DLL_EXTERN tVanSetTIP              VanSetTIP;
_MUX_DLL_EXTERN tVanGetSDCValue         VanGetSDCValue;
_MUX_DLL_EXTERN tVanClearFifoRx         VanClearFifoRx;
_MUX_DLL_EXTERN tVanGetFifoRxLevel      VanGetFifoRxLevel;
_MUX_DLL_EXTERN tVanReadByte            VanReadByte;
_MUX_DLL_EXTERN tVanWriteByte           VanWriteByte;

_MUX_DLL_EXTERN tIsoConfigOper          IsoConfigOper;
_MUX_DLL_EXTERN tIsoConfigBus           IsoConfigBus;
_MUX_DLL_EXTERN tIsoConfigUart           IsoConfigUart;
_MUX_DLL_EXTERN tIsoConfigParam		    IsoConfigParam;
_MUX_DLL_EXTERN tIsoConfigStat		    IsoConfigStat;
_MUX_DLL_EXTERN tIsoConfigPeriodic		IsoConfigPeriodic;
_MUX_DLL_EXTERN tIso14230ConfigPeriodic	Iso14230ConfigPeriodic;
_MUX_DLL_EXTERN tIsoActivate            IsoActivate;
_MUX_DLL_EXTERN tIsoIsBusActive         IsoIsBusActive;
_MUX_DLL_EXTERN tIsoDeactivate          IsoDeactivate;
_MUX_DLL_EXTERN tIsoSetNotification     IsoSetNotification;
_MUX_DLL_EXTERN tIsoSendMsg             IsoSendMsg;
_MUX_DLL_EXTERN tIso14230SendMsg        Iso14230SendMsg;
_MUX_DLL_EXTERN tIsoGetEvent            IsoGetEvent;
_MUX_DLL_EXTERN tIsoWaitResponse        IsoWaitResponse;
_MUX_DLL_EXTERN tIsoSendResp            IsoSendResp;
_MUX_DLL_EXTERN tIsoChangeBaudRate      IsoChangeBaudRate;
_MUX_DLL_EXTERN tIsoGetStat			    IsoGetStat;
_MUX_DLL_EXTERN tIsoClearFifoRx		    IsoClearFifoRx;
_MUX_DLL_EXTERN tIsoGetFifoRxLevel      IsoGetFifoRxLevel;
_MUX_DLL_EXTERN tIsoSetDataRxLevel      IsoSetDataRxLevel;
_MUX_DLL_EXTERN tIsoReadByte            IsoReadByte;
_MUX_DLL_EXTERN tIsoWriteByte           IsoWriteByte;

_MUX_DLL_EXTERN tJ18ConfigOper          J18ConfigOper;
_MUX_DLL_EXTERN tJ18ConfigBus		J18ConfigBus;
_MUX_DLL_EXTERN tJ18Activate		J18Activate;
_MUX_DLL_EXTERN tJ18IsBusActive         J18IsBusActive;
_MUX_DLL_EXTERN tJ18Deactivate	        J18Deactivate;
_MUX_DLL_EXTERN tJ18SendMsg		J18SendMsg;
_MUX_DLL_EXTERN tJ18GetEvent		J18GetEvent;
_MUX_DLL_EXTERN tJ18SetNotification     J18SetNotification;

_MUX_DLL_EXTERN tJ1587ConfigOper        J1587ConfigOper;
_MUX_DLL_EXTERN tJ1587ConfigBus		    J1587ConfigBus;
_MUX_DLL_EXTERN tJ1587ConfigParam	    J1587ConfigParam;
_MUX_DLL_EXTERN tJ1587ConfigStat 	    J1587ConfigStat;
_MUX_DLL_EXTERN tJ1587ConfigPeriodic	J1587ConfigPeriodic;
_MUX_DLL_EXTERN tJ1587Activate		    J1587Activate;
_MUX_DLL_EXTERN tJ1587IsBusActive       J1587IsBusActive;
_MUX_DLL_EXTERN tJ1587Deactivate	    J1587Deactivate;
_MUX_DLL_EXTERN tJ1587SendMsg		    J1587SendMsg;
_MUX_DLL_EXTERN tJ1587GetEvent		    J1587GetEvent;
_MUX_DLL_EXTERN tJ1587GetBusState 	    J1587GetBusState;
_MUX_DLL_EXTERN tJ1587GetStat	 	    J1587GetStat;
_MUX_DLL_EXTERN tJ1587SetNotification   J1587SetNotification;
_MUX_DLL_EXTERN tJ1587ClearFifoRx		J1587ClearFifoRx;
_MUX_DLL_EXTERN tJ1587GetFifoRxLevel    J1587GetFifoRxLevel;

_MUX_DLL_EXTERN tNMEA0183ConfigOper      NMEA0183ConfigOper;
_MUX_DLL_EXTERN tNMEA0183ConfigBus		 NMEA0183ConfigBus;
_MUX_DLL_EXTERN tNMEA0183ConfigUart		 NMEA0183ConfigUart;
_MUX_DLL_EXTERN tNMEA0183ConfigParam	 NMEA0183ConfigParam;
_MUX_DLL_EXTERN tNMEA0183ConfigStat 	 NMEA0183ConfigStat;
_MUX_DLL_EXTERN tNMEA0183ConfigPeriodic	 NMEA0183ConfigPeriodic;
_MUX_DLL_EXTERN tNMEA0183Activate		 NMEA0183Activate;
_MUX_DLL_EXTERN tNMEA0183IsBusActive     NMEA0183IsBusActive;
_MUX_DLL_EXTERN tNMEA0183Deactivate	     NMEA0183Deactivate;
_MUX_DLL_EXTERN tNMEA0183SendMsg		 NMEA0183SendMsg;
_MUX_DLL_EXTERN tNMEA0183GetEvent		 NMEA0183GetEvent;
_MUX_DLL_EXTERN tNMEA0183GetBusState 	 NMEA0183GetBusState;
_MUX_DLL_EXTERN tNMEA0183GetStat	 	 NMEA0183GetStat;
_MUX_DLL_EXTERN tNMEA0183SetNotification NMEA0183SetNotification;
_MUX_DLL_EXTERN tNMEA0183ClearFifoRx	 NMEA0183ClearFifoRx;
_MUX_DLL_EXTERN tNMEA0183GetFifoRxLevel  NMEA0183GetFifoRxLevel;

#ifdef _WIN32_WCE	// Under Windows CE
_MUX_DLL_EXTERN tWINCEConfigParam		WINCEConfigParam;
_MUX_DLL_EXTERN tWINCESetNotification	WINCESetNotification;
_MUX_DLL_EXTERN tWINCEActivate			WINCEActivate;
_MUX_DLL_EXTERN tWINCEDeactivate		WINCEDeactivate;
_MUX_DLL_EXTERN tWINCEGetPowerState		WINCEGetPowerState;
_MUX_DLL_EXTERN tWINCEGetEvent			WINCEGetEvent;
_MUX_DLL_EXTERN tWINCEIsDriverUnloaded	WINCEIsDriverUnloaded;
#endif	// _WIN32_WCE	

_MUX_DLL_EXTERN tIOSetOutput		    IOSetOutput;
_MUX_DLL_EXTERN tIOGetInput			    IOGetInput;
_MUX_DLL_EXTERN tIOGetCount			    IOGetCount;
_MUX_DLL_EXTERN tIOConfigInput          IOConfigInput;
_MUX_DLL_EXTERN tIOConfigOutput         IOConfigOutput;
_MUX_DLL_EXTERN tSPITransfer            SPITransfer;
_MUX_DLL_EXTERN tI2CTransfer            I2CTransfer;
_MUX_DLL_EXTERN tFctProprietary         FctProprietary;
_MUX_DLL_EXTERN tPryActivate			PryActivate;
_MUX_DLL_EXTERN tPryDeactivate			PryDeactivate;
_MUX_DLL_EXTERN tPryGetEvent			PryGetEvent;
_MUX_DLL_EXTERN tPrySetNotification		PrySetNotification;
_MUX_DLL_EXTERN tPryClearFifoRx			PryClearFifoRx;
_MUX_DLL_EXTERN tPryGetFifoRxLevel		PryGetFifoRxLevel;

_MUX_DLL_EXTERN tANATransfer            ANATransfer;
_MUX_DLL_EXTERN tANAGetInput			ANAGetInput;
_MUX_DLL_EXTERN tPWMInputActivate       PWMInputActivate;
_MUX_DLL_EXTERN tPWMInputDeactivate     PWMInputDeactivate;
_MUX_DLL_EXTERN tPWMOutputConfig        PWMOutputConfig;
_MUX_DLL_EXTERN tPWMOutputActivate      PWMOutputActivate;
_MUX_DLL_EXTERN tPWMOutputDeactivate    PWMOutputDeactivate;

_MUX_DLL_EXTERN tTimerSet			    TimerSet;
_MUX_DLL_EXTERN tTimerSetNotification	TimerSetNotification;
_MUX_DLL_EXTERN tTimerRead			    TimerRead;

_MUX_DLL_EXTERN tFlashFileOpen			FlashFileOpen;
_MUX_DLL_EXTERN tFlashFileClose			FlashFileClose;
_MUX_DLL_EXTERN tFlashFileRead			FlashFileRead;
_MUX_DLL_EXTERN tFlashFileWrite			FlashFileWrite;
_MUX_DLL_EXTERN tFlashFileSeek			FlashFileSeek;
_MUX_DLL_EXTERN tFlashFileTell			FlashFileTell;
_MUX_DLL_EXTERN tFlashFileGetSize  		FlashFileGetSize;
_MUX_DLL_EXTERN tFlashGetInformations	FlashGetInformations;
_MUX_DLL_EXTERN tFlashFindFirstFile		FlashFindFirstFile;
_MUX_DLL_EXTERN tFlashFindNextFile		FlashFindNextFile;
_MUX_DLL_EXTERN tFlashFileDelete		FlashFileDelete;
_MUX_DLL_EXTERN tFlashFileDownload		FlashFileDownload;
_MUX_DLL_EXTERN tFlashFileRepair		FlashFileRepair;
_MUX_DLL_EXTERN tFlashFormat			FlashFormat;
_MUX_DLL_EXTERN tFlashFileCountSession	FlashFileCountSession;
_MUX_DLL_EXTERN tFlashFindFirstFileInFilter	FlashFindFirstFileInFilter;
_MUX_DLL_EXTERN tFlashFindNextFileInFilter	FlashFindNextFileInFilter;

_MUX_DLL_EXTERN tUSBLIB_GetDeviceList	USBLIB_GetDeviceList;
_MUX_DLL_EXTERN tUSBLIB_Open			USBLIB_Open;
_MUX_DLL_EXTERN tUSBLIB_Close			USBLIB_Close;
_MUX_DLL_EXTERN tUSBLIB_GetPipesInfos	USBLIB_GetPipesInfos;
_MUX_DLL_EXTERN tUSBLIB_GetHardwareID   USBLIB_GetHardwareID;
_MUX_DLL_EXTERN tUSBLIB_GetDeviceIDs	USBLIB_GetDeviceIDs;

_MUX_DLL_EXTERN tUSBLIB_Send			USBLIB_Send;
_MUX_DLL_EXTERN tUSBLIB_WritePipe00		USBLIB_WritePipe00;
_MUX_DLL_EXTERN tUSBLIB_ReadPipe00		USBLIB_ReadPipe00;
_MUX_DLL_EXTERN tUSBLIB_Read			USBLIB_Read;
_MUX_DLL_EXTERN tUSBLIB_ReadCancel		USBLIB_ReadCancel;
_MUX_DLL_EXTERN tUSBLIB_GetEndpointNumber	USBLIB_GetEndpointNumber;

#ifndef MUX_DYNAMIC_DLL_EXTERN
/* Il faut initialiser les pointeurs de fonction DLL // You must call this function first to initialise pointer to library */
static HINSTANCE	hInst=NULL;
tMuxStatus MuxInitAddr(void)
{
	if ((MuxGetTimings			=(tMuxGetTimings)			GetProcAddress(hInst, REFMUX_STR("MuxGetTimings"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxGlobalInit			=(tMuxGlobalInit)			GetProcAddress(hInst, REFMUX_STR("MuxGlobalInit"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxSetUserTimerFct		=(tMuxSetUserTimerFct)		GetProcAddress(hInst, REFMUX_STR("MuxSetUserTimerFct"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxCreateEvent			=(tMuxCreateEvent)			GetProcAddress(hInst, REFMUX_STR("MuxCreateEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxCloseEvent			=(tMuxCloseEvent)			GetProcAddress(hInst, REFMUX_STR("MuxCloseEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxWaitOnEvent			=(tMuxWaitOnEvent)			GetProcAddress(hInst, REFMUX_STR("MuxWaitOnEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxSetEvent			=(tMuxSetEvent)				GetProcAddress(hInst, REFMUX_STR("MuxSetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxClientServerMode	=(tMuxClientServerMode)		GetProcAddress(hInst, REFMUX_STR("MuxClientServerMode"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxCheckAlignment		=(tMuxCheckAlignment)		GetProcAddress(hInst, REFMUX_STR("MuxCheckAlignment"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxCountCards			=(tMuxCountCards)           GetProcAddress(hInst, REFMUX_STR("MuxCountCards"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxPciCountCards		=(tMuxPciCountCards)	    GetProcAddress(hInst, REFMUX_STR("MuxPciCountCards"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxUsbCountCards		=(tMuxUsbCountCards)	    GetProcAddress(hInst, REFMUX_STR("MuxUsbCountCards"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxEthCountCards		=(tMuxEthCountCards)	    GetProcAddress(hInst, REFMUX_STR("MuxEthCountCards"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxPciGetCardInfo		=(tMuxPciGetCardInfo)	    GetProcAddress(hInst, REFMUX_STR("MuxPciGetCardInfo"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxUsbGetCardInfo		=(tMuxUsbGetCardInfo)	    GetProcAddress(hInst, REFMUX_STR("MuxUsbGetCardInfo"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxEthGetCardInfo		=(tMuxEthGetCardInfo)	    GetProcAddress(hInst, REFMUX_STR("MuxEthGetCardInfo"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxInit				=(tMuxInit)				    GetProcAddress(hInst, REFMUX_STR("MuxInit"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxOpen				=(tMuxOpen)				    GetProcAddress(hInst, REFMUX_STR("MuxOpen"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxGetVersion			=(tMuxGetVersion)		    GetProcAddress(hInst, REFMUX_STR("MuxGetVersion"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxGetDescription	  	=(tMuxGetDescription) 	    GetProcAddress(hInst, REFMUX_STR("MuxGetDescription"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxGetInformations		=(tMuxGetInformations)	    GetProcAddress(hInst, REFMUX_STR("MuxGetInformations"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxClose				=(tMuxClose)			    GetProcAddress(hInst, REFMUX_STR("MuxClose"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxGetLastErrorString	=(tMuxGetLastErrorString)   GetProcAddress(hInst, REFMUX_STR("MuxGetLastErrorString"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxGetProtectedCode	=(tMuxGetProtectedCode)     GetProcAddress(hInst, REFMUX_STR("MuxGetProtectedCode"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxUsbDownload     	=(tMuxUsbDownload)          GetProcAddress(hInst, REFMUX_STR("MuxUsbDownload"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxGetInternalInfo    	=(tMuxGetInternalInfo)      GetProcAddress(hInst, REFMUX_STR("MuxGetInternalInfo"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxIsLicenceActive    	=(tMuxIsLicenceActive)      GetProcAddress(hInst, REFMUX_STR("MuxIsLicenceActive"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxSetProductIDMode   	=(tMuxSetProductIDMode)     GetProcAddress(hInst, REFMUX_STR("MuxSetProductIDMode"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxGetBuildNumber   	=(tMuxGetBuildNumber)     	GetProcAddress(hInst, REFMUX_STR("MuxGetBuildNumber"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxGetRTCValue  	 	=(tMuxGetRTCValue) 	    	GetProcAddress(hInst, REFMUX_STR("MuxGetRTCValue"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxSetRTCValue   		=(tMuxSetRTCValue)  	   	GetProcAddress(hInst, REFMUX_STR("MuxSetRTCValue"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxUsbResetPipe   		=(tMuxUsbResetPipe)  	   	GetProcAddress(hInst, REFMUX_STR("MuxUsbResetPipe"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxGetHardwareID  		=(tMuxGetHardwareID)  	   	GetProcAddress(hInst, REFMUX_STR("MuxGetHardwareID"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxSetEthernet 		=(tMuxSetEthernet)  	   	GetProcAddress(hInst, REFMUX_STR("MuxSetEthernet"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((MuxGetEthernet 		=(tMuxGetEthernet)  	   	GetProcAddress(hInst, REFMUX_STR("MuxGetEthernet"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((AdminOpenSession	 	=(tAdminOpenSession)		GetProcAddress(hInst, REFMUX_STR("AdminOpenSession"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((AdminWriteConfig	 	=(tAdminWriteConfig)		GetProcAddress(hInst, REFMUX_STR("AdminWriteConfig"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((AdminReadConfig	 	=(tAdminReadConfig)			GetProcAddress(hInst, REFMUX_STR("AdminReadConfig"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((AdminGetLicenceCount	=(tAdminGetLicenceCount)	GetProcAddress(hInst, REFMUX_STR("AdminGetLicenceCount"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((AdminReadLicences 		=(tAdminReadLicences)		GetProcAddress(hInst, REFMUX_STR("AdminReadLicences"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((AdminWriteLicences		=(tAdminWriteLicences)		GetProcAddress(hInst, REFMUX_STR("AdminWriteLicences"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((AdminGetLicenceData	=(tAdminGetLicenceData)		GetProcAddress(hInst, REFMUX_STR("AdminGetLicenceData"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((AdminSetLicenceData	=(tAdminSetLicenceData)		GetProcAddress(hInst, REFMUX_STR("AdminSetLicenceData"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((AdminReadLicencesData 	=(tAdminReadLicencesData)	GetProcAddress(hInst, REFMUX_STR("AdminReadLicencesData"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((AdminWriteLicencesData	=(tAdminWriteLicencesData)	GetProcAddress(hInst, REFMUX_STR("AdminWriteLicencesData"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((SysSetNotification		=(tSysSetNotification)		GetProcAddress(hInst, REFMUX_STR("SysSetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((SysGetEvent			=(tSysGetEvent)			    GetProcAddress(hInst, REFMUX_STR("SysGetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((CanConfigOper			=(tCanConfigOper)		    GetProcAddress(hInst, REFMUX_STR("CanConfigOper"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanConfigBus			=(tCanConfigBus)		    GetProcAddress(hInst, REFMUX_STR("CanConfigBus"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanConfigParam			=(tCanConfigParam)		    GetProcAddress(hInst, REFMUX_STR("CanConfigParam"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanConfigRangeFilter	=(tCanConfigRangeFilter)    GetProcAddress(hInst, REFMUX_STR("CanConfigRangeFilter"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanConfigClock			=(tCanConfigClock)		    GetProcAddress(hInst, REFMUX_STR("CanConfigClock"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanConfigDualFilter	=(tCanConfigDualFilter)		GetProcAddress(hInst, REFMUX_STR("CanConfigDualFilter"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanConfigStat			=(tCanConfigStat)		    GetProcAddress(hInst, REFMUX_STR("CanConfigStat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanConfigTransceiverHS	=(tCanConfigTransceiverHS)	GetProcAddress(hInst, REFMUX_STR("CanConfigTransceiverHS"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanSelectTransceiverHS	=(tCanSelectTransceiverHS)	GetProcAddress(hInst, REFMUX_STR("CanSelectTransceiverHS"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanConfigTransceiverLS	=(tCanConfigTransceiverLS)	GetProcAddress(hInst, REFMUX_STR("CanConfigTransceiverLS"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanConfigTerminationLS	=(tCanConfigTerminationLS)	GetProcAddress(hInst, REFMUX_STR("CanConfigTerminationLS"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanReadTransceiverLS	=(tCanReadTransceiverLS)	GetProcAddress(hInst, REFMUX_STR("CanReadTransceiverLS"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanCreateMsg			=(tCanCreateMsg)		    GetProcAddress(hInst, REFMUX_STR("CanCreateMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanReadMsg				=(tCanReadMsg)			    GetProcAddress(hInst, REFMUX_STR("CanReadMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanWriteMsg			=(tCanWriteMsg)		    	GetProcAddress(hInst, REFMUX_STR("CanWriteMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanConfigPeriodic		=(tCanConfigPeriodic) 	    GetProcAddress(hInst, REFMUX_STR("CanConfigPeriodic"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanConfigPeriodicList	=(tCanConfigPeriodicList) 	GetProcAddress(hInst, REFMUX_STR("CanConfigPeriodicList"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanSetNotification		=(tCanSetNotification)	    GetProcAddress(hInst, REFMUX_STR("CanSetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanActivate			=(tCanActivate)			    GetProcAddress(hInst, REFMUX_STR("CanActivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanIsBusActive			=(tCanIsBusActive)			GetProcAddress(hInst, REFMUX_STR("CanIsBusActive"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanDeactivate			=(tCanDeactivate)		    GetProcAddress(hInst, REFMUX_STR("CanDeactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanSendMsg				=(tCanSendMsg)			    GetProcAddress(hInst, REFMUX_STR("CanSendMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanSendMsgList			=(tCanSendMsgList)		    GetProcAddress(hInst, REFMUX_STR("CanSendMsgList"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanGetEvent			=(tCanGetEvent)			    GetProcAddress(hInst, REFMUX_STR("CanGetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanBusOn				=(tCanBusOn)			    GetProcAddress(hInst, REFMUX_STR("CanBusOn"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanChangeBaudRate		=(tCanChangeBaudRate)	    GetProcAddress(hInst, REFMUX_STR("CanChangeBaudRate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanGetStat				=(tCanGetStat)			    GetProcAddress(hInst, REFMUX_STR("CanGetStat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanGetBusState			=(tCanGetBusState)		    GetProcAddress(hInst, REFMUX_STR("CanGetBusState"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanClearFifoRx			=(tCanClearFifoRx)		    GetProcAddress(hInst, REFMUX_STR("CanClearFifoRx"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanGetFifoRxLevel  	=(tCanGetFifoRxLevel)	    GetProcAddress(hInst, REFMUX_STR("CanGetFifoRxLevel"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanReadByte			=(tCanReadByte)			    GetProcAddress(hInst, REFMUX_STR("CanReadByte"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((CanWriteByte			=(tCanWriteByte)		    GetProcAddress(hInst, REFMUX_STR("CanWriteByte"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((NwcRegister 		    =(tNwcRegister)	            GetProcAddress(hInst, REFMUX_STR("NwcRegister"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcGetChannelCount	    =(tNwcGetChannelCount)	    GetProcAddress(hInst, REFMUX_STR("NwcGetChannelCount"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcChannelOpen 	    =(tNwcChannelOpen)	        GetProcAddress(hInst, REFMUX_STR("NwcChannelOpen"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcChannelConfig       =(tNwcChannelConfig)        GetProcAddress(hInst, REFMUX_STR("NwcChannelConfig"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcChannelParam 	    =(tNwcChannelParam)	        GetProcAddress(hInst, REFMUX_STR("NwcChannelParam"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcChannelAddr  	    =(tNwcChannelAddr)	        GetProcAddress(hInst, REFMUX_STR("NwcChannelAddr"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcChannelStart 	    =(tNwcChannelStart)         GetProcAddress(hInst, REFMUX_STR("NwcChannelStart"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcChannelStop  	    =(tNwcChannelStop)	        GetProcAddress(hInst, REFMUX_STR("NwcChannelStop"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcChannelClose 	    =(tNwcChannelClose)	        GetProcAddress(hInst, REFMUX_STR("NwcChannelClose"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcSetNotification		=(tNwcSetNotification)	    GetProcAddress(hInst, REFMUX_STR("NwcSetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcActivate            =(tNwcActivate)             GetProcAddress(hInst, REFMUX_STR("NwcActivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcIsBusActive         =(tNwcIsBusActive)          GetProcAddress(hInst, REFMUX_STR("NwcIsBusActive"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcDeactivate          =(tNwcDeactivate)           GetProcAddress(hInst, REFMUX_STR("NwcDeactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcChannelSendMsg      =(tNwcChannelSendMsg)       GetProcAddress(hInst, REFMUX_STR("NwcChannelSendMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcChannelSendAsyncMsg =(tNwcChannelSendAsyncMsg)  GetProcAddress(hInst, REFMUX_STR("NwcChannelSendAsyncMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcGetEvent            =(tNwcGetEvent)             GetProcAddress(hInst, REFMUX_STR("NwcGetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcGetIdent            =(tNwcGetIdent)             GetProcAddress(hInst, REFMUX_STR("NwcGetIdent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcGetFifoRxLevel  	=(tNwcGetFifoRxLevel)	    GetProcAddress(hInst, REFMUX_STR("NwcGetFifoRxLevel"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcConfigSpyMode     	=(tNwcConfigSpyMode)	    GetProcAddress(hInst, REFMUX_STR("NwcConfigSpyMode"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcGetChannelState    	=(tNwcGetChannelState)	    GetProcAddress(hInst, REFMUX_STR("NwcGetChannelState"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwcChannelSetBytePadding    	=(tNwcChannelSetBytePadding)	    GetProcAddress(hInst, REFMUX_STR("NwcChannelSetBytePadding"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((J19Register 		    =(tJ19Register)	            GetProcAddress(hInst, REFMUX_STR("J19Register"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19ChannelOpen			=(tJ19ChannelOpen)			GetProcAddress(hInst, REFMUX_STR("J19ChannelOpen"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19ChannelAddr			=(tJ19ChannelAddr)			GetProcAddress(hInst, REFMUX_STR("J19ChannelAddr"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19ChannelParam		=(tJ19ChannelParam)			GetProcAddress(hInst, REFMUX_STR("J19ChannelParam"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19ChannelConfig		=(tJ19ChannelConfig)		GetProcAddress(hInst, REFMUX_STR("J19ChannelConfig"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19ChannelStart		=(tJ19ChannelStart)			GetProcAddress(hInst, REFMUX_STR("J19ChannelStart"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19ChannelStop			=(tJ19ChannelStop)			GetProcAddress(hInst, REFMUX_STR("J19ChannelStop"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19ChannelClose		=(tJ19ChannelClose)			GetProcAddress(hInst, REFMUX_STR("J19ChannelClose"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19Activate			=(tJ19Activate)				GetProcAddress(hInst, REFMUX_STR("J19Activate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19IsBusActive         =(tJ19IsBusActive)          GetProcAddress(hInst, REFMUX_STR("J19IsBusActive"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19ConfigBus			=(tJ19ConfigBus)			GetProcAddress(hInst, REFMUX_STR("J19ConfigBus"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19Deactivate			=(tJ19Deactivate)			GetProcAddress(hInst, REFMUX_STR("J19Deactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19ChannelSendMsg		=(tJ19ChannelSendMsg)		GetProcAddress(hInst, REFMUX_STR("J19ChannelSendMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19ChannelSendNMEAFastPacket=(tJ19ChannelSendNMEAFastPacket)GetProcAddress(hInst, REFMUX_STR("J19ChannelSendNMEAFastPacket"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19SetNotification		=(tJ19SetNotification)		GetProcAddress(hInst, REFMUX_STR("J19SetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19GetEvent			=(tJ19GetEvent)				GetProcAddress(hInst, REFMUX_STR("J19GetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19GetFifoRxLevel  	=(tJ19GetFifoRxLevel)	    GetProcAddress(hInst, REFMUX_STR("J19GetFifoRxLevel"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J19StoreNMEAFastPacket	=(tJ19StoreNMEAFastPacket)  GetProcAddress(hInst, REFMUX_STR("J19StoreNMEAFastPacket"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1939SetParam          =(tJ1939SetParam)           GetProcAddress(hInst, REFMUX_STR("J1939SetParam"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1939SendMsg           =(tJ1939SendMsg)            GetProcAddress(hInst, REFMUX_STR("J1939SendMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	J1939IsBusActive            =(tJ1939IsBusActive)        J19IsBusActive;
	J1939SetNotification        =(tJ1939SetNotification)    J19SetNotification;
	J1939GetEvent               =(tJ1939GetEvent)           J19GetEvent;
	J1939GetFifoRxLevel         =(tJ1939GetFifoRxLevel)     J19GetFifoRxLevel;

	if ((LinConfigOper			=(tLinConfigOper)		    GetProcAddress(hInst, REFMUX_STR("LinConfigOper"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinConfigBus			=(tLinConfigBus)		    GetProcAddress(hInst, REFMUX_STR("LinConfigBus"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinConfigUart			=(tLinConfigUart)		    GetProcAddress(hInst, REFMUX_STR("LinConfigUart"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinConfigParam			=(tLinConfigParam)		    GetProcAddress(hInst, REFMUX_STR("LinConfigParam"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinConfigStat			=(tLinConfigStat)		    GetProcAddress(hInst, REFMUX_STR("LinConfigStat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinSetVersion			=(tLinSetVersion)		    GetProcAddress(hInst, REFMUX_STR("LinSetVersion"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinSetNotification		=(tLinSetNotification)	    GetProcAddress(hInst, REFMUX_STR("LinSetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinActivate			=(tLinActivate)			    GetProcAddress(hInst, REFMUX_STR("LinActivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinIsBusActive			=(tLinIsBusActive)	        GetProcAddress(hInst, REFMUX_STR("LinIsBusActive"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinConfigTransceiver	=(tLinConfigTransceiver)    GetProcAddress(hInst, REFMUX_STR("LinConfigTransceiver"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinConfigPeriodic		=(tLinConfigPeriodic) 	    GetProcAddress(hInst, REFMUX_STR("LinConfigPeriodic"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinConfigPeriodicList	=(tLinConfigPeriodicList)   GetProcAddress(hInst, REFMUX_STR("LinConfigPeriodicList"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinDeactivate			=(tLinDeactivate)		    GetProcAddress(hInst, REFMUX_STR("LinDeactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinSendMsg				=(tLinSendMsg)			    GetProcAddress(hInst, REFMUX_STR("LinSendMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinSendMsgList			=(tLinSendMsgList)		    GetProcAddress(hInst, REFMUX_STR("LinSendMsgList"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinGetEvent			=(tLinGetEvent)			    GetProcAddress(hInst, REFMUX_STR("LinGetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinGetStat				=(tLinGetStat)			    GetProcAddress(hInst, REFMUX_STR("LinGetStat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinGetBusState			=(tLinGetBusState)		    GetProcAddress(hInst, REFMUX_STR("LinGetBusState"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinSetSleepMode		=(tLinSetSleepMode)		    GetProcAddress(hInst, REFMUX_STR("LinSetSleepMode"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinSetWakeUpMode		=(tLinSetWakeUpMode)	    GetProcAddress(hInst, REFMUX_STR("LinSetWakeUpMode"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinClearFifoRx 		=(tLinClearFifoRx   )	    GetProcAddress(hInst, REFMUX_STR("LinClearFifoRx"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinClearBufferIFR 		=(tLinClearBufferIFR   )	GetProcAddress(hInst, "LinClearBufferIFR")) == NULL) return(STATUS_ERR_OPENDLL);
	if ((LinGetFifoRxLevel 		=(tLinGetFifoRxLevel)	    GetProcAddress(hInst, REFMUX_STR("LinGetFifoRxLevel"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((NwlGetChannelCount	    =(tNwlGetChannelCount)		GetProcAddress(hInst, REFMUX_STR("NwlGetChannelCount"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlChannelOpen 	    =(tNwlChannelOpen)	        GetProcAddress(hInst, REFMUX_STR("NwlChannelOpen"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlChannelConfig       =(tNwlChannelConfig)        GetProcAddress(hInst, REFMUX_STR("NwlChannelConfig"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlChannelParam 	    =(tNwlChannelParam)	        GetProcAddress(hInst, REFMUX_STR("NwlChannelParam"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlChannelAddr  	    =(tNwlChannelAddr)	        GetProcAddress(hInst, REFMUX_STR("NwlChannelAddr"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlChannelStart 	    =(tNwlChannelStart)         GetProcAddress(hInst, REFMUX_STR("NwlChannelStart"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlChannelStop  	    =(tNwlChannelStop)	        GetProcAddress(hInst, REFMUX_STR("NwlChannelStop"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlChannelClose 	    =(tNwlChannelClose)	        GetProcAddress(hInst, REFMUX_STR("NwlChannelClose"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlSetNotification	    =(tNwlSetNotification)		GetProcAddress(hInst, REFMUX_STR("NwlSetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlActivate            =(tNwlActivate)             GetProcAddress(hInst, REFMUX_STR("NwlActivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlIsBusActive         =(tNwlIsBusActive)          GetProcAddress(hInst, REFMUX_STR("NwlIsBusActive"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlDeactivate          =(tNwlDeactivate)           GetProcAddress(hInst, REFMUX_STR("NwlDeactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlChannelSendMsg      =(tNwlChannelSendMsg)       GetProcAddress(hInst, REFMUX_STR("NwlChannelSendMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlChannelReceiveMsg   =(tNwlChannelReceiveMsg)    GetProcAddress(hInst, REFMUX_STR("NwlChannelReceiveMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlGetEvent            =(tNwlGetEvent)             GetProcAddress(hInst, REFMUX_STR("NwlGetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlGetFifoRxLevel      =(tNwlGetFifoRxLevel)		GetProcAddress(hInst, REFMUX_STR("NwlGetFifoRxLevel"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NwlGetChannelState     =(tNwlGetChannelState)		GetProcAddress(hInst, REFMUX_STR("NwlGetChannelState"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((VanConfigOper			=(tVanConfigOper)		    GetProcAddress(hInst, REFMUX_STR("VanConfigOper"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanConfigBus			=(tVanConfigBus)		    GetProcAddress(hInst, REFMUX_STR("VanConfigBus"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanConfigParam			=(tVanConfigParam)		    GetProcAddress(hInst, REFMUX_STR("VanConfigParam"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanConfigStat			=(tVanConfigStat)		    GetProcAddress(hInst, REFMUX_STR("VanConfigStat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanCreateMsg			=(tVanCreateMsg)		    GetProcAddress(hInst, REFMUX_STR("VanCreateMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanConfigPeriodic		=(tVanConfigPeriodic) 	    GetProcAddress(hInst, REFMUX_STR("VanConfigPeriodic"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanConfigPeriodicList	=(tVanConfigPeriodicList)   GetProcAddress(hInst, REFMUX_STR("VanConfigPeriodicList"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanSetNotification		=(tVanSetNotification)	    GetProcAddress(hInst, REFMUX_STR("VanSetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanActivate			=(tVanActivate)		        GetProcAddress(hInst, REFMUX_STR("VanActivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanIsBusActive			=(tVanIsBusActive)	        GetProcAddress(hInst, REFMUX_STR("VanIsBusActive"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanDeactivate			=(tVanDeactivate)		    GetProcAddress(hInst, REFMUX_STR("VanDeactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanSendMsg			    =(tVanSendMsg)		        GetProcAddress(hInst, REFMUX_STR("VanSendMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanSendMsgList		    =(tVanSendMsgList)		    GetProcAddress(hInst, REFMUX_STR("VanSendMsgList"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanGetEvent			=(tVanGetEvent)		        GetProcAddress(hInst, REFMUX_STR("VanGetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanGetStat			    =(tVanGetStat)		        GetProcAddress(hInst, REFMUX_STR("VanGetStat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanGetBusState			=(tVanGetBusState)		    GetProcAddress(hInst, REFMUX_STR("VanGetBusState"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanSetSleepMode		=(tVanSetSleepMode)		    GetProcAddress(hInst, REFMUX_STR("VanSetSleepMode"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanSetWakeUpMode		=(tVanSetWakeUpMode)	    GetProcAddress(hInst, REFMUX_STR("VanSetWakeUpMode"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanGetSleepMode		=(tVanGetSleepMode)		    GetProcAddress(hInst, REFMUX_STR("VanGetSleepMode"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanSetTIP			    =(tVanSetTIP)		        GetProcAddress(hInst, REFMUX_STR("VanSetTIP"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanGetSDCValue			=(tVanGetSDCValue)		    GetProcAddress(hInst, REFMUX_STR("VanGetSDCValue"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanClearFifoRx			=(tVanClearFifoRx)		    GetProcAddress(hInst, REFMUX_STR("VanClearFifoRx"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanGetFifoRxLevel		=(tVanGetFifoRxLevel)	    GetProcAddress(hInst, REFMUX_STR("VanGetFifoRxLevel"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanReadByte			=(tVanReadByte)		        GetProcAddress(hInst, REFMUX_STR("VanReadByte"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((VanWriteByte			=(tVanWriteByte)		    GetProcAddress(hInst, REFMUX_STR("VanWriteByte"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((IsoConfigOper			=(tIsoConfigOper)		    GetProcAddress(hInst, REFMUX_STR("IsoConfigOper"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoConfigBus			=(tIsoConfigBus)		    GetProcAddress(hInst, REFMUX_STR("IsoConfigBus"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoConfigUart			=(tIsoConfigUart)		    GetProcAddress(hInst, REFMUX_STR("IsoConfigUart"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoConfigParam			=(tIsoConfigParam)		    GetProcAddress(hInst, REFMUX_STR("IsoConfigParam"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoConfigStat			=(tIsoConfigStat)		    GetProcAddress(hInst, REFMUX_STR("IsoConfigStat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoConfigPeriodic		=(tIsoConfigPeriodic)		GetProcAddress(hInst, REFMUX_STR("IsoConfigPeriodic"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((Iso14230ConfigPeriodic	=(tIso14230ConfigPeriodic) 	GetProcAddress(hInst, REFMUX_STR("Iso14230ConfigPeriodic"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoActivate			=(tIsoActivate)		        GetProcAddress(hInst, REFMUX_STR("IsoActivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoIsBusActive			=(tIsoIsBusActive)	        GetProcAddress(hInst, REFMUX_STR("IsoIsBusActive"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoDeactivate			=(tIsoDeactivate)		    GetProcAddress(hInst, REFMUX_STR("IsoDeactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoSetNotification	 	=(tIsoSetNotification)	    GetProcAddress(hInst, REFMUX_STR("IsoSetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoSendMsg				=(tIsoSendMsg)				GetProcAddress(hInst, REFMUX_STR("IsoSendMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((Iso14230SendMsg		=(tIso14230SendMsg)	        GetProcAddress(hInst, REFMUX_STR("Iso14230SendMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoGetEvent			=(tIsoGetEvent)		        GetProcAddress(hInst, REFMUX_STR("IsoGetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoWaitResponse		=(tIsoWaitResponse)	        GetProcAddress(hInst, REFMUX_STR("IsoWaitResponse"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoSendResp			=(tIsoSendResp)				GetProcAddress(hInst, REFMUX_STR("IsoSendResp"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoChangeBaudRate 		=(tIsoChangeBaudRate)	    GetProcAddress(hInst, REFMUX_STR("IsoChangeBaudRate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoGetStat				=(tIsoGetStat)			    GetProcAddress(hInst, REFMUX_STR("IsoGetStat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoClearFifoRx			=(tIsoClearFifoRx)		    GetProcAddress(hInst, REFMUX_STR("IsoClearFifoRx"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoGetFifoRxLevel		=(tIsoGetFifoRxLevel)	    GetProcAddress(hInst, REFMUX_STR("IsoGetFifoRxLevel"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoSetDataRxLevel		=(tIsoSetDataRxLevel)	    GetProcAddress(hInst, REFMUX_STR("IsoSetDataRxLevel"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoReadByte			=(tIsoReadByte)		        GetProcAddress(hInst, REFMUX_STR("IsoReadByte"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IsoWriteByte			=(tIsoWriteByte)		    GetProcAddress(hInst, REFMUX_STR("IsoWriteByte"))) == NULL) return(STATUS_ERR_OPENDLL);

    if ((J18ConfigOper			=(tJ18ConfigOper)		    GetProcAddress(hInst, REFMUX_STR("J18ConfigOper"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J18ConfigBus			=(tJ18ConfigBus)		    GetProcAddress(hInst, REFMUX_STR("J18ConfigBus"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J18Activate			=(tJ18Activate)				GetProcAddress(hInst, REFMUX_STR("J18Activate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J18IsBusActive			=(tJ18IsBusActive)			GetProcAddress(hInst, REFMUX_STR("J18IsBusActive"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J18Deactivate	   		=(tJ18Deactivate)		    GetProcAddress(hInst, REFMUX_STR("J18Deactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J18SendMsg	  			=(tJ18SendMsg)   		    GetProcAddress(hInst, REFMUX_STR("J18SendMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J18GetEvent			=(tJ18GetEvent)				GetProcAddress(hInst, REFMUX_STR("J18GetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J18SetNotification  	=(tJ18SetNotification)		GetProcAddress(hInst, REFMUX_STR("J18SetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((J1587ConfigOper		=(tJ1587ConfigOper)		    GetProcAddress(hInst, REFMUX_STR("J1587ConfigOper"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587ConfigBus			=(tJ1587ConfigBus)		    GetProcAddress(hInst, REFMUX_STR("J1587ConfigBus"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587ConfigParam	 	=(tJ1587ConfigParam)	    GetProcAddress(hInst, REFMUX_STR("J1587ConfigParam"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587ConfigStat 	 	=(tJ1587ConfigStat)	        GetProcAddress(hInst, REFMUX_STR("J1587ConfigStat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587ConfigPeriodic	=(tJ1587ConfigPeriodic)     GetProcAddress(hInst, REFMUX_STR("J1587ConfigPeriodic"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587Activate			=(tJ1587Activate)		    GetProcAddress(hInst, REFMUX_STR("J1587Activate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587IsBusActive		=(tJ1587IsBusActive)	    GetProcAddress(hInst, REFMUX_STR("J1587IsBusActive"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587Deactivate	   	=(tJ1587Deactivate)		    GetProcAddress(hInst, REFMUX_STR("J1587Deactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587SendMsg	  		=(tJ1587SendMsg)   		    GetProcAddress(hInst, REFMUX_STR("J1587SendMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587GetEvent			=(tJ1587GetEvent)			GetProcAddress(hInst, REFMUX_STR("J1587GetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587GetBusState 		=(tJ1587GetBusState)	    GetProcAddress(hInst, REFMUX_STR("J1587GetBusState"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587GetStat	 		=(tJ1587GetStat)  		    GetProcAddress(hInst, REFMUX_STR("J1587GetStat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587SetNotification  	=(tJ1587SetNotification)    GetProcAddress(hInst, REFMUX_STR("J1587SetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587ClearFifoRx	    =(tJ1587ClearFifoRx)	    GetProcAddress(hInst, REFMUX_STR("J1587ClearFifoRx"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((J1587GetFifoRxLevel  	=(tJ1587GetFifoRxLevel)	    GetProcAddress(hInst, REFMUX_STR("J1587GetFifoRxLevel"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((NMEA0183ConfigOper		 =(tNMEA0183ConfigOper)		    GetProcAddress(hInst, REFMUX_STR("NMEA0183ConfigOper"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183ConfigBus		 =(tNMEA0183ConfigBus)		    GetProcAddress(hInst, REFMUX_STR("NMEA0183ConfigBus"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183ConfigUart		 =(tNMEA0183ConfigUart)		    GetProcAddress(hInst, REFMUX_STR("NMEA0183ConfigUart"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183ConfigParam	 =(tNMEA0183ConfigParam)	    GetProcAddress(hInst, REFMUX_STR("NMEA0183ConfigParam"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183ConfigStat 	 =(tNMEA0183ConfigStat)	        GetProcAddress(hInst, REFMUX_STR("NMEA0183ConfigStat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183ConfigPeriodic	 =(tNMEA0183ConfigPeriodic)     GetProcAddress(hInst, REFMUX_STR("NMEA0183ConfigPeriodic"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183Activate		 =(tNMEA0183Activate)		    GetProcAddress(hInst, REFMUX_STR("NMEA0183Activate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183IsBusActive	 =(tNMEA0183IsBusActive)	    GetProcAddress(hInst, REFMUX_STR("NMEA0183IsBusActive"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183Deactivate	   	 =(tNMEA0183Deactivate)		    GetProcAddress(hInst, REFMUX_STR("NMEA0183Deactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183SendMsg	  	 =(tNMEA0183SendMsg)   		    GetProcAddress(hInst, REFMUX_STR("NMEA0183SendMsg"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183GetEvent		 =(tNMEA0183GetEvent)			GetProcAddress(hInst, REFMUX_STR("NMEA0183GetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183GetBusState 	 =(tNMEA0183GetBusState)	    GetProcAddress(hInst, REFMUX_STR("NMEA0183GetBusState"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183GetStat	 	 =(tNMEA0183GetStat)  		    GetProcAddress(hInst, REFMUX_STR("NMEA0183GetStat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183SetNotification =(tNMEA0183SetNotification)    GetProcAddress(hInst, REFMUX_STR("NMEA0183SetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183ClearFifoRx	 =(tNMEA0183ClearFifoRx)	    GetProcAddress(hInst, REFMUX_STR("NMEA0183ClearFifoRx"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((NMEA0183GetFifoRxLevel  =(tNMEA0183GetFifoRxLevel)	    GetProcAddress(hInst, REFMUX_STR("NMEA0183GetFifoRxLevel"))) == NULL) return(STATUS_ERR_OPENDLL);

#ifdef _WIN32_WCE	// Under Windows CE
	if ((WINCEConfigParam      = (tWINCEConfigParam)		GetProcAddress(hInst, REFMUX_STR("WINCEConfigParam"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((WINCESetNotification  = (tWINCESetNotification)	GetProcAddress(hInst, REFMUX_STR("WINCESetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((WINCEActivate         = (tWINCEActivate)			GetProcAddress(hInst, REFMUX_STR("WINCEActivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((WINCEDeactivate       = (tWINCEDeactivate)			GetProcAddress(hInst, REFMUX_STR("WINCEDeactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((WINCEGetPowerState    = (tWINCEGetPowerState)		GetProcAddress(hInst, REFMUX_STR("WINCEGetPowerState"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((WINCEGetEvent         = (tWINCEGetEvent)			GetProcAddress(hInst, REFMUX_STR("WINCEGetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((WINCEIsDriverUnloaded = (tWINCEIsDriverUnloaded)	GetProcAddress(hInst, REFMUX_STR("WINCEIsDriverUnloaded"))) == NULL) return(STATUS_ERR_OPENDLL);
#endif	// _WIN32_WCE	

	if ((TimerSet				=(tTimerSet)			    GetProcAddress(hInst, REFMUX_STR("TimerSet"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((TimerSetNotification	=(tTimerSetNotification)    GetProcAddress(hInst, REFMUX_STR("TimerSetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((TimerRead				=(tTimerRead)			    GetProcAddress(hInst, REFMUX_STR("TimerRead"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((IOSetOutput			=(tIOSetOutput)			    GetProcAddress(hInst, REFMUX_STR("IOSetOutput"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IOGetInput				=(tIOGetInput)			    GetProcAddress(hInst, REFMUX_STR("IOGetInput"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IOGetCount				=(tIOGetCount)			    GetProcAddress(hInst, REFMUX_STR("IOGetCount"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IOConfigInput   	    =(tIOConfigInput) 		    GetProcAddress(hInst, REFMUX_STR("IOConfigInput"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((IOConfigOutput   	    =(tIOConfigOutput) 		    GetProcAddress(hInst, REFMUX_STR("IOConfigOutput"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((SPITransfer       	    =(tSPITransfer) 		    GetProcAddress(hInst, REFMUX_STR("SPITransfer"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((I2CTransfer       	    =(tI2CTransfer) 		    GetProcAddress(hInst, REFMUX_STR("I2CTransfer"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FctProprietary       	=(tFctProprietary) 		    GetProcAddress(hInst, REFMUX_STR("FctProprietary"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((PryActivate      	 	=(tPryActivate) 		    GetProcAddress(hInst, REFMUX_STR("PryActivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((PryDeactivate     	 	=(tPryDeactivate) 		    GetProcAddress(hInst, REFMUX_STR("PryDeactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((PryGetEvent      	 	=(tPryGetEvent) 		    GetProcAddress(hInst, REFMUX_STR("PryGetEvent"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((PrySetNotification    	=(tPrySetNotification) 	    GetProcAddress(hInst, REFMUX_STR("PrySetNotification"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((PryClearFifoRx       	=(tPryClearFifoRx) 		    GetProcAddress(hInst, REFMUX_STR("PryClearFifoRx"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((PryGetFifoRxLevel     	=(tPryGetFifoRxLevel)  	    GetProcAddress(hInst, REFMUX_STR("PryGetFifoRxLevel"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((ANATransfer       	    =(tANATransfer) 		    GetProcAddress(hInst, REFMUX_STR("ANATransfer"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((ANAGetInput       	    =(tANAGetInput) 		    GetProcAddress(hInst, REFMUX_STR("ANAGetInput"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((PWMInputActivate  	    =(tPWMInputActivate)        GetProcAddress(hInst, REFMUX_STR("PWMInputActivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((PWMInputDeactivate	    =(tPWMInputDeactivate)      GetProcAddress(hInst, REFMUX_STR("PWMInputDeactivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((PWMOutputConfig	    =(tPWMOutputConfig)         GetProcAddress(hInst, REFMUX_STR("PWMOutputConfig"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((PWMOutputActivate	    =(tPWMOutputActivate)       GetProcAddress(hInst, REFMUX_STR("PWMOutputActivate"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((PWMOutputDeactivate    =(tPWMOutputDeactivate)     GetProcAddress(hInst, REFMUX_STR("PWMOutputDeactivate"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((FlashFileOpen			=(tFlashFileOpen)			GetProcAddress(hInst, REFMUX_STR("FlashFileOpen"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFileClose			=(tFlashFileClose)			GetProcAddress(hInst, REFMUX_STR("FlashFileClose"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFileRead			=(tFlashFileRead)			GetProcAddress(hInst, REFMUX_STR("FlashFileRead"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFileWrite	   		=(tFlashFileWrite)			GetProcAddress(hInst, REFMUX_STR("FlashFileWrite"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFileSeek			=(tFlashFileSeek)			GetProcAddress(hInst, REFMUX_STR("FlashFileSeek"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFileTell			=(tFlashFileTell)			GetProcAddress(hInst, REFMUX_STR("FlashFileTell"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFileGetSize		=(tFlashFileGetSize)		GetProcAddress(hInst, REFMUX_STR("FlashFileGetSize"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashGetInformations	=(tFlashGetInformations)	GetProcAddress(hInst, REFMUX_STR("FlashGetInformations"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFindFirstFile		=(tFlashFindFirstFile)		GetProcAddress(hInst, REFMUX_STR("FlashFindFirstFile"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFindNextFile		=(tFlashFindNextFile)		GetProcAddress(hInst, REFMUX_STR("FlashFindNextFile"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFileDelete		=(tFlashFileDelete)			GetProcAddress(hInst, REFMUX_STR("FlashFileDelete"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFileDownload		=(tFlashFileDownload)	   	GetProcAddress(hInst, REFMUX_STR("FlashFileDownload"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFileRepair		=(tFlashFileRepair)		   	GetProcAddress(hInst, REFMUX_STR("FlashFileRepair"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFormat			=(tFlashFormat)		 	  	GetProcAddress(hInst, REFMUX_STR("FlashFormat"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFileCountSession	=(tFlashFileCountSession)	GetProcAddress(hInst, REFMUX_STR("FlashFileCountSession"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFindFirstFileInFilter	=(tFlashFindFirstFileInFilter)	GetProcAddress(hInst, REFMUX_STR("FlashFindFirstFileInFilter"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((FlashFindNextFileInFilter	=(tFlashFindNextFileInFilter)	GetProcAddress(hInst, REFMUX_STR("FlashFindNextFileInFilter"))) == NULL) return(STATUS_ERR_OPENDLL);

	if ((USBLIB_GetDeviceList 	=(tUSBLIB_GetDeviceList)   	GetProcAddress(hInst, REFMUX_STR("USBLIB_GetDeviceList"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((USBLIB_Open 			=(tUSBLIB_Open)   			GetProcAddress(hInst, REFMUX_STR("USBLIB_Open"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((USBLIB_Close 			=(tUSBLIB_Close)   			GetProcAddress(hInst, REFMUX_STR("USBLIB_Close"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((USBLIB_GetPipesInfos	=(tUSBLIB_GetPipesInfos)	GetProcAddress(hInst, REFMUX_STR("USBLIB_GetPipesInfos"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((USBLIB_Send			=(tUSBLIB_Send)				GetProcAddress(hInst, REFMUX_STR("USBLIB_Send"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((USBLIB_WritePipe00		=(tUSBLIB_WritePipe00)		GetProcAddress(hInst, REFMUX_STR("USBLIB_WritePipe00"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((USBLIB_ReadPipe00		=(tUSBLIB_ReadPipe00)		GetProcAddress(hInst, REFMUX_STR("USBLIB_ReadPipe00"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((USBLIB_Read			=(tUSBLIB_Read)				GetProcAddress(hInst, REFMUX_STR("USBLIB_Read"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((USBLIB_ReadCancel		=(tUSBLIB_ReadCancel)		GetProcAddress(hInst, REFMUX_STR("USBLIB_ReadCancel"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((USBLIB_GetEndpointNumber = (tUSBLIB_GetEndpointNumber)GetProcAddress(hInst, REFMUX_STR("USBLIB_GetEndpointNumber"))) == NULL) return(STATUS_ERR_OPENDLL);
	if ((USBLIB_GetHardwareID = (tUSBLIB_GetHardwareID)GetProcAddress(hInst, REFMUX_STR("USBLIB_GetHardwareID"))) == NULL) return(STATUS_ERR_OPENDLL);
	if( ( USBLIB_GetDeviceIDs = ( tUSBLIB_GetDeviceIDs )GetProcAddress( hInst, REFMUX_STR( "USBLIB_GetDeviceIDs" ) ) ) == NULL ) return( STATUS_ERR_OPENDLL );

	return(STATUS_OK);
}
tMuxStatus MuxFreeDLL(void)
{
	if (hInst != NULL) FreeLibrary(hInst);
    hInst=NULL;
    return(STATUS_OK);
}

tMuxStatus MuxLoadDLL(void)
{
	if ((hInst=LoadLibrary(_MUXDLLBIN_STR)) == NULL)				// Specific DLL (./bin)
	{
		if ((hInst=LoadLibrary(_MUXDLLCUR_STR)) == NULL)			// Specific DLL (./)
		{
			if ((hInst=LoadLibrary(REFMUX_STR(_MUXDLL_STR))) == NULL)					// Generic DLL (Windows/system)
			{
				return(STATUS_ERR_FILEDLL);
			}
		}
	}
	if (MuxInitAddr() != STATUS_OK)
	{
		MuxFreeDLL();
		return(STATUS_ERR_OPENDLL);
	}
	return STATUS_OK;
}

// Load the muxdll using server/client connection allowing to use several application with the same device
tMuxStatus MuxLoadDLLClient(void)
{
	void *	hMutex;

	hMutex = OpenMutex(MUTEX_ALL_ACCESS, FALSE, _MUTEX_NAME);
    if(hMutex==NULL) return(STATUS_ERR_SERVERNOTLOADED);
    CloseHandle(hMutex);

	if ((hInst=LoadLibrary(_AEBRDGBIN_STR)) == NULL)				// Specific DLL
    {
		if ((hInst=LoadLibrary(_AEBRDGB_STR)) == NULL)					// Generic DLL (Windows/system)
        {
            return(STATUS_ERR_FILEDLL);
        }
    }
    if (MuxInitAddr() != STATUS_OK)
    {
        MuxFreeDLL();
        return(STATUS_ERR_OPENDLL);
    }
	return STATUS_OK;
}

#endif

#endif


#ifdef __BORLANDC__
#pragma option pop                  // Return as before
#endif
#pragma pack(pop)                   // Return as before


#endif                              // End of _REFMUX_H_


